@@ -143,6 +143,7 @@ elif [[ "$DRIVER" == "lvm" ]]; then
 
     echo "SHARE_DRIVER=manila.share.drivers.lvm.LVMShareDriver" >> $localconf
     echo "SHARE_BACKING_FILE_SIZE=32000M" >> $localconf
+    export MANILA_SETUP_IPV6=True
 elif [[ "$DRIVER" == "zfsonlinux" ]]; then
     MANILA_SERVICE_IMAGE_ENABLED=True
     echo "SHARE_DRIVER=manila.share.drivers.zfsonlinux.driver.ZFSonLinuxShareDriver" >> $localconf
@@ -162,10 +163,6 @@ elif [[ "$DRIVER" == "container"* ]]; then
 fi
 
 echo "MANILA_SERVICE_IMAGE_ENABLED=$MANILA_SERVICE_IMAGE_ENABLED" >> $localconf
-if [[ "$MANILA_SERVICE_IMAGE_ENABLED" == True ]]; then
-    echo "MANILA_SERVICE_IMAGE_URL=$MANILA_SERVICE_IMAGE_URL" >> $localconf
-    echo "MANILA_SERVICE_IMAGE_NAME=$MANILA_SERVICE_IMAGE_NAME" >> $localconf
-fi
 echo "MANILA_DEFAULT_SHARE_TYPE_EXTRA_SPECS=$DEFAULT_EXTRA_SPECS" >> $localconf
 
 # Enabling isolated metadata in Neutron is required because
@@ -178,6 +175,16 @@ echo "TEMPEST_USE_TEST_ACCOUNTS=True" >> $localconf
 echo "TEMPEST_ALLOW_TENANT_ISOLATION=False" >> $localconf
 echo "TEMPEST_CONCURRENCY=${MANILA_TEMPEST_CONCURRENCY:-8}" >> $localconf
 
+MANILA_SETUP_IPV6=${MANILA_SETUP_IPV6:-False}
+echo "MANILA_SETUP_IPV6=${MANILA_SETUP_IPV6}" >> $localconf
+if [[ "$MANILA_SETUP_IPV6" == True ]]; then
+    # When setting up proper IPv6 networks, we should do it ourselves so we can
+    # use Neutron Dynamic Routing plugin with address scopes instead of the
+    # regular Neutron DevStack configuration.
+    echo "NEUTRON_CREATE_INITIAL_NETWORKS=False" >> $localconf
+    echo "IP_VERSION=4+6" >> $localconf
+fi
+
 if [[ "$DRIVER" == "generic"* ]]; then
     echo -e '[[post-config|${NOVA_CONF:-/etc/nova/nova.conf}]]\n[DEFAULT]\nquota_instances=30\n' >> $localconf
     echo -e '[[post-config|${NEUTRON_CONF:-/etc/neutron/neutron.conf}]]\n[DEFAULT]\nmax_fixed_ips_per_port=100\n' >> $localconf
