@@ -136,32 +136,6 @@ def limited(items, request, max_limit=CONF.osapi_max_limit):
     return items[offset:range_end]
 
 
-def limited_by_marker(items, request, max_limit=CONF.osapi_max_limit):
-    """Return a slice of items according to the requested marker and limit."""
-    params = get_pagination_params(request)
-
-    limit = params.get('limit', max_limit)
-    marker = params.get('marker')
-
-    limit = min(max_limit, limit)
-    start_index = 0
-    if marker:
-        start_index = -1
-        for i, item in enumerate(items):
-            if 'flavorid' in item:
-                if item['flavorid'] == marker:
-                    start_index = i + 1
-                    break
-            elif item['id'] == marker or item.get('uuid') == marker:
-                start_index = i + 1
-                break
-        if start_index < 0:
-            msg = _('marker [%s] not found') % marker
-            raise webob.exc.HTTPBadRequest(explanation=msg)
-    range_end = start_index + limit
-    return items[start_index:range_end]
-
-
 def remove_version_from_href(href):
     """Removes the first api version from the href.
 
@@ -337,12 +311,12 @@ def validate_common_name(access):
 
 
 def validate_username(access):
-    valid_username_re = '[\w\.\-_\`;\'\{\}\[\]\\\\]{4,255}$'
+    valid_username_re = '[\w\$\.\-_\`;\'\{\}\[\]\\\\]{4,255}$'
     username = access
     if not re.match(valid_username_re, username):
         exc_str = ('Invalid user or group name. Must be 4-255 characters '
                    'and consist of alphanumeric characters and '
-                   'special characters ]{.-_\'`;}[\\')
+                   'special characters $]{.-_\'`;}[\\')
         raise webob.exc.HTTPBadRequest(explanation=exc_str)
 
 
