@@ -29,9 +29,10 @@ from manila.api.openstack import api_version_request as api_version
 from manila.api.openstack import versioned_method
 from manila.common import constants
 from manila import exception
-from manila.i18n import _, _LE, _LI
+from manila.i18n import _
 from manila import policy
-from manila import wsgi
+from manila import utils
+from manila.wsgi import common as wsgi
 
 LOG = log.getLogger(__name__)
 
@@ -524,14 +525,14 @@ class ResourceExceptionHandler(object):
                 code=ex_value.code, explanation=six.text_type(ex_value)))
         elif isinstance(ex_value, TypeError):
             exc_info = (ex_type, ex_value, ex_traceback)
-            LOG.error(_LE('Exception handling resource: %s'),
+            LOG.error('Exception handling resource: %s',
                       ex_value, exc_info=exc_info)
             raise Fault(webob.exc.HTTPBadRequest())
         elif isinstance(ex_value, Fault):
-            LOG.info(_LI("Fault thrown: %s"), ex_value)
+            LOG.info("Fault thrown: %s", ex_value)
             raise ex_value
         elif isinstance(ex_value, webob.exc.HTTPException):
-            LOG.info(_LI("HTTP exception thrown: %s"), ex_value)
+            LOG.info("HTTP exception thrown: %s", ex_value)
             raise Fault(ex_value)
 
         # We didn't handle the exception
@@ -732,8 +733,8 @@ class Resource(wsgi.Application):
     def __call__(self, request):
         """WSGI method that controls (de)serialization and method dispatch."""
 
-        LOG.info(_LI("%(method)s %(url)s") % {"method": request.method,
-                                              "url": request.url})
+        LOG.info("%(method)s %(url)s", {"method": request.method,
+                                        "url": request.url})
         if self.support_api_request_version:
             # Set the version of the API requested based on the header
             try:
@@ -860,15 +861,20 @@ class Resource(wsgi.Application):
 
         if hasattr(response, 'headers'):
             for hdr, val in response.headers.items():
-                # Headers must be utf-8 strings
-                response.headers[hdr] = six.text_type(val)
+                val = utils.convert_str(val)
+                response.headers[hdr] = val
 
             if not request.api_version_request.is_null():
                 response.headers[API_VERSION_REQUEST_HEADER] = (
                     request.api_version_request.get_string())
                 if request.api_version_request.experimental:
+                    # NOTE(vponomaryov): Translate our boolean header
+                    # to string explicitly to avoid 'TypeError' failure
+                    # running manila API under Apache + mod-wsgi.
+                    # It is safe to do so, because all headers are returned as
+                    # strings anyway.
                     response.headers[EXPERIMENTAL_API_REQUEST_HEADER] = (
-                        request.api_version_request.experimental)
+                        '%s' % request.api_version_request.experimental)
                 response.headers['Vary'] = API_VERSION_REQUEST_HEADER
 
         return response
@@ -894,7 +900,7 @@ class Resource(wsgi.Application):
             # OK, it's an action; figure out which action...
             mtype = _MEDIA_TYPE_MAP.get(content_type)
             action_name = self.action_peek[mtype](body)
-            LOG.debug("Action body: %s" % body)
+            LOG.debug("Action body: %s", body)
         else:
             action_name = action
 
@@ -1280,14 +1286,19 @@ class Fault(webob.exc.HTTPException):
                 'message': self.wrapped_exc.explanation}}
         if code == 413:
             retry = self.wrapped_exc.headers['Retry-After']
-            fault_data[fault_name]['retryAfter'] = retry
+            fault_data[fault_name]['retryAfter'] = '%s' % retry
 
         if not req.api_version_request.is_null():
             self.wrapped_exc.headers[API_VERSION_REQUEST_HEADER] = (
                 req.api_version_request.get_string())
             if req.api_version_request.experimental:
+                # NOTE(vponomaryov): Translate our boolean header
+                # to string explicitly to avoid 'TypeError' failure
+                # running manila API under Apache + mod-wsgi.
+                # It is safe to do so, because all headers are returned as
+                # strings anyway.
                 self.wrapped_exc.headers[EXPERIMENTAL_API_REQUEST_HEADER] = (
-                    req.api_version_request.experimental)
+                    '%s' % req.api_version_request.experimental)
             self.wrapped_exc.headers['Vary'] = API_VERSION_REQUEST_HEADER
 
         content_type = req.best_match_content_type()
@@ -1330,7 +1341,7 @@ class OverLimitFault(webob.exc.HTTPException):
     def _retry_after(retry_time):
         delay = int(math.ceil(retry_time - time.time()))
         retry_after = delay if delay > 0 else 0
-        headers = {'Retry-After': '%d' % retry_after}
+        headers = {'Retry-After': '%s' % retry_after}
         return headers
 
     @webob.dec.wsgify(RequestClass=Request)
