@@ -26,7 +26,6 @@ from manila.api.v1 import scheduler_stats
 from manila.api.v1 import security_service
 from manila.api.v1 import share_manage
 from manila.api.v1 import share_metadata
-from manila.api.v1 import share_networks
 from manila.api.v1 import share_servers
 from manila.api.v1 import share_snapshots
 from manila.api.v1 import share_types_extra_specs
@@ -36,6 +35,7 @@ from manila.api.v2 import availability_zones
 from manila.api.v2 import quota_class_sets
 from manila.api.v2 import quota_sets
 from manila.api.v2 import services
+from manila.api.v2 import share_networks
 from manila.api.v2 import share_types
 from manila.api import versions
 
@@ -120,8 +120,8 @@ class APIRouter(manila.api.openstack.APIRouter):
         mapper.resource("limit", "limits",
                         controller=self.resources['limits'])
 
-        self.resources["security_services"] = \
-            security_service.create_resource()
+        self.resources["security_services"] = (
+            security_service.create_resource())
         mapper.resource("security-service", "security-services",
                         controller=self.resources['security_services'],
                         collection={'detail': 'GET'})
