@@ -31,6 +31,7 @@ from manila.api.v1 import share_servers
 from manila.api.v1 import share_types_extra_specs
 from manila.api.v1 import share_unmanage
 from manila.api.v2 import availability_zones
+from manila.api.v2 import messages
 from manila.api.v2 import quota_class_sets
 from manila.api.v2 import quota_sets
 from manila.api.v2 import services
@@ -410,3 +411,7 @@ class APIRouter(manila.api.openstack.APIRouter):
                         controller=self.resources['share-replicas'],
                         collection={'detail': 'GET'},
                         member={'action': 'POST'})
+
+        self.resources['messages'] = messages.create_resource()
+        mapper.resource("message", "messages",
+                        controller=self.resources['messages'])
