@@ -20,11 +20,12 @@ import webob
 from webob import exc
 
 from manila.api import common
+from manila.api.openstack import api_version_request as api_version
 from manila.api.openstack import wsgi
 from manila.api.views import share_groups as share_group_views
 from manila import db
 from manila import exception
-from manila.i18n import _, _LI
+from manila.i18n import _
 from manila.share import share_types
 from manila.share_group import api as share_group_api
 from manila.share_group import share_group_types
@@ -64,7 +65,7 @@ class ShareGroupController(wsgi.Controller, wsgi.AdminActionsMixin):
         """Delete a share group."""
         context = req.environ['manila.context']
 
-        LOG.info(_LI("Delete share group with id: %s"), id, context=context)
+        LOG.info("Delete share group with id: %s", id, context=context)
         share_group = self._get_share_group(context, id)
         try:
             self.share_group_api.delete(context, share_group)
@@ -96,6 +97,9 @@ class ShareGroupController(wsgi.Controller, wsgi.AdminActionsMixin):
         search_opts.pop('offset', None)
         sort_key = search_opts.pop('sort_key', 'created_at')
         sort_dir = search_opts.pop('sort_dir', 'desc')
+        if req.api_version_request < api_version.APIVersionRequest("2.36"):
+            search_opts.pop('name~', None)
+            search_opts.pop('description~', None)
         if 'group_type_id' in search_opts:
             search_opts['share_group_type_id'] = search_opts.pop(
                 'group_type_id')
@@ -154,6 +158,7 @@ class ShareGroupController(wsgi.Controller, wsgi.AdminActionsMixin):
             'share_group_type_id',
             'source_share_group_snapshot_id',
             'share_network_id',
+            'availability_zone',
         }
         invalid_fields = set(share_group.keys()) - valid_fields
         if invalid_fields:
@@ -197,6 +202,20 @@ class ShareGroupController(wsgi.Controller, wsgi.AdminActionsMixin):
                     "network is inherited from the source.")
             raise exc.HTTPBadRequest(explanation=msg)
 
+        availability_zone = share_group.get('availability_zone')
+        if availability_zone:
+            if 'source_share_group_snapshot_id' in share_group:
+                msg = _(
+                    "Cannot supply both 'availability_zone' and "
+                    "'source_share_group_snapshot_id' attributes as the "
+                    "availability zone is inherited from the source.")
+                raise exc.HTTPBadRequest(explanation=msg)
+            try:
+                az_id = db.availability_zone_get(context, availability_zone).id
+                kwargs['availability_zone_id'] = az_id
+            except exception.AvailabilityZoneNotFound as e:
+                raise exc.HTTPNotFound(explanation=six.text_type(e))
+
         if 'source_share_group_snapshot_id' in share_group:
             source_share_group_snapshot_id = share_group.get(
                 'source_share_group_snapshot_id')
