@@ -17,11 +17,14 @@ class ViewBuilder(common.ViewBuilder):
     """Model a server API response as a python dictionary."""
 
     _collection_name = 'share_instances'
+    _collection_links = 'share_instances_links'
 
     _detail_version_modifiers = [
         "remove_export_locations",
         "add_access_rules_status_field",
         "add_replication_fields",
+        "add_share_type_field",
+        "add_cast_rules_to_readonly_field",
     ]
 
     def detail_list(self, request, instances):
@@ -58,21 +61,33 @@ class ViewBuilder(common.ViewBuilder):
         instances_dict = {self._collection_name: instances_list}
 
         if instances_links:
-            instances_dict[self._collection_name] = instances_links
+            instances_dict[self._collection_links] = instances_links
 
         return instances_dict
 
     @common.ViewBuilder.versioned_method("2.9")
-    def remove_export_locations(self, share_instance_dict, share_instance):
+    def remove_export_locations(self, context, share_instance_dict,
+                                share_instance):
         share_instance_dict.pop('export_location')
         share_instance_dict.pop('export_locations')
 
     @common.ViewBuilder.versioned_method("2.10")
-    def add_access_rules_status_field(self, instance_dict, share_instance):
+    def add_access_rules_status_field(self, context, instance_dict,
+                                      share_instance):
         instance_dict['access_rules_status'] = (
             share_instance.get('access_rules_status')
         )
 
     @common.ViewBuilder.versioned_method("2.11")
-    def add_replication_fields(self, instance_dict, share_instance):
+    def add_replication_fields(self, context, instance_dict, share_instance):
         instance_dict['replica_state'] = share_instance.get('replica_state')
+
+    @common.ViewBuilder.versioned_method("2.22")
+    def add_share_type_field(self, context, instance_dict, share_instance):
+        instance_dict['share_type_id'] = share_instance.get('share_type_id')
+
+    @common.ViewBuilder.versioned_method("2.30")
+    def add_cast_rules_to_readonly_field(self, context, instance_dict,
+                                         share_instance):
+        instance_dict['cast_rules_to_readonly'] = share_instance.get(
+            'cast_rules_to_readonly', False)
