@@ -23,6 +23,8 @@ import sys
 
 from oslo_config import cfg
 from oslo_log import log
+from oslo_reports import guru_meditation_report as gmr
+from oslo_reports import opts as gmr_opts
 
 from manila import i18n
 i18n.enable_lazy()
@@ -36,10 +38,12 @@ CONF = cfg.CONF
 
 def main():
     log.register_options(CONF)
+    gmr_opts.set_defaults(CONF)
     CONF(sys.argv[1:], project='manila',
          version=version.version_string())
     log.setup(CONF, "manila")
     utils.monkey_patch()
+    gmr.TextGuruMeditation.setup_autorun(version, conf=CONF)
     server = service.Service.create(binary='manila-data')
     service.serve(server)
     service.wait()
