@@ -21,7 +21,7 @@ from oslo_config import cfg
 from oslo_log import log
 
 from manila import exception
-from manila.i18n import _, _LW
+from manila.i18n import _
 
 CONF = cfg.CONF
 LOG = log.getLogger(__name__)
@@ -78,7 +78,7 @@ class AuthClientLoader(object):
             CONF, self.group)
 
         if self.deprecated_opts_for_v2 and not self.auth_plugin:
-            LOG.warning(_LW("Not specifying auth options is deprecated"))
+            LOG.warning("Not specifying auth options is deprecated")
             self.auth_plugin = v2.Password().load_from_options(
                 **self.deprecated_opts_for_v2)
 
