@@ -44,8 +44,6 @@ core_opts = [
     cfg.StrOpt('state_path',
                default='/var/lib/manila',
                help="Top-level directory for maintaining manila's state."),
-    cfg.StrOpt('os_region_name',
-               help='Region name of this node.'),
 ]
 
 debug_opts = [
