@@ -136,15 +136,11 @@ def service_update(context, service_id, values):
 ####################
 
 
-def quota_create(context, project_id, resource, limit, user_id=None):
+def quota_create(context, project_id, resource, limit, user_id=None,
+                 share_type_id=None):
     """Create a quota for the given project and resource."""
     return IMPL.quota_create(context, project_id, resource, limit,
-                             user_id=user_id)
-
-
-def quota_get(context, project_id, resource, user_id=None):
-    """Retrieve a quota or raise if it does not exist."""
-    return IMPL.quota_get(context, project_id, resource, user_id=user_id)
+                             user_id=user_id, share_type_id=share_type_id)
 
 
 def quota_get_all_by_project_and_user(context, project_id, user_id):
@@ -152,6 +148,13 @@ def quota_get_all_by_project_and_user(context, project_id, user_id):
     return IMPL.quota_get_all_by_project_and_user(context, project_id, user_id)
 
 
+def quota_get_all_by_project_and_share_type(context, project_id,
+                                            share_type_id):
+    """Retrieve all quotas associated with a given project and user."""
+    return IMPL.quota_get_all_by_project_and_share_type(
+        context, project_id, share_type_id)
+
+
 def quota_get_all_by_project(context, project_id):
     """Retrieve all quotas associated with a given project."""
     return IMPL.quota_get_all_by_project(context, project_id)
@@ -162,10 +165,11 @@ def quota_get_all(context, project_id):
     return IMPL.quota_get_all(context, project_id)
 
 
-def quota_update(context, project_id, resource, limit, user_id=None):
+def quota_update(context, project_id, resource, limit, user_id=None,
+                 share_type_id=None):
     """Update a quota or raise if it does not exist."""
     return IMPL.quota_update(context, project_id, resource, limit,
-                             user_id=user_id)
+                             user_id=user_id, share_type_id=share_type_id)
 
 
 ###################
@@ -199,9 +203,12 @@ def quota_class_update(context, class_name, resource, limit):
 ###################
 
 
-def quota_usage_get(context, project_id, resource, user_id=None):
+def quota_usage_get(context, project_id, resource, user_id=None,
+                    share_type_id=None):
     """Retrieve a quota usage or raise if it does not exist."""
-    return IMPL.quota_usage_get(context, project_id, resource, user_id=user_id)
+    return IMPL.quota_usage_get(
+        context, project_id, resource, user_id=user_id,
+        share_type_id=share_type_id)
 
 
 def quota_usage_get_all_by_project_and_user(context, project_id, user_id):
@@ -210,47 +217,61 @@ def quota_usage_get_all_by_project_and_user(context, project_id, user_id):
                                                         project_id, user_id)
 
 
+def quota_usage_get_all_by_project_and_share_type(context, project_id,
+                                                  share_type_id):
+    """Retrieve all usage associated with a given resource."""
+    return IMPL.quota_usage_get_all_by_project_and_share_type(
+        context, project_id, share_type_id)
+
+
 def quota_usage_get_all_by_project(context, project_id):
     """Retrieve all usage associated with a given resource."""
     return IMPL.quota_usage_get_all_by_project(context, project_id)
 
 
 def quota_usage_create(context, project_id, user_id, resource, in_use,
-                       reserved=0, until_refresh=None):
+                       reserved=0, until_refresh=None, share_type_id=None):
     """Create a quota usage."""
-    return IMPL.quota_usage_create(context, project_id, user_id, resource,
-                                   in_use, reserved, until_refresh)
+    return IMPL.quota_usage_create(
+        context, project_id, user_id, resource, in_use, reserved,
+        until_refresh, share_type_id=share_type_id)
 
 
-def quota_usage_update(context, project_id, user_id, resource, **kwargs):
+def quota_usage_update(context, project_id, user_id, resource,
+                       share_type_id=None, **kwargs):
     """Update a quota usage or raise if it does not exist."""
-    return IMPL.quota_usage_update(context, project_id, user_id, resource,
-                                   **kwargs)
+    return IMPL.quota_usage_update(
+        context, project_id, user_id, resource, share_type_id=share_type_id,
+        **kwargs)
 
 
 ###################
 
 
-def quota_reserve(context, resources, quotas, user_quotas, deltas, expire,
-                  until_refresh, max_age, project_id=None, user_id=None):
+def quota_reserve(context, resources, quotas, user_quotas, share_type_quotas,
+                  deltas, expire, until_refresh, max_age,
+                  project_id=None, user_id=None, share_type_id=None):
     """Check quotas and create appropriate reservations."""
-    return IMPL.quota_reserve(context, resources, quotas, user_quotas, deltas,
-                              expire, until_refresh, max_age,
-                              project_id=project_id, user_id=user_id)
+    return IMPL.quota_reserve(
+        context, resources, quotas, user_quotas, share_type_quotas, deltas,
+        expire, until_refresh, max_age, project_id=project_id, user_id=user_id,
+        share_type_id=share_type_id)
 
 
-def reservation_commit(context, reservations, project_id=None, user_id=None):
+def reservation_commit(context, reservations, project_id=None, user_id=None,
+                       share_type_id=None):
     """Commit quota reservations."""
-    return IMPL.reservation_commit(context, reservations,
-                                   project_id=project_id,
-                                   user_id=user_id)
+    return IMPL.reservation_commit(
+        context, reservations, project_id=project_id, user_id=user_id,
+        share_type_id=share_type_id)
 
 
-def reservation_rollback(context, reservations, project_id=None, user_id=None):
+def reservation_rollback(context, reservations, project_id=None, user_id=None,
+                         share_type_id=None):
     """Roll back quota reservations."""
-    return IMPL.reservation_rollback(context, reservations,
-                                     project_id=project_id,
-                                     user_id=user_id)
+    return IMPL.reservation_rollback(
+        context, reservations, project_id=project_id, user_id=user_id,
+        share_type_id=share_type_id)
 
 
 def quota_destroy_all_by_project_and_user(context, project_id, user_id):
@@ -259,6 +280,13 @@ def quota_destroy_all_by_project_and_user(context, project_id, user_id):
                                                       project_id, user_id)
 
 
+def quota_destroy_all_by_project_and_share_type(context, project_id,
+                                                share_type_id):
+    """Destroy all quotas associated with a given project and user."""
+    return IMPL.quota_destroy_all_by_project_and_share_type(
+        context, project_id, share_type_id)
+
+
 def quota_destroy_all_by_project(context, project_id):
     """Destroy all quotas associated with a given project."""
     return IMPL.quota_destroy_all_by_project(context, project_id)
@@ -283,9 +311,12 @@ def share_instance_create(context, share_id, values):
     return IMPL.share_instance_create(context, share_id, values)
 
 
-def share_instance_delete(context, instance_id):
+def share_instance_delete(context, instance_id, session=None,
+                          need_to_update_usages=False):
     """Delete share instance."""
-    return IMPL.share_instance_delete(context, instance_id)
+    return IMPL.share_instance_delete(
+        context, instance_id, session=session,
+        need_to_update_usages=need_to_update_usages)
 
 
 def share_instance_update(context, instance_id, values, with_share_data=False):
@@ -294,9 +325,9 @@ def share_instance_update(context, instance_id, values, with_share_data=False):
                                       with_share_data=with_share_data)
 
 
-def share_instances_get_all(context):
+def share_instances_get_all(context, filters=None):
     """Returns all share instances."""
-    return IMPL.share_instances_get_all(context)
+    return IMPL.share_instances_get_all(context, filters=filters)
 
 
 def share_instances_get_all_by_share_server(context, share_server_id):
@@ -770,6 +801,13 @@ def share_network_remove_security_service(context, id, security_service_id):
                                                       security_service_id)
 
 
+def count_share_networks(context, project_id, user_id=None,
+                         share_type_id=None, session=None):
+    return IMPL.count_share_networks(
+        context, project_id, user_id=user_id, share_type_id=share_type_id,
+        session=session,
+    )
+
 ##################
 
 
@@ -1259,3 +1297,44 @@ def share_group_type_specs_update_or_create(context, type_id, group_specs):
     """
     return IMPL.share_group_type_specs_update_or_create(
         context, type_id, group_specs)
+
+
+####################
+
+
+def message_get(context, message_id):
+    """Return a message with the specified ID."""
+    return IMPL.message_get(context, message_id)
+
+
+def message_get_all(context, filters=None, sort_key=None, sort_dir=None):
+    """Returns all messages with the project of the specified context."""
+    return IMPL.message_get_all(context, filters=filters, sort_key=sort_key,
+                                sort_dir=sort_dir)
+
+
+def message_create(context, values):
+    """Creates a new message with the specified values."""
+    return IMPL.message_create(context, values)
+
+
+def message_destroy(context, message_id):
+    """Deletes message with the specified ID."""
+    return IMPL.message_destroy(context, message_id)
+
+
+def cleanup_expired_messages(context):
+    """Soft delete expired messages"""
+    return IMPL.cleanup_expired_messages(context)
+
+
+def backend_info_get(context, host):
+    """Get hash info for given host."""
+    return IMPL.backend_info_get(context, host)
+
+
+def backend_info_update(context, host, value=None,
+                        delete_existing=False):
+    """Update hash info for host."""
+    return IMPL.backend_info_update(context, host=host, value=value,
+                                    delete_existing=delete_existing)
