@@ -21,6 +21,7 @@ SQLAlchemy models for Manila data.
 
 from oslo_config import cfg
 from oslo_db.sqlalchemy import models
+from oslo_log import log
 from sqlalchemy import Column, Integer, String, schema
 from sqlalchemy.ext.declarative import declarative_base
 from sqlalchemy import orm
@@ -31,6 +32,8 @@ from manila.common import constants
 CONF = cfg.CONF
 BASE = declarative_base()
 
+LOG = log.getLogger(__name__)
+
 
 class ManilaBase(models.ModelBase,
                  models.TimestampMixin,
@@ -233,9 +236,15 @@ class Share(BASE, ManilaBase):
         return all_export_locations
 
     def __getattr__(self, item):
-        proxified_properties = ('status', 'host', 'share_server_id',
-                                'share_network_id', 'availability_zone',
-                                'share_type_id', 'share_type')
+        deprecated_properties = ('host', 'share_server_id', 'share_network_id',
+                                 'availability_zone', 'share_type_id',
+                                 'share_type')
+        proxified_properties = ('status',) + deprecated_properties
+
+        if item in deprecated_properties:
+            msg = ("Property '%s' is deprecated. Please use appropriate "
+                   "property from share instance." % item)
+            LOG.warning(msg)
 
         if item in proxified_properties:
             return getattr(self.instance, item, None)
@@ -476,6 +485,7 @@ class ShareTypes(BASE, ManilaBase):
     id = Column(String(36), primary_key=True)
     deleted = Column(String(36), default='False')
     name = Column(String(255))
+    description = Column(String(255))
     is_public = Column(Boolean, default=True)
 
 
@@ -1210,6 +1220,13 @@ class Message(BASE, ManilaBase):
     deleted = Column(String(36), default='False')
 
 
+class BackendInfo(BASE, ManilaBase):
+    """Represent Backend Info."""
+    __tablename__ = "backend_info"
+    host = Column(String(255), primary_key=True)
+    info_hash = Column(String(255))
+
+
 def register_models():
     """Register Models and create metadata.
 
