@@ -23,6 +23,7 @@ import oslo_concurrency.opts
 import oslo_log._options
 import oslo_middleware.opts
 import oslo_policy.opts
+import oslo_service.sslutils
 
 import manila.api.common
 import manila.api.middleware.auth
@@ -30,7 +31,6 @@ import manila.common.config
 import manila.compute
 import manila.compute.nova
 import manila.coordination
-import manila.data.helper
 import manila.db.api
 import manila.db.base
 import manila.exception
@@ -70,6 +70,7 @@ import manila.share.drivers.hitachi.hsp.driver
 import manila.share.drivers.hpe.hpe_3par_driver
 import manila.share.drivers.huawei.huawei_nas
 import manila.share.drivers.ibm.gpfs
+import manila.share.drivers.infinidat.infinibox
 import manila.share.drivers.lvm
 import manila.share.drivers.maprfs.maprfs_native
 import manila.share.drivers.netapp.options
@@ -101,7 +102,6 @@ _global_opt_lists = [
     manila.common.config.global_opts,
     manila.compute._compute_opts,
     manila.coordination.coordination_opts,
-    manila.data.helper.data_helper_opts,
     manila.db.api.db_opts,
     [manila.db.base.db_driver_opt],
     manila.exception.exc_log_opts,
@@ -152,6 +152,9 @@ _global_opt_lists = [
     manila.share.drivers.hpe.hpe_3par_driver.HPE3PAR_OPTS,
     manila.share.drivers.huawei.huawei_nas.huawei_opts,
     manila.share.drivers.ibm.gpfs.gpfs_share_opts,
+    manila.share.drivers.infinidat.infinibox.infinidat_auth_opts,
+    manila.share.drivers.infinidat.infinibox.infinidat_connection_opts,
+    manila.share.drivers.infinidat.infinibox.infinidat_general_opts,
     manila.share.drivers.maprfs.maprfs_native.maprfs_native_share_opts,
     manila.share.drivers.lvm.share_opts,
     manila.share.drivers.netapp.options.netapp_proxy_opts,
@@ -196,6 +199,7 @@ _opts.extend(oslo_policy.opts.list_opts())
 _opts.extend(manila.network.neutron.api.list_opts())
 _opts.extend(manila.compute.nova.list_opts())
 _opts.extend(manila.volume.cinder.list_opts())
+_opts.extend(oslo_service.sslutils.list_opts())
 
 
 def list_opts():
