@@ -15,9 +15,9 @@
 #    under the License.
 
 """
-The FilterScheduler is for creating shares.
-You can customize this scheduler by specifying your own share Filters and
-Weighing Functions.
+The FilterScheduler is for scheduling of share and share group creation.
+You can customize this scheduler by specifying your own share/share group
+filters and weighing functions.
 """
 
 from oslo_config import cfg
@@ -25,7 +25,6 @@ from oslo_log import log
 
 from manila import exception
 from manila.i18n import _
-from manila.i18n import _LE, _LI
 from manila.scheduler.drivers import base
 from manila.scheduler import scheduler_options
 from manila.share import share_types
@@ -84,9 +83,6 @@ class FilterScheduler(base.Scheduler):
                                             request_spec,
                                             filter_properties)
 
-        if not weighed_host:
-            raise exception.NoValidHost(reason="")
-
         host = weighed_host.obj.host
         share_id = request_spec['share_id']
         snapshot_id = request_spec['snapshot_id']
@@ -112,11 +108,6 @@ class FilterScheduler(base.Scheduler):
         weighed_host = self._schedule_share(
             context, request_spec, filter_properties)
 
-        if not weighed_host:
-            msg = _('Failed to find a weighted host for scheduling share '
-                    'replica %s.')
-            raise exception.NoValidHost(reason=msg % share_replica_id)
-
         host = weighed_host.obj.host
 
         updated_share_replica = base.share_replica_update_db(
@@ -219,10 +210,15 @@ class FilterScheduler(base.Scheduler):
         hosts = self.host_manager.get_all_host_states_share(elevated)
 
         # Filter local hosts based on requirements ...
-        hosts = self.host_manager.get_filtered_hosts(hosts,
-                                                     filter_properties)
+        hosts, last_filter = self.host_manager.get_filtered_hosts(
+            hosts, filter_properties)
+
         if not hosts:
-            return None
+            msg = _('Failed to find a weighted host, the last executed filter'
+                    ' was %s.')
+            raise exception.NoValidHost(
+                reason=msg % last_filter,
+                detail_data={'last_filter': last_filter})
 
         LOG.debug("Filtered share %(hosts)s", {"hosts": hosts})
         # weighted_host = WeightedHost() ... the best
@@ -265,8 +261,8 @@ class FilterScheduler(base.Scheduler):
         if retry['num_attempts'] > max_attempts:
             msg = _("Exceeded max scheduling attempts %(max_attempts)d for "
                     "share %(share_id)s") % {
-                        "max_attempts": max_attempts,
-                        "share_id": share_id
+                "max_attempts": max_attempts,
+                "share_id": share_id
             }
             raise exception.NoValidHost(reason=msg)
 
@@ -285,12 +281,12 @@ class FilterScheduler(base.Scheduler):
             return  # no previously attempted hosts, skip
 
         last_host = hosts[-1]
-        LOG.error(_LE("Error scheduling %(share_id)s from last share-service: "
-                      "%(last_host)s : %(exc)s"), {
-                          "share_id": share_id,
-                          "last_host": last_host,
-                          "exc": "exc"
-        })
+        LOG.error("Error scheduling %(share_id)s from last share-service: "
+                  "%(last_host)s : %(exc)s", {
+                      "share_id": share_id,
+                      "last_host": last_host,
+                      "exc": "exc"
+                      })
 
     def populate_filter_properties_share(self, request_spec,
                                          filter_properties):
@@ -310,15 +306,15 @@ class FilterScheduler(base.Scheduler):
     def schedule_create_share_group(self, context, share_group_id,
                                     request_spec, filter_properties):
 
-        LOG.info(_LI("Scheduling share group %s.") % share_group_id)
+        LOG.info("Scheduling share group %s.", share_group_id)
         host = self._get_best_host_for_share_group(context, request_spec)
 
         if not host:
             msg = _("No hosts available for share group %s.") % share_group_id
             raise exception.NoValidHost(reason=msg)
 
-        msg = _LI("Chose host %(host)s for create_share_group %(group)s.")
-        LOG.info(msg % {'host': host, 'group': share_group_id})
+        msg = "Chose host %(host)s for create_share_group %(group)s."
+        LOG.info(msg, {'host': host, 'group': share_group_id})
 
         updated_share_group = base.share_group_update_db(
             context, share_group_id, host)
@@ -359,13 +355,13 @@ class FilterScheduler(base.Scheduler):
             'size': 0,
         }
         # Filter local hosts based on requirements ...
-        hosts = self.host_manager.get_filtered_hosts(all_hosts,
-                                                     filter_properties)
+        hosts, last_filter = self.host_manager.get_filtered_hosts(
+            all_hosts, filter_properties)
 
         if not hosts:
             return []
 
-        LOG.debug("Filtered %s" % hosts)
+        LOG.debug("Filtered %s", hosts)
 
         # weighted_host = WeightedHost() ... the best host for the job.
         weighed_hosts = self.host_manager.get_weighed_hosts(
@@ -392,13 +388,15 @@ class FilterScheduler(base.Scheduler):
             'resource_type': share_group_type,
         }
 
-        hosts = self.host_manager.get_filtered_hosts(
-            all_hosts, filter_properties)
+        hosts, last_filter = self.host_manager.get_filtered_hosts(
+            all_hosts,
+            filter_properties,
+            CONF.scheduler_default_share_group_filters)
 
         if not hosts:
             return []
 
-        LOG.debug("Filtered %s" % hosts)
+        LOG.debug("Filtered %s", hosts)
 
         weighed_hosts = self.host_manager.get_weighed_hosts(
             hosts,
@@ -470,13 +468,16 @@ class FilterScheduler(base.Scheduler):
             context, filter_properties, request_spec)
 
         hosts = self.host_manager.get_all_host_states_share(elevated)
-        hosts = self.host_manager.get_filtered_hosts(hosts, filter_properties)
+        hosts, last_filter = self.host_manager.get_filtered_hosts(
+            hosts, filter_properties)
         hosts = self.host_manager.get_weighed_hosts(hosts, filter_properties)
 
         for tgt_host in hosts:
             if tgt_host.obj.host == host:
                 return tgt_host.obj
 
-        msg = (_('Cannot place share %(id)s on %(host)s')
-               % {'id': request_spec['share_id'], 'host': host})
+        msg = (_('Cannot place share %(id)s on %(host)s, the last executed'
+                 ' filter was %(last_filter)s.')
+               % {'id': request_spec['share_id'], 'host': host,
+                  'last_filter': last_filter})
         raise exception.NoValidHost(reason=msg)
