@@ -14,11 +14,13 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-
+from oslo_log import log
 from oslo_utils import strutils
 
 from manila.scheduler.filters import extra_specs_ops
 
+LOG = log.getLogger(__name__)
+
 
 def generate_stats(host_state, properties):
     """Generates statistics from host and share data."""
@@ -38,16 +40,23 @@ def generate_stats(host_state, properties):
             host_state.driver_handles_share_servers,
         'thin_provisioning': host_state.thin_provisioning,
         'updated': host_state.updated,
-        'consistency_group_support': host_state.consistency_group_support,
         'dedupe': host_state.dedupe,
         'compression': host_state.compression,
         'snapshot_support': host_state.snapshot_support,
+        'create_share_from_snapshot_support':
+            host_state.create_share_from_snapshot_support,
+        'revert_to_snapshot_support': host_state.revert_to_snapshot_support,
+        'mount_snapshot_support': host_state.mount_snapshot_support,
         'replication_domain': host_state.replication_domain,
         'replication_type': host_state.replication_type,
         'provisioned_capacity_gb': host_state.provisioned_capacity_gb,
         'pools': host_state.pools,
         'max_over_subscription_ratio':
             host_state.max_over_subscription_ratio,
+        'sg_consistent_snapshot_support': (
+            host_state.sg_consistent_snapshot_support),
+        'ipv4_support': host_state.ipv4_support,
+        'ipv6_support': host_state.ipv6_support,
     }
 
     host_caps = host_state.capabilities
@@ -55,15 +64,20 @@ def generate_stats(host_state, properties):
     share_type = properties.get('share_type', {})
     extra_specs = share_type.get('extra_specs', {})
 
+    share_group_type = properties.get('share_group_type', {})
+    group_specs = share_group_type.get('group_specs', {})
+
     request_spec = properties.get('request_spec', {})
     share_stats = request_spec.get('resource_properties', {})
 
     stats = {
         'host_stats': host_stats,
         'host_caps': host_caps,
+        'share_type': share_type,
         'extra_specs': extra_specs,
         'share_stats': share_stats,
-        'share_type': share_type,
+        'share_group_type': share_group_type,
+        'group_specs': group_specs,
     }
 
     return stats
@@ -111,3 +125,45 @@ def thin_provisioning(host_state_thin_provisioning):
     thin_capability = [host_state_thin_provisioning] if not isinstance(
         host_state_thin_provisioning, list) else host_state_thin_provisioning
     return True in thin_capability
+
+
+def capabilities_satisfied(capabilities, extra_specs):
+
+    for key, req in extra_specs.items():
+        # Either not scoped format, or in capabilities scope
+        scope = key.split(':')
+
+        # Ignore scoped (such as vendor-specific) capabilities
+        if len(scope) > 1 and scope[0] != "capabilities":
+            continue
+        # Strip off prefix if spec started with 'capabilities:'
+        elif scope[0] == "capabilities":
+            del scope[0]
+
+        cap = capabilities
+        for index in range(len(scope)):
+            try:
+                cap = cap.get(scope[index])
+            except AttributeError:
+                cap = None
+            if cap is None:
+                LOG.debug("Host doesn't provide capability '%(cap)s' "
+                          "listed in the extra specs",
+                          {'cap': scope[index]})
+                return False
+
+        # Make all capability values a list so we can handle lists
+        cap_list = [cap] if not isinstance(cap, list) else cap
+
+        # Loop through capability values looking for any match
+        for cap_value in cap_list:
+            if extra_specs_ops.match(cap_value, req):
+                break
+        else:
+            # Nothing matched, so bail out
+            LOG.debug('Share type extra spec requirement '
+                      '"%(key)s=%(req)s" does not match reported '
+                      'capability "%(cap)s"',
+                      {'key': key, 'req': req, 'cap': cap})
+            return False
+    return True
