@@ -370,7 +370,7 @@ class WSGIService(service.ServiceBase):
 
 
 def process_launcher():
-    return service.ProcessLauncher(CONF)
+    return service.ProcessLauncher(CONF, restart_method='mutate')
 
 
 # NOTE(vish): the global launcher is to maintain the existing
@@ -387,7 +387,18 @@ def serve(server, workers=None):
 
 
 def wait():
-    CONF.log_opt_values(LOG, log.DEBUG)
+    LOG.debug('Full set of CONF:')
+    for flag in CONF:
+        flag_get = CONF.get(flag, None)
+        # hide flag contents from log if contains a password
+        # should use secret flag when switch over to openstack-common
+        if ("_password" in flag or "_key" in flag or
+                (flag == "transport_url" and "rabbit:" in flag_get) or
+                (flag == "sql_connection" and "mysql:" in flag_get)):
+            LOG.debug('%(flag)s : FLAG SET ', {"flag": flag})
+        else:
+            LOG.debug('%(flag)s : %(flag_get)s',
+                      {"flag": flag, "flag_get": flag_get})
     try:
         _launcher.wait()
     except KeyboardInterrupt:
