@@ -14,13 +14,16 @@
 #    under the License.
 
 import copy
+import ipaddress
 
 from oslo_log import log
 
 from manila.common import constants
-from manila.i18n import _, _LI
+from manila.i18n import _
 from manila import utils
 
+import six
+
 LOG = log.getLogger(__name__)
 
 
@@ -370,6 +373,13 @@ class ShareInstanceAccess(ShareInstanceAccessDatabaseMixin):
                                            rules_to_be_removed_from_db,
                                            share_server):
         driver_rule_updates = {}
+        share_protocol = share_instance['share_proto'].lower()
+        if (not self.driver.ipv6_implemented and
+                share_protocol == 'nfs'):
+            add_rules = self._filter_ipv6_rules(add_rules)
+            delete_rules = self._filter_ipv6_rules(delete_rules)
+            access_rules_to_be_on_share = self._filter_ipv6_rules(
+                access_rules_to_be_on_share)
         try:
             driver_rule_updates = self.driver.update_access(
                 context,
@@ -459,6 +469,18 @@ class ShareInstanceAccess(ShareInstanceAccessDatabaseMixin):
 
         return access_rules_to_be_on_share
 
+    @staticmethod
+    def _filter_ipv6_rules(rules):
+        filtered = []
+        for rule in rules:
+            if rule['access_type'] == 'ip':
+                ip_version = ipaddress.ip_network(
+                    six.text_type(rule['access_to'])).version
+                if 6 == ip_version:
+                    continue
+            filtered.append(rule)
+        return filtered
+
     def _get_rules_to_send_to_driver(self, context, share_instance):
         add_rules = []
         delete_rules = []
@@ -472,6 +494,7 @@ class ShareInstanceAccess(ShareInstanceAccessDatabaseMixin):
             share_instance_id=share_instance['id'])
         # Update queued rules to transitional states
         for rule in existing_rules_in_db:
+
             if rule['state'] == constants.ACCESS_STATE_APPLYING:
                 add_rules.append(rule)
             elif rule['state'] == constants.ACCESS_STATE_DENYING:
@@ -493,8 +516,8 @@ class ShareInstanceAccess(ShareInstanceAccessDatabaseMixin):
                                 remove_rules, share_instance, share_server):
         for rule in add_rules:
             LOG.info(
-                _LI("Applying access rule '%(rule)s' for share "
-                    "instance '%(instance)s'"),
+                "Applying access rule '%(rule)s' for share "
+                "instance '%(instance)s'",
                 {'rule': rule['id'], 'instance': share_instance['id']}
             )
 
@@ -511,8 +534,8 @@ class ShareInstanceAccess(ShareInstanceAccessDatabaseMixin):
 
         for rule in delete_rules:
             LOG.info(
-                _LI("Denying access rule '%(rule)s' from share "
-                    "instance '%(instance)s'"),
+                "Denying access rule '%(rule)s' from share "
+                "instance '%(instance)s'",
                 {'rule': rule['id'], 'instance': share_instance['id']}
             )
 
