@@ -27,7 +27,7 @@ from oslo_log import log
 from oslo_utils import importutils
 
 from manila import exception
-from manila.i18n import _, _LI, _LW
+from manila.i18n import _
 from manila.share import driver
 from manila import utils
 
@@ -117,7 +117,7 @@ class ContainerShareDriver(driver.ShareDriver, driver.ExecuteMixin):
         super(ContainerShareDriver, self)._update_share_stats(data)
 
     def create_share(self, context, share, share_server=None):
-        LOG.debug("Create share on server '%s'." % share_server["id"])
+        LOG.debug("Create share on server '%s'.", share_server["id"])
         server_id = self._get_container_name(share_server["id"])
         share_name = share.share_id
         self.container.execute(
@@ -135,7 +135,7 @@ class ContainerShareDriver(driver.ShareDriver, driver.ExecuteMixin):
 
     @utils.synchronized('container_driver_delete_share_lock', external=True)
     def delete_share(self, context, share, share_server=None):
-        LOG.debug("Deleting share %(share)s on server '%(server)s'." %
+        LOG.debug("Deleting share %(share)s on server '%(server)s'.",
                   {"server": share_server["id"],
                    "share": share.share_id})
         server_id = self._get_container_name(share_server["id"])
@@ -156,9 +156,9 @@ class ContainerShareDriver(driver.ShareDriver, driver.ExecuteMixin):
                 ["rm", "-fR", "/shares/%s" % share.share_id]
             )
         except exception.ProcessExecutionError as e:
-            LOG.warning(_LW("Failed to remove /shares/%(share)s directory in "
-                            "container %(cont)s."), {"share": share.share_id,
-                                                     "cont": server_id})
+            LOG.warning("Failed to remove /shares/%(share)s directory in "
+                        "container %(cont)s.", {"share": share.share_id,
+                                                "cont": server_id})
             LOG.error(e)
 
         self.storage.remove_storage(share)
@@ -213,8 +213,8 @@ class ContainerShareDriver(driver.ShareDriver, driver.ExecuteMixin):
                     "specified.") % neutron_class
             raise exception.ManilaException(msg)
         elif host_id is None:
-            LOG.warning(_LW("neutron_host_id is not specified. This driver "
-                            "might not work as expected without it."))
+            LOG.warning("neutron_host_id is not specified. This driver "
+                        "might not work as expected without it.")
 
     def _connect_to_network(self, server_id, network_info, host_veth):
         LOG.debug("Attempting to connect container to neutron network.")
@@ -235,6 +235,7 @@ class ContainerShareDriver(driver.ShareDriver, driver.ExecuteMixin):
             'lb': self.configuration.container_linux_bridge_name,
             'ovsb': self.configuration.container_ovs_bridge_name,
             'ip': port_address,
+            'network': network_info['neutron_net_id'],
             'subnet': network_info['neutron_subnet_id'],
         }
         LOG.debug("Container %(id)s veth is %(veth)s.", msg_helper)
@@ -254,7 +255,8 @@ class ContainerShareDriver(driver.ShareDriver, driver.ExecuteMixin):
                       self.configuration.container_ovs_bridge_name, host_veth,
                       *(e_mac + e_id + e_status + e_mcid), run_as_root=True)
         LOG.debug("Now container %(id)s should be accessible from network "
-                  "%(subnet)s by address %(ip)s." % msg_helper)
+                  "%(network)s and subnet %(subnet)s by address %(ip)s.",
+                  msg_helper)
 
     @utils.synchronized("container_driver_teardown_lock", external=True)
     def _teardown_server(self, *args, **kwargs):
@@ -278,8 +280,8 @@ class ContainerShareDriver(driver.ShareDriver, driver.ExecuteMixin):
                                   self.configuration.container_ovs_bridge_name,
                                   veth, run_as_root=True)
                 except exception.ProcessExecutionError as e:
-                    LOG.warning(_LW("Failed to delete port %s: port "
-                                    "vanished."), veth)
+                    LOG.warning("Failed to delete port %s: port "
+                                "vanished.", veth)
                     LOG.error(e)
 
     def _get_veth_state(self):
@@ -303,7 +305,7 @@ class ContainerShareDriver(driver.ShareDriver, driver.ExecuteMixin):
     def _setup_server(self, network_info, metadata=None):
         msg = "Creating share server '%s'."
         server_id = self._get_container_name(network_info["server_id"])
-        LOG.debug(msg % server_id)
+        LOG.debug(msg, server_id)
 
         veths_before = self._get_veth_state()
         try:
@@ -315,5 +317,5 @@ class ContainerShareDriver(driver.ShareDriver, driver.ExecuteMixin):
 
         veth = self._get_corresponding_veth(veths_before, veths_after)
         self._connect_to_network(server_id, network_info, veth)
-        LOG.info(_LI("Container %s was created."), server_id)
+        LOG.info("Container %s was created.", server_id)
         return {"id": network_info["server_id"]}
