@@ -30,8 +30,8 @@ EMC_NAS_OPTS = [
                help='User name for the EMC server.'),
     cfg.StrOpt('emc_nas_password',
                help='Password for the EMC server.'),
-    cfg.StrOpt('emc_nas_server',
-               help='EMC server hostname or IP address.'),
+    cfg.HostAddressOpt('emc_nas_server',
+                       help='EMC server hostname or IP address.'),
     cfg.PortOpt('emc_nas_server_port',
                 default=8080,
                 help='Port number for the EMC server.'),
@@ -43,7 +43,15 @@ EMC_NAS_OPTS = [
                choices=['isilon', 'vnx', 'unity', 'vmax'],
                help='Share backend.'),
     cfg.StrOpt('emc_nas_root_dir',
-               help='The root directory where shares will be located.')
+               help='The root directory where shares will be located.'),
+    cfg.BoolOpt('emc_ssl_cert_verify',
+                default=True,
+                help='If set to False the https client will not validate the '
+                     'SSL certificate of the backend endpoint.'),
+    cfg.StrOpt('emc_ssl_cert_path',
+               help='Can be used to specify a non default path to a '
+                    'CA_BUNDLE file or directory with certificates of trusted '
+                    'CAs, which will be used to validate the backend.')
 ]
 
 CONF = cfg.CONF
@@ -70,6 +78,9 @@ class EMCShareDriver(driver.ShareDriver):
         super(EMCShareDriver, self).__init__(
             self.plugin.driver_handles_share_servers, *args, **kwargs)
 
+        if hasattr(self.plugin, 'ipv6_implemented'):
+            self.ipv6_implemented = self.plugin.ipv6_implemented
+
     def create_share(self, context, share, share_server=None):
         """Is called to create share."""
         location = self.plugin.create_share(context, share, share_server)
@@ -112,6 +123,12 @@ class EMCShareDriver(driver.ShareDriver):
         """Deny access to the share."""
         self.plugin.deny_access(context, share, access, share_server)
 
+    def update_access(self, context, share, access_rules, add_rules,
+                      delete_rules, share_server=None):
+        """Update access to the share."""
+        self.plugin.update_access(context, share, access_rules, add_rules,
+                                  delete_rules, share_server)
+
     def check_for_setup_error(self):
         """Check for setup error."""
         self.plugin.check_for_setup_error()
@@ -145,3 +162,9 @@ class EMCShareDriver(driver.ShareDriver):
     def _teardown_server(self, server_details, security_services=None):
         """Teardown share server."""
         return self.plugin.teardown_server(server_details, security_services)
+
+    def get_configured_ip_versions(self):
+        if self.ipv6_implemented:
+            return [4, 6]
+        else:
+            return [4]
