@@ -20,6 +20,7 @@ import sys
 
 from oslo_log import log
 from oslo_serialization import jsonutils
+from oslo_utils import importutils
 import six
 
 from manila import exception
@@ -204,6 +205,19 @@ def mkconf(confdict):
     return s.getvalue()
 
 
+rados = None
+
+
+def setup_rados():
+    global rados
+    if not rados:
+        try:
+            rados = importutils.import_module('rados')
+        except ImportError:
+            raise exception.ShareBackendException(
+                _("python-rados is not installed"))
+
+
 class GaneshaManager(object):
     """Ganesha instrumentation class."""
 
@@ -227,30 +241,54 @@ class GaneshaManager(object):
                     stdout=e.stdout, stderr=e.stderr, exit_code=e.exit_code,
                     cmd=e.cmd)
         self.execute = _execute
+        self.ganesha_service = kwargs['ganesha_service_name']
         self.ganesha_export_dir = kwargs['ganesha_export_dir']
         self.execute('mkdir', '-p', self.ganesha_export_dir)
-        self.ganesha_db_path = kwargs['ganesha_db_path']
-        self.execute('mkdir', '-p', os.path.dirname(self.ganesha_db_path))
-        self.ganesha_service = kwargs['ganesha_service_name']
-        # Here we are to make sure that an SQLite database of the
-        # required scheme exists at self.ganesha_db_path.
-        # The following command gets us there -- provided the file
-        # does not yet exist (otherwise it just fails). However,
-        # we don't care about this condition, we just execute the
-        # command unconditionally (ignoring failure). Instead we
-        # directly query the db right after, to check its validity.
-        self.execute("sqlite3", self.ganesha_db_path,
-                     'create table ganesha(key varchar(20) primary key, '
-                     'value int); insert into ganesha values("exportid", '
-                     '100);', run_as_root=False, check_exit_code=False)
-        self.get_export_id(bump=False)
+
+        self.ganesha_rados_store_enable = kwargs.get(
+            'ganesha_rados_store_enable')
+        if self.ganesha_rados_store_enable:
+            setup_rados()
+            self.ganesha_rados_store_pool_name = (
+                kwargs['ganesha_rados_store_pool_name'])
+            self.ganesha_rados_export_counter = (
+                kwargs['ganesha_rados_export_counter'])
+            self.ganesha_rados_export_index = (
+                kwargs['ganesha_rados_export_index'])
+            self.ceph_vol_client = (
+                kwargs['ceph_vol_client'])
+            try:
+                self._get_rados_object(self.ganesha_rados_export_counter)
+            except rados.ObjectNotFound:
+                self._put_rados_object(self.ganesha_rados_export_counter,
+                                       six.text_type(1000))
+        else:
+            self.ganesha_db_path = kwargs['ganesha_db_path']
+            self.execute('mkdir', '-p', os.path.dirname(self.ganesha_db_path))
+            # Here we are to make sure that an SQLite database of the
+            # required scheme exists at self.ganesha_db_path.
+            # The following command gets us there -- provided the file
+            # does not yet exist (otherwise it just fails). However,
+            # we don't care about this condition, we just execute the
+            # command unconditionally (ignoring failure). Instead we
+            # directly query the db right after, to check its validity.
+            self.execute(
+                "sqlite3", self.ganesha_db_path,
+                'create table ganesha(key varchar(20) primary key, '
+                'value int); insert into ganesha values("exportid", '
+                '100);', run_as_root=False, check_exit_code=False)
+            self.get_export_id(bump=False)
 
     def _getpath(self, name):
         """Get the path of config file for name."""
         return os.path.join(self.ganesha_export_dir, name + ".conf")
 
-    def _write_file(self, path, data):
-        """Write data to path atomically."""
+    @staticmethod
+    def _get_export_rados_object_name(name):
+        return 'ganesha-export-' + name
+
+    def _write_tmp_conf_file(self, path, data):
+        """Write data to tmp conf file."""
         dirpath, fname = (getattr(os.path, q + "name")(path) for q in
                           ("dir", "base"))
         tmpf = self.execute('mktemp', '-p', dirpath, "-t",
@@ -259,12 +297,18 @@ class GaneshaManager(object):
             'sh', '-c',
             'echo %s > %s' % (pipes.quote(data), pipes.quote(tmpf)),
             message='writing ' + tmpf)
-        self.execute('mv', tmpf, path)
+        return tmpf
 
     def _write_conf_file(self, name, data):
         """Write data to config file for name atomically."""
         path = self._getpath(name)
-        self._write_file(path, data)
+        tmpf = self._write_tmp_conf_file(path, data)
+        try:
+            self.execute('mv', tmpf, path)
+        except exception.ProcessExecutionError:
+            LOG.error('mv temp file ({0}) to {1} failed.'.format(tmpf, path))
+            self.execute('rm', tmpf)
+            raise
         return path
 
     def _mkindex(self):
@@ -280,15 +324,32 @@ class GaneshaManager(object):
             self._write_conf_file("INDEX", index)
         _mkindex()
 
+    def _read_export_rados_object(self, name):
+        return parseconf(self._get_rados_object(
+            self._get_export_rados_object_name(name)))
+
     def _read_export_file(self, name):
-        """Return the dict of the export identified by name."""
         return parseconf(self.execute("cat", self._getpath(name),
                                       message='reading export ' + name)[0])
 
-    def _check_export_file_exists(self, name):
-        """Check whether export exists."""
+    def _read_export(self, name):
+        """Return the dict of the export identified by name."""
+        if self.ganesha_rados_store_enable:
+            return self._read_export_rados_object(name)
+        else:
+            return self._read_export_file(name)
+
+    def _check_export_rados_object_exists(self, name):
         try:
-            self.execute('test', '-f', self._getpath(name), makelog=False,
+            self._get_rados_object(
+                self._get_export_rados_object_name(name))
+            return True
+        except rados.ObjectNotFound:
+            return False
+
+    def _check_file_exists(self, path):
+        try:
+            self.execute('test', '-f', path, makelog=False,
                          run_as_root=False)
             return True
         except exception.GaneshaCommandFailure as e:
@@ -297,8 +358,25 @@ class GaneshaManager(object):
             else:
                 raise
 
-    def _write_export_file(self, name, confdict):
-        """Write confdict to the export file of name."""
+    def _check_export_file_exists(self, name):
+        return self._check_file_exists(self._getpath(name))
+
+    def check_export_exists(self, name):
+        """Check whether export exists."""
+        if self.ganesha_rados_store_enable:
+            return self._check_export_rados_object_exists(name)
+        else:
+            return self._check_export_file_exists(name)
+
+    def _write_export_rados_object(self, name, data):
+        """Write confdict to the export RADOS object of name."""
+        self._put_rados_object(self._get_export_rados_object_name(name),
+                               data)
+        # temp export config file required for DBus calls
+        return self._write_tmp_conf_file(self._getpath(name), data)
+
+    def _write_export(self, name, confdict):
+        """Write confdict to the export file or RADOS object of name."""
         for k, v in ganesha_utils.walk(confdict):
             # values in the export block template that need to be
             # filled in by Manila are pre-fixed by '@'
@@ -306,11 +384,21 @@ class GaneshaManager(object):
                 msg = _("Incomplete export block: value %(val)s of attribute "
                         "%(key)s is a stub.") % {'key': k, 'val': v}
                 raise exception.InvalidParameterValue(err=msg)
-        return self._write_conf_file(name, mkconf(confdict))
+        if self.ganesha_rados_store_enable:
+            return self._write_export_rados_object(name, mkconf(confdict))
+        else:
+            return self._write_conf_file(name, mkconf(confdict))
+
+    def _rm_file(self, path):
+        self.execute("rm", "-f", path)
 
     def _rm_export_file(self, name):
         """Remove export file of name."""
-        self.execute("rm", self._getpath(name))
+        self._rm_file(self._getpath(name))
+
+    def _rm_export_rados_object(self, name):
+        """Remove export object of name."""
+        self._delete_rados_object(self._get_export_rados_object_name(name))
 
     def _dbus_send_ganesha(self, method, *args, **kwargs):
         """Send a message to Ganesha via dbus."""
@@ -324,70 +412,158 @@ class GaneshaManager(object):
         """Remove an export from Ganesha runtime with given export id."""
         self._dbus_send_ganesha("RemoveExport", "uint16:%d" % xid)
 
+    def _add_rados_object_url_to_index(self, name):
+        """Add an export RADOS object's URL to the RADOS URL index."""
+
+        # TODO(rraja): Ensure that the export index object's update is atomic,
+        # e.g., retry object update until the object version between the 'get'
+        # and 'put' operations remains the same.
+        index_data = self._get_rados_object(self.ganesha_rados_export_index)
+
+        want_url = "%url rados://{0}/{1}".format(
+            self.ganesha_rados_store_pool_name,
+            self._get_export_rados_object_name(name))
+
+        if index_data:
+            self._put_rados_object(
+                self.ganesha_rados_export_index,
+                '\n'.join([index_data, want_url])
+            )
+        else:
+            self._put_rados_object(self.ganesha_rados_export_index, want_url)
+
+    def _remove_rados_object_url_from_index(self, name):
+        """Remove an export RADOS object's URL from the RADOS URL index."""
+
+        # TODO(rraja): Ensure that the export index object's update is atomic,
+        # e.g., retry object update until the object version between the 'get'
+        # and 'put' operations remains the same.
+        index_data = self._get_rados_object(self.ganesha_rados_export_index)
+        if not index_data:
+            return
+
+        unwanted_url = "%url rados://{0}/{1}".format(
+            self.ganesha_rados_store_pool_name,
+            self._get_export_rados_object_name(name))
+
+        rados_urls = index_data.split('\n')
+        new_rados_urls = [url for url in rados_urls if url != unwanted_url]
+
+        self._put_rados_object(self.ganesha_rados_export_index,
+                               '\n'.join(new_rados_urls))
+
     def add_export(self, name, confdict):
         """Add an export to Ganesha specified by confdict."""
         xid = confdict["EXPORT"]["Export_Id"]
         undos = []
         _mkindex_called = False
         try:
-            path = self._write_export_file(name, confdict)
-            undos.append(lambda: self._rm_export_file(name))
+            path = self._write_export(name, confdict)
+            if self.ganesha_rados_store_enable:
+                undos.append(lambda: self._rm_export_rados_object(name))
+                undos.append(lambda: self._rm_file(path))
+            else:
+                undos.append(lambda: self._rm_export_file(name))
 
             self._dbus_send_ganesha("AddExport", "string:" + path,
                                     "string:EXPORT(Export_Id=%d)" % xid)
             undos.append(lambda: self._remove_export_dbus(xid))
 
-            _mkindex_called = True
-            self._mkindex()
+            if self.ganesha_rados_store_enable:
+                # Clean up temp export file used for the DBus call
+                self._rm_file(path)
+                self._add_rados_object_url_to_index(name)
+            else:
+                _mkindex_called = True
+                self._mkindex()
         except Exception:
             for u in undos:
                 u()
-            if not _mkindex_called:
+            if not self.ganesha_rados_store_enable and not _mkindex_called:
                 self._mkindex()
             raise
 
     def update_export(self, name, confdict):
         """Update an export to Ganesha specified by confdict."""
         xid = confdict["EXPORT"]["Export_Id"]
-        old_confdict = self._read_export_file(name)
+        old_confdict = self._read_export(name)
 
-        path = self._write_export_file(name, confdict)
+        path = self._write_export(name, confdict)
         try:
             self._dbus_send_ganesha("UpdateExport", "string:" + path,
                                     "string:EXPORT(Export_Id=%d)" % xid)
         except Exception:
-            # Revert the export file update.
-            self._write_export_file(name, old_confdict)
+            # Revert the export update.
+            self._write_export(name, old_confdict)
             raise
+        finally:
+            if self.ganesha_rados_store_enable:
+                # Clean up temp export file used for the DBus update call
+                self._rm_file(path)
 
     def remove_export(self, name):
         """Remove an export from Ganesha."""
         try:
-            confdict = self._read_export_file(name)
+            confdict = self._read_export(name)
             self._remove_export_dbus(confdict["EXPORT"]["Export_Id"])
         finally:
-            self._rm_export_file(name)
-            self._mkindex()
+            if self.ganesha_rados_store_enable:
+                self._delete_rados_object(
+                    self._get_export_rados_object_name(name))
+                self._remove_rados_object_url_from_index(name)
+            else:
+                self._rm_export_file(name)
+                self._mkindex()
+
+    def _get_rados_object(self, obj_name):
+        """Get data stored in Ceph RADOS object as a text string."""
+        return self.ceph_vol_client.get_object(
+            self.ganesha_rados_store_pool_name, obj_name).decode('utf-8')
+
+    def _put_rados_object(self, obj_name, data):
+        """Put data as a byte string in a Ceph RADOS object."""
+        return self.ceph_vol_client.put_object(
+            self.ganesha_rados_store_pool_name,
+            obj_name,
+            data.encode('utf-8'))
+
+    def _delete_rados_object(self, obj_name):
+        return self.ceph_vol_client.delete_object(
+            self.ganesha_rados_store_pool_name,
+            obj_name)
 
     def get_export_id(self, bump=True):
         """Get a new export id."""
         # XXX overflowing the export id (16 bit unsigned integer)
         # is not handled
-        if bump:
-            bumpcode = 'update ganesha set value = value + 1;'
+        if self.ganesha_rados_store_enable:
+            # TODO(rraja): Ensure that the export counter object's update is
+            # atomic, e.g., retry object update until the object version
+            # between the 'get' and 'put' operations remains the same.
+            export_id = int(
+                self._get_rados_object(self.ganesha_rados_export_counter))
+            if not bump:
+                return export_id
+            export_id += 1
+            self._put_rados_object(self.ganesha_rados_export_counter,
+                                   str(export_id))
+            return export_id
         else:
-            bumpcode = ''
-        out = self.execute(
-            "sqlite3", self.ganesha_db_path,
-            bumpcode + 'select * from ganesha where key = "exportid";',
-            run_as_root=False)[0]
-        match = re.search('\Aexportid\|(\d+)$', out)
-        if not match:
-            LOG.error("Invalid export database on "
-                      "Ganesha node %(tag)s: %(db)s.",
-                      {'tag': self.tag, 'db': self.ganesha_db_path})
-            raise exception.InvalidSqliteDB()
-        return int(match.groups()[0])
+            if bump:
+                bumpcode = 'update ganesha set value = value + 1;'
+            else:
+                bumpcode = ''
+            out = self.execute(
+                "sqlite3", self.ganesha_db_path,
+                bumpcode + 'select * from ganesha where key = "exportid";',
+                run_as_root=False)[0]
+            match = re.search('\Aexportid\|(\d+)$', out)
+            if not match:
+                LOG.error("Invalid export database on "
+                          "Ganesha node %(tag)s: %(db)s.",
+                          {'tag': self.tag, 'db': self.ganesha_db_path})
+                raise exception.InvalidSqliteDB()
+            return int(match.groups()[0])
 
     def restart_service(self):
         """Restart the Ganesha service."""
