@@ -285,19 +285,16 @@ class GenericShareDriver(driver.ExecuteMixin, driver.ShareDriver):
                     return True
         return False
 
-    def _add_mount_permanently(self, share_id, server_details):
-        """Add mount permanently for mounted filesystems."""
+    def _sync_mount_temp_and_perm_files(self, server_details):
+        """Sync temporary and permanent files for mounted filesystems."""
         try:
             self._ssh_exec(
                 server_details,
-                ['grep', share_id, const.MOUNT_FILE_TEMP,
-                 '|', 'sudo', 'tee', '-a', const.MOUNT_FILE],
+                ['sudo', 'cp', const.MOUNT_FILE_TEMP, const.MOUNT_FILE],
             )
         except exception.ProcessExecutionError as e:
-            LOG.error("Failed to add 'Share-%(share_id)s' mount "
-                      "permanently on server '%(instance_id)s'.",
-                      {"share_id": share_id,
-                       "instance_id": server_details['instance_id']})
+            LOG.error("Failed to sync mount files on server '%s'.",
+                      server_details['instance_id'])
             raise exception.ShareBackendException(msg=six.text_type(e))
         try:
             # Remount it to avoid postponed point of failure
@@ -305,20 +302,6 @@ class GenericShareDriver(driver.ExecuteMixin, driver.ShareDriver):
         except exception.ProcessExecutionError as e:
             LOG.error("Failed to mount all shares on server '%s'.",
                       server_details['instance_id'])
-
-    def _remove_mount_permanently(self, share_id, server_details):
-        """Remove mount permanently from mounted filesystems."""
-        try:
-            self._ssh_exec(
-                server_details,
-                ['sudo', 'sed', '-i', '\'/%s/d\'' % share_id,
-                 const.MOUNT_FILE],
-            )
-        except exception.ProcessExecutionError as e:
-            LOG.error("Failed to remove 'Share-%(share_id)s' mount "
-                      "permanently on server '%(instance_id)s'.",
-                      {"share_id": share_id,
-                       "instance_id": server_details['instance_id']})
             raise exception.ShareBackendException(msg=six.text_type(e))
 
     def _mount_device(self, share, server_details, volume):
@@ -359,7 +342,9 @@ class GenericShareDriver(driver.ExecuteMixin, driver.ShareDriver):
                         '&&', 'sudo', 'mount', device_path, mount_path,
                     )
                     self._ssh_exec(server_details, mount_cmd)
-                    self._add_mount_permanently(share.id, server_details)
+
+                    # Add mount permanently
+                    self._sync_mount_temp_and_perm_files(server_details)
                 else:
                     LOG.warning("Mount point '%(path)s' already exists on "
                                 "server '%(server)s'.", log_data)
@@ -385,7 +370,8 @@ class GenericShareDriver(driver.ExecuteMixin, driver.ShareDriver):
                 unmount_cmd = ['sudo', 'umount', mount_path, '&&', 'sudo',
                                'rmdir', mount_path]
                 self._ssh_exec(server_details, unmount_cmd)
-                self._remove_mount_permanently(share.id, server_details)
+                # Remove mount permanently
+                self._sync_mount_temp_and_perm_files(server_details)
             else:
                 LOG.warning("Mount point '%(path)s' does not exist on "
                             "server '%(server)s'.", log_data)
@@ -425,7 +411,7 @@ class GenericShareDriver(driver.ExecuteMixin, driver.ShareDriver):
                 volume = self.volume_api.get(context, volume['id'])
                 if volume['status'] == 'in-use':
                     return volume
-                elif volume['status'] != 'attaching':
+                elif volume['status'] not in ('attaching', 'reserved'):
                     raise exception.ManilaException(
                         _('Failed to attach volume %s') % volume['id'])
                 time.sleep(1)
