@@ -23,17 +23,17 @@ import six
 
 from manila.common import constants
 from manila import exception
-from manila.i18n import _, _LI, _LW
+from manila.i18n import _
 from manila.share import driver
 from manila.share import utils
 
 LOG = log.getLogger(__name__)
 
 hitachi_hnas_opts = [
-    cfg.StrOpt('hitachi_hnas_ip',
-               deprecated_name='hds_hnas_ip',
-               help="HNAS management interface IP for communication "
-                    "between Manila controller and HNAS."),
+    cfg.HostAddressOpt('hitachi_hnas_ip',
+                       deprecated_name='hds_hnas_ip',
+                       help="HNAS management interface IP for communication "
+                            "between Manila controller and HNAS."),
     cfg.StrOpt('hitachi_hnas_user',
                deprecated_name='hds_hnas_user',
                help="HNAS username Base64 String in order to perform tasks "
@@ -46,11 +46,12 @@ hitachi_hnas_opts = [
     cfg.IntOpt('hitachi_hnas_evs_id',
                deprecated_name='hds_hnas_evs_id',
                help="Specify which EVS this backend is assigned to."),
-    cfg.StrOpt('hitachi_hnas_evs_ip',
-               deprecated_name='hds_hnas_evs_ip',
-               help="Specify IP for mounting shares."),
-    cfg.StrOpt('hitachi_hnas_admin_network_ip',
-               help="Specify IP for mounting shares in the Admin network."),
+    cfg.HostAddressOpt('hitachi_hnas_evs_ip',
+                       deprecated_name='hds_hnas_evs_ip',
+                       help="Specify IP for mounting shares."),
+    cfg.HostAddressOpt('hitachi_hnas_admin_network_ip',
+                       help="Specify IP for mounting shares in the Admin "
+                            "network."),
     cfg.StrOpt('hitachi_hnas_file_system_name',
                deprecated_name='hds_hnas_file_system_name',
                help="Specify file-system name for creating shares."),
@@ -59,10 +60,10 @@ hitachi_hnas_opts = [
                secret=True,
                help="RSA/DSA private key value used to connect into HNAS. "
                     "Required only if password is not provided."),
-    cfg.StrOpt('hitachi_hnas_cluster_admin_ip0',
-               deprecated_name='hds_hnas_cluster_admin_ip0',
-               help="The IP of the clusters admin node. Only set in HNAS "
-                    "multinode clusters."),
+    cfg.HostAddressOpt('hitachi_hnas_cluster_admin_ip0',
+                       deprecated_name='hds_hnas_cluster_admin_ip0',
+                       help="The IP of the clusters admin node. Only set in "
+                            "HNAS multinode clusters."),
     cfg.IntOpt('hitachi_hnas_stalled_job_timeout',
                deprecated_name='hds_hnas_stalled_job_timeout',
                default=30,
@@ -89,12 +90,15 @@ CONF.register_opts(hitachi_hnas_opts)
 class HitachiHNASDriver(driver.ShareDriver):
     """Manila HNAS Driver implementation.
 
-    1.0.0 - Initial Version.
-    2.0.0 - Refactoring, bugfixes, implemented Share Shrink and Update Access.
-    3.0.0 - New driver location, implemented support for CIFS protocol.
-    3.1.0 - Added admin network export location support.
-    4.0.0 - Added mountable snapshots, revert-to-snapshot and manage snapshots
-            features support.
+    Driver versions::
+
+        1.0.0 - Initial Version.
+        2.0.0 - Refactoring, bugfixes, implemented Share Shrink and
+                Update Access.
+        3.0.0 - New driver location, implemented support for CIFS protocol.
+        3.1.0 - Added admin network export location support.
+        4.0.0 - Added mountable snapshots, revert-to-snapshot and
+                manage snapshots features support.
     """
 
     def __init__(self, *args, **kwargs):
@@ -277,10 +281,10 @@ class HitachiHNASDriver(driver.ShareDriver):
 
         for rule in delete_rules:
             if rule['access_type'].lower() != 'user':
-                LOG.warning(_LW('Only USER access type is allowed for '
-                                'CIFS. %(entity_type)s '
-                                'provided %(share)s with '
-                                'protocol %(proto)s.'),
+                LOG.warning('Only USER access type is allowed for '
+                            'CIFS. %(entity_type)s '
+                            'provided %(share)s with '
+                            'protocol %(proto)s.',
                             {'entity_type': entity_type.capitalize(),
                              'share': share_or_snapshot['id'],
                              'proto': share_proto})
@@ -318,31 +322,45 @@ class HitachiHNASDriver(driver.ShareDriver):
             Example for NFS::
 
             [
+
               {
+
                 'path': '172.24.44.10:/shares/id',
                 'metadata': {},
                 'is_admin_only': False
+
               },
+
               {
+
                 'path': '192.168.0.10:/shares/id',
                 'metadata': {},
                 'is_admin_only': True
+
               }
+
             ]
 
             Example for CIFS::
 
             [
+
               {
+
                 'path': '\\172.24.44.10\id',
                 'metadata': {},
                 'is_admin_only': False
+
               },
+
               {
+
                 'path': '\\192.168.0.10\id',
                 'metadata': {},
                 'is_admin_only': True
+
               }
+
             ]
 
         """
@@ -394,7 +412,7 @@ class HitachiHNASDriver(driver.ShareDriver):
                    'snap_id': snapshot['id']})
 
         export_locations = self._create_snapshot(hnas_share_id, snapshot)
-        LOG.info(_LI("Snapshot %(id)s successfully created."),
+        LOG.info("Snapshot %(id)s successfully created.",
                  {'id': snapshot['id']})
 
         output = {
@@ -426,7 +444,7 @@ class HitachiHNASDriver(driver.ShareDriver):
         self._delete_snapshot(snapshot['share'],
                               hnas_share_id, hnas_snapshot_id)
 
-        LOG.info(_LI("Snapshot %(id)s successfully deleted."),
+        LOG.info("Snapshot %(id)s successfully deleted.",
                  {'id': snapshot['id']})
 
     def create_share_from_snapshot(self, context, share, snapshot,
@@ -445,31 +463,45 @@ class HitachiHNASDriver(driver.ShareDriver):
             Example for NFS::
 
             [
+
               {
+
                 'path': '172.24.44.10:/shares/id',
                 'metadata': {},
                 'is_admin_only': False
+
               },
+
               {
+
                 'path': '192.168.0.10:/shares/id',
                 'metadata': {},
                 'is_admin_only': True
+
               }
+
             ]
 
             Example for CIFS::
 
             [
+
               {
+
                 'path': '\\172.24.44.10\id',
                 'metadata': {},
                 'is_admin_only': False
+
               },
+
               {
+
                 'path': '\\192.168.0.10\id',
                 'metadata': {},
                 'is_admin_only': True
+
               }
+
             ]
 
         """
@@ -501,31 +533,45 @@ class HitachiHNASDriver(driver.ShareDriver):
             Example for NFS::
 
             [
+
               {
+
                 'path': '172.24.44.10:/shares/id',
                 'metadata': {},
                 'is_admin_only': False
+
               },
+
               {
+
                 'path': '192.168.0.10:/shares/id',
                 'metadata': {},
                 'is_admin_only': True
+
               }
+
             ]
 
             Example for CIFS::
 
             [
+
               {
+
                 'path': '\\172.24.44.10\id',
                 'metadata': {},
                 'is_admin_only': False
+
               },
+
               {
+
                 'path': '\\192.168.0.10\id',
                 'metadata': {},
                 'is_admin_only': True
+
               }
+
             ]
 
         """
@@ -553,8 +599,8 @@ class HitachiHNASDriver(driver.ShareDriver):
                   {'shr_id': share['id']})
 
         self._extend_share(hnas_share_id, share, new_size)
-        LOG.info(_LI("Share %(shr_id)s successfully extended to "
-                     "%(shr_size)s."),
+        LOG.info("Share %(shr_id)s successfully extended to "
+                 "%(shr_size)s.",
                  {'shr_id': share['id'],
                   'shr_size': six.text_type(new_size)})
 
@@ -594,7 +640,7 @@ class HitachiHNASDriver(driver.ShareDriver):
             'mount_snapshot_support': True,
         }
 
-        LOG.info(_LI("HNAS Capabilities: %(data)s."),
+        LOG.info("HNAS Capabilities: %(data)s.",
                  {'data': six.text_type(data)})
 
         super(HitachiHNASDriver, self)._update_share_stats(data)
@@ -610,37 +656,55 @@ class HitachiHNASDriver(driver.ShareDriver):
             Example for NFS::
 
             {
+
               'size': 10,
               'export_locations': [
+
                 {
+
                   'path': '172.24.44.10:/shares/id',
                   'metadata': {},
                   'is_admin_only': False
+
                 },
+
                 {
+
                   'path': '192.168.0.10:/shares/id',
                   'metadata': {},
                   'is_admin_only': True
+
                 }
+
               ]
+
             }
 
             Example for CIFS::
 
             {
+
               'size': 10,
               'export_locations': [
+
                 {
+
                   'path': '\\172.24.44.10\id',
                   'metadata': {},
                   'is_admin_only': False
+
                 },
+
                 {
+
                   'path': '\\192.168.0.10\id',
                   'metadata': {},
                   'is_admin_only': True
+
                 }
+
               ]
+
             }
 
         """
@@ -656,8 +720,8 @@ class HitachiHNASDriver(driver.ShareDriver):
 
         if share['share_proto'].lower() == 'nfs':
             # 10.0.0.1:/shares/example
-            LOG.info(_LI("Share %(shr_path)s will be managed with ID "
-                         "%(shr_id)s."),
+            LOG.info("Share %(shr_path)s will be managed with ID "
+                     "%(shr_id)s.",
                      {'shr_path': share['export_locations'][0]['path'],
                       'shr_id': share['id']})
 
@@ -701,8 +765,8 @@ class HitachiHNASDriver(driver.ShareDriver):
                   "Share ID %(share_id)s", {'hnas_id': hnas_share_id,
                                             'share_id': share['id']})
 
-        LOG.info(_LI("Share %(shr_path)s was successfully managed with ID "
-                     "%(shr_id)s."),
+        LOG.info("Share %(shr_path)s was successfully managed with ID "
+                 "%(shr_id)s.",
                  {'shr_path': share['export_locations'][0]['path'],
                   'shr_id': share['id']})
 
@@ -716,13 +780,13 @@ class HitachiHNASDriver(driver.ShareDriver):
         self.private_storage.delete(share['id'])
 
         if len(share['export_locations']) == 0:
-            LOG.info(_LI("The share with ID %(shr_id)s is no longer being "
-                         "managed."), {'shr_id': share['id']})
+            LOG.info("The share with ID %(shr_id)s is no longer being "
+                     "managed.", {'shr_id': share['id']})
         else:
-            LOG.info(_LI("The share with current path %(shr_path)s and ID "
-                         "%(shr_id)s is no longer being managed."),
+            LOG.info("The share with current path %(shr_path)s and ID "
+                     "%(shr_id)s is no longer being managed.",
                      {'shr_path': share['export_locations'][0]['path'],
-                         'shr_id': share['id']})
+                      'shr_id': share['id']})
 
     def shrink_share(self, share, new_size, share_server=None):
         """Shrinks a share to new size.
@@ -738,29 +802,31 @@ class HitachiHNASDriver(driver.ShareDriver):
                   {'shr_id': share['id']})
 
         self._shrink_share(hnas_share_id, share, new_size)
-        LOG.info(_LI("Share %(shr_id)s successfully shrunk to "
-                     "%(shr_size)sG."),
+        LOG.info("Share %(shr_id)s successfully shrunk to "
+                 "%(shr_size)sG.",
                  {'shr_id': share['id'],
                   'shr_size': six.text_type(new_size)})
 
-    def revert_to_snapshot(self, context, snapshot, access_rules,
-                           share_server=None):
+    def revert_to_snapshot(self, context, snapshot, share_access_rules,
+                           snapshot_access_rules, share_server=None):
         """Reverts a share to a given snapshot.
 
         :param context: The `context.RequestContext` object for the request
         :param snapshot: The snapshot to which the share is to be reverted to.
-        :param access_rules: List of all access rules for the affected share.
-            Not used by this driver.
+        :param share_access_rules: List of all access rules for the affected
+            share. Not used by this driver.
+        :param snapshot_access_rules: List of all access rules for the affected
+            snapshot. Not used by this driver.
         :param share_server: Data structure with share server information.
             Not used by this driver.
         """
 
-        self._check_fs_mounted()
-
         hnas_share_id = self._get_hnas_share_id(snapshot['share_id'])
 
         hnas_snapshot_id = self._get_hnas_snapshot_id(snapshot)
 
+        self._ensure_snapshot(snapshot, hnas_snapshot_id)
+
         dest_path = os.path.join('/shares', hnas_share_id)
         src_path = os.path.join('/snapshots', hnas_share_id, hnas_snapshot_id)
 
@@ -773,12 +839,12 @@ class HitachiHNASDriver(driver.ShareDriver):
         try:
             self.hnas.tree_clone(src_path, dest_path)
         except exception.HNASNothingToCloneException:
-            LOG.warning(_LW("Source directory is empty, creating an empty "
-                            "directory."))
+            LOG.warning("Source directory is empty, creating an empty "
+                        "directory.")
 
-        LOG.info(_LI("Share %(share)s successfully reverted to snapshot "
-                     "%(snapshot)s."), {'share': snapshot['share_id'],
-                                        'snapshot': snapshot['id']})
+        LOG.info("Share %(share)s successfully reverted to snapshot "
+                 "%(snapshot)s.", {'share': snapshot['share_id'],
+                                   'snapshot': snapshot['id']})
 
     def _get_hnas_share_id(self, share_id):
         hnas_id = self.private_storage.get(share_id, 'hnas_id')
@@ -993,8 +1059,8 @@ class HitachiHNASDriver(driver.ShareDriver):
         try:
             self.hnas.tree_clone(src_path, dest_path)
         except exception.HNASNothingToCloneException:
-            LOG.warning(_LW("Source directory is empty, creating an empty "
-                            "directory."))
+            LOG.warning("Source directory is empty, creating an empty "
+                        "directory.")
             self.hnas.create_directory(dest_path)
         finally:
             if share_proto.lower() == 'nfs':
@@ -1062,8 +1128,8 @@ class HitachiHNASDriver(driver.ShareDriver):
         try:
             self.hnas.tree_clone(src_path, dest_path)
         except exception.HNASNothingToCloneException:
-            LOG.warning(_LW("Source directory is empty, exporting "
-                            "directory."))
+            LOG.warning("Source directory is empty, exporting "
+                        "directory.")
 
         self._check_protocol(share['id'], share['share_proto'])
 
@@ -1140,6 +1206,8 @@ class HitachiHNASDriver(driver.ShareDriver):
                              snapshot['share']['share_proto'])
         self._check_fs_mounted()
 
+        self.hnas.check_directory(snapshot['provider_location'])
+
         export_list = None
         if snapshot['share'].get('mount_snapshot_support'):
             if snapshot['share']['share_proto'].lower() == 'nfs':
@@ -1169,32 +1237,47 @@ class HitachiHNASDriver(driver.ShareDriver):
             Example for NFS::
 
             [
+
               {
+
                 'path': '172.24.44.10:/snapshots/id',
                 'metadata': {},
                 'is_admin_only': False
+
               },
+
               {
+
                 'path': '192.168.0.10:/snapshots/id',
                 'metadata': {},
                 'is_admin_only': True
+
               }
+
             ]
 
             Example for CIFS::
 
             [
+
               {
+
                 'path': '\\172.24.44.10\id',
                 'metadata': {},
                 'is_admin_only': False
+
               },
+
               {
+
                 'path': '\\192.168.0.10\id',
                 'metadata': {},
                 'is_admin_only': True
+
               }
+
             ]
+
         """
         LOG.debug("Ensuring snapshot in HNAS: %(snap)s.",
                   {'snap': snapshot['id']})
@@ -1260,7 +1343,7 @@ class HitachiHNASDriver(driver.ShareDriver):
                                         'share_id': snapshot['share_id']}
             raise exception.ManageInvalidShareSnapshot(reason=msg)
 
-        if not self.hnas.check_snapshot(snapshot['provider_location']):
+        if not self.hnas.check_directory(snapshot['provider_location']):
             msg = _("Snapshot %(snap_id)s does not exist in "
                     "HNAS.") % {'snap_id': hnas_snapshot_id}
             raise exception.ManageInvalidShareSnapshot(reason=msg)
@@ -1268,8 +1351,8 @@ class HitachiHNASDriver(driver.ShareDriver):
         try:
             self._ensure_snapshot(snapshot, hnas_snapshot_id)
         except exception.HNASItemNotFoundException:
-            LOG.warning(_LW("Export does not exist for snapshot %s, "
-                            "creating a new one."), snapshot['id'])
+            LOG.warning("Export does not exist for snapshot %s, "
+                        "creating a new one.", snapshot['id'])
             self._create_export(hnas_share_id,
                                 snapshot['share']['share_proto'],
                                 snapshot_id=hnas_snapshot_id)
@@ -1282,8 +1365,8 @@ class HitachiHNASDriver(driver.ShareDriver):
                 is_snapshot=True)
             output['export_locations'] = export_locations
 
-        LOG.info(_LI("Snapshot %(snap_path)s for share %(shr_id)s was "
-                     "successfully managed with ID %(snap_id)s."),
+        LOG.info("Snapshot %(snap_path)s for share %(shr_id)s was "
+                 "successfully managed with ID %(snap_id)s.",
                  {'snap_path': snapshot['provider_location'],
                   'shr_id': snapshot['share_id'],
                   'snap_id': snapshot['id']})
@@ -1295,9 +1378,9 @@ class HitachiHNASDriver(driver.ShareDriver):
 
         :param snapshot: Snapshot that will be unmanaged.
         """
-        LOG.info(_LI("The snapshot with ID %(snap_id)s from share "
-                     "%(share_id)s is no longer being managed by Manila. "
-                     "However, it is not deleted and can be found in HNAS."),
+        LOG.info("The snapshot with ID %(snap_id)s from share "
+                 "%(share_id)s is no longer being managed by Manila. "
+                 "However, it is not deleted and can be found in HNAS.",
                  {'snap_id': snapshot['id'],
                   'share_id': snapshot['share_id']})
 
