@@ -27,7 +27,7 @@ import six
 
 from manila.common import config
 from manila import exception
-from manila.i18n import _, _LI
+from manila.i18n import _
 from manila.share import driver
 from manila.share.drivers.hpe import hpe_3par_mediator
 from manila.share import share_types
@@ -42,8 +42,10 @@ class FPG(types.String, types.IPAddress):
 
     Used to represent multiple pools per backend values.
     Converts configuration value to an FPGs value.
-    FPGs value format:
+    FPGs value format::
+
         FPG name, IP address 1, IP address 2, ..., IP address 4
+
     where FPG name is a string value,
     IP address is of type types.IPAddress
 
@@ -130,10 +132,9 @@ HPE3PAR_OPTS = [
                help="3PAR password for the user specified in hpe3par_username",
                secret=True,
                deprecated_name='hp3par_password'),
-    cfg.StrOpt('hpe3par_san_ip',
-               default='',
-               help="IP address of SAN controller",
-               deprecated_name='hp3par_san_ip'),
+    cfg.HostAddressOpt('hpe3par_san_ip',
+                       help="IP address of SAN controller",
+                       deprecated_name='hp3par_san_ip'),
     cfg.StrOpt('hpe3par_san_login',
                default='',
                help="Username for SAN controller",
@@ -199,7 +200,8 @@ class HPE3ParShareDriver(driver.ShareDriver):
 
     Supports NFS and CIFS protocols on arrays with File Persona.
 
-    Version history:
+    Version history::
+
         1.0.0 - Begin Liberty development (post-Kilo)
         1.0.1 - Report thin/dedup/hp_flash_cache capabilities
         1.0.2 - Add share server/share network support
@@ -211,10 +213,13 @@ class HPE3ParShareDriver(driver.ShareDriver):
                 when a share is deleted #1582931
         2.0.5 - Add update_access support
         2.0.6 - Multi pool support per backend
+        2.0.7 - Fix get_vfs() to correctly validate conf IP addresses at
+                boot up #1621016
+        2.0.8 - Replace ConsistencyGroup with ShareGroup
 
     """
 
-    VERSION = "2.0.6"
+    VERSION = "2.0.8"
 
     def __init__(self, *args, **kwargs):
         super(HPE3ParShareDriver, self).__init__((True, False),
@@ -231,7 +236,7 @@ class HPE3ParShareDriver(driver.ShareDriver):
     def do_setup(self, context):
         """Any initialization the share driver does while starting."""
 
-        LOG.info(_LI("Starting share driver %(driver_name)s (%(version)s)"),
+        LOG.info("Starting share driver %(driver_name)s (%(version)s)",
                  {'driver_name': self.__class__.__name__,
                   'version': self.VERSION})
 
@@ -264,7 +269,6 @@ class HPE3ParShareDriver(driver.ShareDriver):
         def _validate_pool_ips(addresses, conf_pool_ips):
             # Pool configured IP addresses should be subset of IP addresses
             # retured from vfs
-            addresses = to_list(addresses)
             if not set(conf_pool_ips) <= set(addresses):
                 msg = _("Incorrect configuration. "
                         "Configuration pool IP address did not match with "
@@ -286,8 +290,6 @@ class HPE3ParShareDriver(driver.ShareDriver):
                 vfs_info = mediator.get_vfs(pool_name)
                 if self.driver_handles_share_servers:
                     # Use discovered IP(s) from array
-                    vfs_info['vfsip']['address'] = to_list(
-                        vfs_info['vfsip']['address'])
                     self.fpgs[pool_name] = {
                         vfs_info['vfsname']: vfs_info['vfsip']['address']}
                 elif conf_pool_ips == []:
@@ -300,8 +302,6 @@ class HPE3ParShareDriver(driver.ShareDriver):
                         raise exception.HPE3ParInvalid(err=msg)
                     else:
                         # Use discovered pool ips
-                        vfs_info['vfsip']['address'] = to_list(
-                            vfs_info['vfsip']['address'])
                         self.fpgs[pool_name] = {
                             vfs_info['vfsname']: vfs_info['vfsip']['address']}
                 else:
@@ -384,7 +384,7 @@ class HPE3ParShareDriver(driver.ShareDriver):
 
     def choose_share_server_compatible_with_share(self, context, share_servers,
                                                   share, snapshot=None,
-                                                  consistency_group=None):
+                                                  share_group=None):
         """Method that allows driver to choose share server for provided share.
 
         If compatible share-server is not found, method should return None.
@@ -393,12 +393,12 @@ class HPE3ParShareDriver(driver.ShareDriver):
         :param share_servers: list with share-server models
         :param share:  share model
         :param snapshot: snapshot model
-        :param consistency_group: ConsistencyGroup model with shares
+        :param share_group: ShareGroup model with shares
         :returns: share-server or None
         """
-        # If creating in a consistency group, raise exception
-        if consistency_group:
-            msg = _("HPE 3PAR driver does not support consistency group")
+        # If creating in a share group, raise exception
+        if share_group:
+            msg = _("HPE 3PAR driver does not support share group")
             raise exception.InvalidRequest(message=msg)
 
         pool_name = share_utils.extract_host(share['host'], level='pool')
@@ -636,8 +636,8 @@ class HPE3ParShareDriver(driver.ShareDriver):
 
         if not self._hpe3par:
             LOG.info(
-                _LI("Skipping capacity and capabilities update. Setup has not "
-                    "completed."))
+                "Skipping capacity and capabilities update. Setup has not "
+                "completed.")
         else:
             for fpg in self.fpgs:
                 fpg_status = self._hpe3par.get_fpg_status(fpg)
