@@ -55,6 +55,10 @@ class NetAppCmodeSingleSvmShareDriver(driver.ShareDriver):
     def create_snapshot(self, context, snapshot, **kwargs):
         return self.library.create_snapshot(context, snapshot, **kwargs)
 
+    def revert_to_snapshot(self, context, snapshot, share_access_rules,
+                           snapshot_access_rules, **kwargs):
+        return self.library.revert_to_snapshot(context, snapshot, **kwargs)
+
     def delete_share(self, context, share, **kwargs):
         self.library.delete_share(context, share, **kwargs)
 
@@ -67,25 +71,6 @@ class NetAppCmodeSingleSvmShareDriver(driver.ShareDriver):
     def shrink_share(self, share, new_size, **kwargs):
         self.library.shrink_share(share, new_size, **kwargs)
 
-    def create_consistency_group(self, context, cg_dict, **kwargs):
-        return self.library.create_consistency_group(context, cg_dict,
-                                                     **kwargs)
-
-    def create_consistency_group_from_cgsnapshot(self, context, cg_dict,
-                                                 cgsnapshot_dict, **kwargs):
-        return self.library.create_consistency_group_from_cgsnapshot(
-            context, cg_dict, cgsnapshot_dict, **kwargs)
-
-    def delete_consistency_group(self, context, cg_dict, **kwargs):
-        return self.library.delete_consistency_group(context, cg_dict,
-                                                     **kwargs)
-
-    def create_cgsnapshot(self, context, snap_dict, **kwargs):
-        return self.library.create_cgsnapshot(context, snap_dict, **kwargs)
-
-    def delete_cgsnapshot(self, context, snap_dict, **kwargs):
-        return self.library.delete_cgsnapshot(context, snap_dict, **kwargs)
-
     def ensure_share(self, context, share, **kwargs):
         pass
 
@@ -95,16 +80,30 @@ class NetAppCmodeSingleSvmShareDriver(driver.ShareDriver):
     def unmanage(self, share):
         self.library.unmanage(share)
 
+    def manage_existing_snapshot(self, snapshot, driver_options):
+        return self.library.manage_existing_snapshot(snapshot, driver_options)
+
+    def unmanage_snapshot(self, snapshot):
+        self.library.unmanage_snapshot(snapshot)
+
     def update_access(self, context, share, access_rules, add_rules,
                       delete_rules, **kwargs):
         self.library.update_access(context, share, access_rules, add_rules,
                                    delete_rules, **kwargs)
 
     def _update_share_stats(self, data=None):
-        data = self.library.get_share_stats()
+        data = self.library.get_share_stats(
+            filter_function=self.get_filter_function(),
+            goodness_function=self.get_goodness_function())
         super(NetAppCmodeSingleSvmShareDriver, self)._update_share_stats(
             data=data)
 
+    def get_default_filter_function(self):
+        return self.library.get_default_filter_function()
+
+    def get_default_goodness_function(self):
+        return self.library.get_default_goodness_function()
+
     def get_share_server_pools(self, share_server):
         return self.library.get_share_server_pools(share_server)
 
@@ -165,3 +164,92 @@ class NetAppCmodeSingleSvmShareDriver(driver.ShareDriver):
         return self.library.update_replicated_snapshot(
             replica_list, share_replica, replica_snapshots, replica_snapshot,
             share_server=share_server)
+
+    def revert_to_replicated_snapshot(self, context, active_replica,
+                                      replica_list, active_replica_snapshot,
+                                      replica_snapshots, share_access_rules,
+                                      snapshot_access_rules,
+                                      **kwargs):
+        return self.library.revert_to_replicated_snapshot(
+            context, active_replica, replica_list, active_replica_snapshot,
+            replica_snapshots, **kwargs)
+
+    def migration_check_compatibility(self, context, source_share,
+                                      destination_share, share_server=None,
+                                      destination_share_server=None):
+        return self.library.migration_check_compatibility(
+            context, source_share, destination_share,
+            share_server=share_server,
+            destination_share_server=destination_share_server)
+
+    def migration_start(self, context, source_share, destination_share,
+                        source_snapshots, snapshot_mappings,
+                        share_server=None, destination_share_server=None):
+        return self.library.migration_start(
+            context, source_share, destination_share,
+            source_snapshots, snapshot_mappings, share_server=share_server,
+            destination_share_server=destination_share_server)
+
+    def migration_continue(self, context, source_share, destination_share,
+                           source_snapshots, snapshot_mappings,
+                           share_server=None, destination_share_server=None):
+        return self.library.migration_continue(
+            context, source_share, destination_share,
+            source_snapshots, snapshot_mappings, share_server=share_server,
+            destination_share_server=destination_share_server)
+
+    def migration_get_progress(self, context, source_share,
+                               destination_share, source_snapshots,
+                               snapshot_mappings, share_server=None,
+                               destination_share_server=None):
+        return self.library.migration_get_progress(
+            context, source_share, destination_share,
+            source_snapshots, snapshot_mappings, share_server=share_server,
+            destination_share_server=destination_share_server)
+
+    def migration_cancel(self, context, source_share, destination_share,
+                         source_snapshots, snapshot_mappings,
+                         share_server=None, destination_share_server=None):
+        return self.library.migration_cancel(
+            context, source_share, destination_share,
+            source_snapshots, snapshot_mappings, share_server=share_server,
+            destination_share_server=destination_share_server)
+
+    def migration_complete(self, context, source_share, destination_share,
+                           source_snapshots, snapshot_mappings,
+                           share_server=None, destination_share_server=None):
+        return self.library.migration_complete(
+            context, source_share, destination_share,
+            source_snapshots, snapshot_mappings, share_server=share_server,
+            destination_share_server=destination_share_server)
+
+    def create_share_group_snapshot(self, context, snap_dict,
+                                    share_server=None):
+        fallback_create = super(NetAppCmodeSingleSvmShareDriver,
+                                self).create_share_group_snapshot
+        return self.library.create_group_snapshot(context, snap_dict,
+                                                  fallback_create,
+                                                  share_server)
+
+    def delete_share_group_snapshot(self, context, snap_dict,
+                                    share_server=None):
+        fallback_delete = super(NetAppCmodeSingleSvmShareDriver,
+                                self).delete_share_group_snapshot
+        return self.library.delete_group_snapshot(context, snap_dict,
+                                                  fallback_delete,
+                                                  share_server)
+
+    def create_share_group_from_share_group_snapshot(
+            self, context, share_group_dict, snapshot_dict,
+            share_server=None):
+        fallback_create = super(
+            NetAppCmodeSingleSvmShareDriver,
+            self).create_share_group_from_share_group_snapshot
+        return self.library.create_group_from_snapshot(context,
+                                                       share_group_dict,
+                                                       snapshot_dict,
+                                                       fallback_create,
+                                                       share_server)
+
+    def get_configured_ip_versions(self):
+        return self.library.get_configured_ip_versions()
