@@ -77,10 +77,9 @@ class QuobyteShareDriver(driver.ExecuteMixin, driver.ShareDriver,):
         1.2.2   - Minor optimizations
         1.2.3   - Updated RPC layer for improved stability
         1.2.4   - Fixed handling updated QB API error codes
-        1.2.5   - Fixed two quota handling bugs
     """
 
-    DRIVER_VERSION = '1.2.5'
+    DRIVER_VERSION = '1.2.4'
 
     def __init__(self, *args, **kwargs):
         super(QuobyteShareDriver, self).__init__(False, *args, **kwargs)
@@ -89,8 +88,9 @@ class QuobyteShareDriver(driver.ExecuteMixin, driver.ShareDriver,):
                              or CONF.share_backend_name or 'Quobyte')
 
     def _fetch_existing_access(self, context, share):
-        volume_uuid = self._resolve_volume_name(share['name'],
-                                                share['project_id'])
+        volume_uuid = self._resolve_volume_name(
+            share['name'],
+            self._get_project_name(context, share['project_id']))
         result = self.rpc.call('getConfiguration', {})
         if result is None:
             raise exception.QBException(
@@ -179,15 +179,12 @@ class QuobyteShareDriver(driver.ExecuteMixin, driver.ShareDriver,):
         return project_id
 
     def _resize_share(self, share, new_size):
-        newsize_bytes = new_size * units.Gi
         self.rpc.call('setQuota', {"quotas": [
             {"consumer":
                 [{"type": "VOLUME",
-                  "identifier": self._resolve_volume_name(share["name"],
-                                                          share['project_id']),
-                  "tenant_id": share["project_id"]}],
+                 "identifier": share["name"]}],
              "limits": [{"type": "LOGICAL_DISK_SPACE",
-                        "value": newsize_bytes}]}
+                        "value": new_size}]}
         ]})
 
     def _resolve_volume_name(self, volume_name, tenant_domain):
@@ -223,8 +220,9 @@ class QuobyteShareDriver(driver.ExecuteMixin, driver.ShareDriver,):
             raise exception.QBException(
                 _('Quobyte driver only supports NFS shares'))
 
-        volume_uuid = self._resolve_volume_name(share['name'],
-                                                share['project_id'])
+        volume_uuid = self._resolve_volume_name(
+            share['name'],
+            self._get_project_name(context, share['project_id']))
 
         if not volume_uuid:
             # create tenant, expect ERROR_GARBAGE_ARGS if it already exists
@@ -244,14 +242,13 @@ class QuobyteShareDriver(driver.ExecuteMixin, driver.ShareDriver,):
             volume_uuid=volume_uuid,
             protocol='NFS'))
 
-        self._resize_share(share, share['size'])
-
         return '%(nfs_server_ip)s:%(nfs_export_path)s' % result
 
     def delete_share(self, context, share, share_server=None):
         """Delete the corresponding Quobyte volume."""
-        volume_uuid = self._resolve_volume_name(share['name'],
-                                                share['project_id'])
+        volume_uuid = self._resolve_volume_name(
+            share['name'],
+            self._get_project_name(context, share['project_id']))
         if not volume_uuid:
             LOG.warning("No volume found for "
                         "share %(project_id)s/%(name)s",
@@ -279,8 +276,9 @@ class QuobyteShareDriver(driver.ExecuteMixin, driver.ShareDriver,):
             the backend
         """
 
-        volume_uuid = self._resolve_volume_name(share['name'],
-                                                share['project_id'])
+        volume_uuid = self._resolve_volume_name(
+            share['name'],
+            self._get_project_name(context, share['project_id']))
 
         LOG.debug("Ensuring Quobyte share %s", share['name'])
 
@@ -300,8 +298,9 @@ class QuobyteShareDriver(driver.ExecuteMixin, driver.ShareDriver,):
             raise exception.InvalidShareAccess(
                 _('Quobyte driver only supports ip access control'))
 
-        volume_uuid = self._resolve_volume_name(share['name'],
-                                                share['project_id'])
+        volume_uuid = self._resolve_volume_name(
+            share['name'],
+            self._get_project_name(context, share['project_id']))
         ro = access['access_level'] == (constants.ACCESS_LEVEL_RO)
         call_params = {
             "volume_uuid": volume_uuid,
@@ -318,15 +317,16 @@ class QuobyteShareDriver(driver.ExecuteMixin, driver.ShareDriver,):
                       self._get_project_name(context, share['project_id']))
             return
 
-        volume_uuid = self._resolve_volume_name(share['name'],
-                                                share['project_id'])
+        volume_uuid = self._resolve_volume_name(
+            share['name'],
+            self._get_project_name(context, share['project_id']))
         call_params = {
             "volume_uuid": volume_uuid,
             "remove_allow_ip": access['access_to']}
         self.rpc.call('exportVolume', call_params)
 
     def extend_share(self, ext_share, ext_size, share_server=None):
-        """Uses _resize_share to extend a share.
+        """Uses resize_share to extend a share.
 
         :param ext_share: Share model.
         :param ext_size: New size of share (new_size > share['size']).
@@ -335,7 +335,7 @@ class QuobyteShareDriver(driver.ExecuteMixin, driver.ShareDriver,):
         self._resize_share(share=ext_share, new_size=ext_size)
 
     def shrink_share(self, shrink_share, shrink_size, share_server=None):
-        """Uses _resize_share to shrink a share.
+        """Uses resize_share to shrink a share.
 
         Quobyte uses soft quotas. If a shares current size is bigger than
         the new shrunken size no data is lost. Data can be continuously read
