@@ -30,7 +30,7 @@ from oslo_utils import timeutils
 
 from manila.common import constants
 from manila import exception
-from manila.i18n import _, _LI, _LW
+from manila.i18n import _
 from manila.share import configuration
 from manila.share import driver
 from manila.share.drivers.zfsonlinux import utils as zfs_utils
@@ -41,11 +41,11 @@ from manila import utils
 
 
 zfsonlinux_opts = [
-    cfg.StrOpt(
+    cfg.HostAddressOpt(
         "zfs_share_export_ip",
         required=True,
         help="IP to be added to user-facing export location. Required."),
-    cfg.StrOpt(
+    cfg.HostAddressOpt(
         "zfs_service_ip",
         required=True,
         help="IP to be added to admin-facing export location. Required."),
@@ -279,7 +279,7 @@ class ZFSonLinuxShareDriver(zfs_utils.ExecuteMixin, driver.ShareDriver):
             self.zfs('destroy', '-f', name)
             return
         except exception.ProcessExecutionError:
-            LOG.info(_LI("Failed to destroy ZFS dataset, retrying one time"))
+            LOG.info("Failed to destroy ZFS dataset, retrying one time")
 
         # NOTE(bswartz): There appears to be a bug in ZFS when creating and
         # destroying datasets concurrently where the filesystem remains mounted
@@ -375,8 +375,8 @@ class ZFSonLinuxShareDriver(zfs_utils.ExecuteMixin, driver.ShareDriver):
             'storage_protocol': 'NFS',
             'reserved_percentage':
                 self.configuration.reserved_share_percentage,
-            'consistency_group_support': None,
             'snapshot_support': True,
+            'create_share_from_snapshot_support': True,
             'driver_name': 'ZFS',
             'pools': self._get_pools_info(),
         }
@@ -529,8 +529,8 @@ class ZFSonLinuxShareDriver(zfs_utils.ExecuteMixin, driver.ShareDriver):
             break
         else:
             LOG.warning(
-                _LW("Share with '%(id)s' ID and '%(name)s' NAME is "
-                    "absent on backend. Nothing has been deleted."),
+                "Share with '%(id)s' ID and '%(name)s' NAME is "
+                "absent on backend. Nothing has been deleted.",
                 {'id': share['id'], 'name': dataset_name})
         self.private_storage.delete(share['id'])
 
@@ -574,8 +574,8 @@ class ZFSonLinuxShareDriver(zfs_utils.ExecuteMixin, driver.ShareDriver):
                 break
         else:
             LOG.warning(
-                _LW("Snapshot with '%(id)s' ID and '%(name)s' NAME is "
-                    "absent on backend. Nothing has been deleted."),
+                "Snapshot with '%(id)s' ID and '%(name)s' NAME is "
+                "absent on backend. Nothing has been deleted.",
                 {'id': snapshot['id'], 'name': snapshot_name})
 
     @ensure_share_server_not_provided
@@ -604,7 +604,7 @@ class ZFSonLinuxShareDriver(zfs_utils.ExecuteMixin, driver.ShareDriver):
             # NOTE(vponomaryov): SSH is used as workaround for 'execute'
             # implementation restriction that does not support usage of '|'.
             'ssh', ssh_cmd,
-            'sudo', 'zfs', 'send', '-vDp', snapshot_name, '|',
+            'sudo', 'zfs', 'send', '-vD', snapshot_name, '|',
             'sudo', 'zfs', 'receive', '-v', dataset_name,
         )
         # Apply options based on used share type that may differ from
@@ -787,9 +787,15 @@ class ZFSonLinuxShareDriver(zfs_utils.ExecuteMixin, driver.ShareDriver):
 
         :param snapshot_instance: SnapshotInstance data
         :param driver_options: expects only one optional key 'size'.
-        :return: dict with share snapshot instance fields for update, example:
-            {'size': 1,
-             'provider_location': 'path/to/some/dataset@some_snapshot_tag'}
+        :return: dict with share snapshot instance fields for update, example::
+
+            {
+
+                'size': 1,
+                'provider_location': 'path/to/some/dataset@some_snapshot_tag',
+
+            }
+
         """
         snapshot_size = int(driver_options.get("size", 0))
         old_provider_location = snapshot_instance.get("provider_location")
@@ -966,8 +972,8 @@ class ZFSonLinuxShareDriver(zfs_utils.ExecuteMixin, driver.ShareDriver):
                 break
         else:
             LOG.warning(
-                _LW("Share replica with '%(id)s' ID and '%(name)s' NAME is "
-                    "absent on backend. Nothing has been deleted."),
+                "Share replica with '%(id)s' ID and '%(name)s' NAME is "
+                "absent on backend. Nothing has been deleted.",
                 {'id': replica['id'], 'name': dataset_name})
         self.private_storage.delete(replica['id'])
 
@@ -1085,7 +1091,7 @@ class ZFSonLinuxShareDriver(zfs_utils.ExecuteMixin, driver.ShareDriver):
                 'id': r['id'],
                 # NOTE(vponomaryov): access rules will be updated in next
                 # 'sync' operation.
-                'access_rules_status': constants.STATUS_OUT_OF_SYNC,
+                'access_rules_status': constants.SHARE_INSTANCE_RULES_SYNCING,
             }
             for r in replica_list
         }
@@ -1125,7 +1131,7 @@ class ZFSonLinuxShareDriver(zfs_utils.ExecuteMixin, driver.ShareDriver):
                         'sudo', 'zfs', 'receive', '-vF', dataset_name,
                     )
                 except exception.ProcessExecutionError as e:
-                    LOG.warning(_LW("Failed to sync replica %(id)s. %(e)s"),
+                    LOG.warning("Failed to sync replica %(id)s. %(e)s",
                                 {'id': repl['id'], 'e': e})
                     replica_dict[repl['id']]['replica_state'] = (
                         constants.REPLICA_STATE_OUT_OF_SYNC)
@@ -1147,7 +1153,7 @@ class ZFSonLinuxShareDriver(zfs_utils.ExecuteMixin, driver.ShareDriver):
                 constants.REPLICA_STATE_IN_SYNC)
         except Exception as e:
             LOG.warning(
-                _LW("Failed to update currently active replica. \n%s"), e)
+                "Failed to update currently active replica. \n%s", e)
 
             replica_dict[active_replica['id']]['replica_state'] = (
                 constants.REPLICA_STATE_OUT_OF_SYNC)
@@ -1179,7 +1185,7 @@ class ZFSonLinuxShareDriver(zfs_utils.ExecuteMixin, driver.ShareDriver):
                         'sudo', 'zfs', 'receive', '-vF', dataset_name,
                     )
                 except exception.ProcessExecutionError as e:
-                    LOG.warning(_LW("Failed to sync replica %(id)s. %(e)s"),
+                    LOG.warning("Failed to sync replica %(id)s. %(e)s",
                                 {'id': repl['id'], 'e': e})
                     replica_dict[repl['id']]['replica_state'] = (
                         constants.REPLICA_STATE_OUT_OF_SYNC)
@@ -1268,7 +1274,7 @@ class ZFSonLinuxShareDriver(zfs_utils.ExecuteMixin, driver.ShareDriver):
                 )
             except exception.ProcessExecutionError as e:
                 LOG.warning(
-                    _LW("Failed to sync snapshot instance %(id)s. %(e)s"),
+                    "Failed to sync snapshot instance %(id)s. %(e)s",
                     {'id': replica_snapshot['id'], 'e': e})
                 replica_snapshots_dict[replica_snapshot['id']]['status'] = (
                     constants.STATUS_ERROR)
@@ -1371,8 +1377,9 @@ class ZFSonLinuxShareDriver(zfs_utils.ExecuteMixin, driver.ShareDriver):
 
     @ensure_share_server_not_provided
     def migration_start(
-            self, context, source_share, destination_share,
-            share_server=None, destination_share_server=None):
+            self, context, source_share, destination_share, source_snapshots,
+            snapshot_mappings, share_server=None,
+            destination_share_server=None):
         """Is called to start share migration."""
 
         src_dataset_name = self.private_storage.get(
@@ -1430,8 +1437,9 @@ class ZFSonLinuxShareDriver(zfs_utils.ExecuteMixin, driver.ShareDriver):
 
     @ensure_share_server_not_provided
     def migration_continue(
-            self, context, source_share, destination_share,
-            share_server=None, destination_share_server=None):
+            self, context, source_share, destination_share, source_snapshots,
+            snapshot_mappings, share_server=None,
+            destination_share_server=None):
         """Is called in source share's backend to continue migration."""
 
         snapshot_tag = self.private_storage.get(
@@ -1455,8 +1463,9 @@ class ZFSonLinuxShareDriver(zfs_utils.ExecuteMixin, driver.ShareDriver):
 
     @ensure_share_server_not_provided
     def migration_complete(
-            self, context, source_share, destination_share,
-            share_server=None, destination_share_server=None):
+            self, context, source_share, destination_share, source_snapshots,
+            snapshot_mappings, share_server=None,
+            destination_share_server=None):
         """Is called to perform 2nd phase of driver migration of a given share.
 
         """
@@ -1489,12 +1498,13 @@ class ZFSonLinuxShareDriver(zfs_utils.ExecuteMixin, driver.ShareDriver):
         # Destroy src share and temporary migration snapshot on src (this) host
         self.delete_share(context, source_share)
 
-        return export_locations
+        return {'export_locations': export_locations}
 
     @ensure_share_server_not_provided
     def migration_cancel(
-            self, context, source_share, destination_share,
-            share_server=None, destination_share_server=None):
+            self, context, source_share, destination_share, source_snapshots,
+            snapshot_mappings, share_server=None,
+            destination_share_server=None):
         """Is called to cancel driver migration."""
 
         src_dataset_name = self.private_storage.get(
@@ -1516,8 +1526,8 @@ class ZFSonLinuxShareDriver(zfs_utils.ExecuteMixin, driver.ShareDriver):
                         x for x in line.strip().split(' ') if x != ''][1]
                     self.execute('sudo', 'kill', '-9', migr_pid)
         except exception.ProcessExecutionError as e:
-            LOG.warning(_LW(
-                "Caught following error trying to kill migration process: %s"),
+            LOG.warning(
+                "Caught following error trying to kill migration process: %s",
                 e)
 
         # Sleep couple of seconds before destroying updated objects
@@ -1534,11 +1544,11 @@ class ZFSonLinuxShareDriver(zfs_utils.ExecuteMixin, driver.ShareDriver):
                 'sudo', 'zfs', 'destroy', '-r', dst_dataset_name,
             )
         except exception.ProcessExecutionError as e:
-            LOG.warning(_LW(
+            LOG.warning(
                 "Failed to destroy destination dataset with following error: "
-                "%s"),
+                "%s",
                 e)
 
         LOG.debug(
-            "Migration of share with ID '%s' has been canceled." %
+            "Migration of share with ID '%s' has been canceled.",
             source_share["id"])
