@@ -27,15 +27,15 @@ from manila.common import constants
 from manila.db import base
 from manila import exception
 from manila.i18n import _
+from manila import quota
 from manila.scheduler import rpcapi as scheduler_rpcapi
 from manila import share
 from manila.share import rpcapi as share_rpcapi
 from manila.share import share_types
 
-
 CONF = cfg.CONF
-
 LOG = log.getLogger(__name__)
+QUOTAS = quota.QUOTAS
 
 
 class API(base.Base):
@@ -49,7 +49,8 @@ class API(base.Base):
 
     def create(self, context, name=None, description=None,
                share_type_ids=None, source_share_group_snapshot_id=None,
-               share_network_id=None, share_group_type_id=None):
+               share_network_id=None, share_group_type_id=None,
+               availability_zone_id=None):
         """Create new share group."""
 
         share_group_snapshot = None
@@ -73,6 +74,7 @@ class API(base.Base):
                 for s in original_share_group['share_types']]
             share_network_id = original_share_group['share_network_id']
             share_server_id = original_share_group['share_server_id']
+            availability_zone_id = original_share_group['availability_zone_id']
 
         # Get share_type_objects
         share_type_objects = []
@@ -136,11 +138,34 @@ class API(base.Base):
                     "types supported by the share group type.")
             raise exception.InvalidInput(reason=msg)
 
+        try:
+            reservations = QUOTAS.reserve(context, share_groups=1)
+        except exception.OverQuota as e:
+            overs = e.kwargs['overs']
+            usages = e.kwargs['usages']
+            quotas = e.kwargs['quotas']
+
+            def _consumed(name):
+                return (usages[name]['reserved'] + usages[name]['in_use'])
+
+            if 'share_groups' in overs:
+                msg = ("Quota exceeded for '%(s_uid)s' user in '%(s_pid)s' "
+                       "project. (%(d_consumed)d of "
+                       "%(d_quota)d already consumed).")
+                LOG.warning(msg, {
+                    's_pid': context.project_id,
+                    's_uid': context.user_id,
+                    'd_consumed': _consumed('share_groups'),
+                    'd_quota': quotas['share_groups'],
+                })
+            raise exception.ShareGroupsLimitExceeded()
+
         options = {
             'share_group_type_id': share_group_type_id,
             'source_share_group_snapshot_id': source_share_group_snapshot_id,
             'share_network_id': share_network_id,
             'share_server_id': share_server_id,
+            'availability_zone_id': availability_zone_id,
             'name': name,
             'description': description,
             'user_id': context.user_id,
@@ -151,29 +176,40 @@ class API(base.Base):
         if original_share_group:
             options['host'] = original_share_group['host']
 
-        share_group = self.db.share_group_create(context, options)
-
+        share_group = None
         try:
+            share_group = self.db.share_group_create(context, options)
             if share_group_snapshot:
                 members = self.db.share_group_snapshot_members_get_all(
                     context, source_share_group_snapshot_id)
                 for member in members:
-                    share = self.db.share_get(context, member['share_id'])
+                    share_instance = self.db.share_instance_get(
+                        context, member['share_instance_id'])
                     share_type = share_types.get_share_type(
-                        context, share['share_type_id'])
-                    member['share_instance'] = self.db.share_instance_get(
-                        context, member['share_instance_id'],
-                        with_share_data=True)
-                    self.share_api.create(context, member['share_proto'],
-                                          member['size'], None, None,
-                                          share_group_id=share_group['id'],
-                                          share_group_snapshot_member=member,
-                                          share_type=share_type,
-                                          share_network_id=share_network_id)
+                        context, share_instance['share_type_id'])
+                    self.share_api.create(
+                        context,
+                        member['share_proto'],
+                        member['size'],
+                        None,
+                        None,
+                        share_group_id=share_group['id'],
+                        share_group_snapshot_member=member,
+                        share_type=share_type,
+                        availability_zone=availability_zone_id,
+                        share_network_id=share_network_id)
         except Exception:
             with excutils.save_and_reraise_exception():
-                self.db.share_group_destroy(
-                    context.elevated(), share_group['id'])
+                if share_group:
+                    self.db.share_group_destroy(
+                        context.elevated(), share_group['id'])
+                QUOTAS.rollback(context, reservations)
+
+        try:
+            QUOTAS.commit(context, reservations)
+        except Exception:
+            with excutils.save_and_reraise_exception():
+                QUOTAS.rollback(context, reservations)
 
         request_spec = {'share_group_id': share_group['id']}
         request_spec.update(options)
@@ -218,7 +254,30 @@ class API(base.Base):
         share_group = self.db.share_group_update(
             context, share_group_id, {'status': constants.STATUS_DELETING})
 
-        self.share_rpcapi.delete_share_group(context, share_group)
+        try:
+            reservations = QUOTAS.reserve(
+                context,
+                share_groups=-1,
+                project_id=share_group['project_id'],
+                user_id=share_group['user_id'],
+            )
+        except exception.OverQuota as e:
+            reservations = None
+            LOG.exception(
+                ("Failed to update quota for deleting share group: %s"), e)
+
+        try:
+            self.share_rpcapi.delete_share_group(context, share_group)
+        except Exception:
+            with excutils.save_and_reraise_exception():
+                QUOTAS.rollback(context, reservations)
+
+        if reservations:
+            QUOTAS.commit(
+                context, reservations,
+                project_id=share_group['project_id'],
+                user_id=share_group['user_id'],
+            )
 
     def update(self, context, group, fields):
         return self.db.share_group_update(context, group['id'], fields)
@@ -279,8 +338,31 @@ class API(base.Base):
                           "status": constants.STATUS_AVAILABLE})
                 raise exception.InvalidShareGroup(reason=msg)
 
-        snap = self.db.share_group_snapshot_create(context, options)
         try:
+            reservations = QUOTAS.reserve(context, share_group_snapshots=1)
+        except exception.OverQuota as e:
+            overs = e.kwargs['overs']
+            usages = e.kwargs['usages']
+            quotas = e.kwargs['quotas']
+
+            def _consumed(name):
+                return (usages[name]['reserved'] + usages[name]['in_use'])
+
+            if 'share_group_snapshots' in overs:
+                msg = ("Quota exceeded for '%(s_uid)s' user in '%(s_pid)s' "
+                       "project. (%(d_consumed)d of "
+                       "%(d_quota)d already consumed).")
+                LOG.warning(msg, {
+                    's_pid': context.project_id,
+                    's_uid': context.user_id,
+                    'd_consumed': _consumed('share_group_snapshots'),
+                    'd_quota': quotas['share_group_snapshots'],
+                })
+            raise exception.ShareGroupSnapshotsLimitExceeded()
+
+        snap = None
+        try:
+            snap = self.db.share_group_snapshot_create(context, options)
             members = []
             for s in shares:
                 member_options = {
@@ -290,7 +372,6 @@ class API(base.Base):
                     'status': constants.STATUS_CREATING,
                     'size': s['size'],
                     'share_proto': s['share_proto'],
-                    'share_id': s['id'],
                     'share_instance_id': s.instance['id']
                 }
                 member = self.db.share_group_snapshot_member_create(
@@ -303,7 +384,15 @@ class API(base.Base):
         except Exception:
             with excutils.save_and_reraise_exception():
                 # This will delete the snapshot and all of it's members
-                self.db.share_group_snapshot_destroy(context, snap['id'])
+                if snap:
+                    self.db.share_group_snapshot_destroy(context, snap['id'])
+                QUOTAS.rollback(context, reservations)
+
+        try:
+            QUOTAS.commit(context, reservations)
+        except Exception:
+            with excutils.save_and_reraise_exception():
+                QUOTAS.rollback(context, reservations)
 
         return snap
 
@@ -320,10 +409,30 @@ class API(base.Base):
         self.db.share_group_snapshot_update(
             context, snap_id, {'status': constants.STATUS_DELETING})
 
+        try:
+            reservations = QUOTAS.reserve(
+                context,
+                share_group_snapshots=-1,
+                project_id=snap['project_id'],
+                user_id=snap['user_id'],
+            )
+        except exception.OverQuota as e:
+            reservations = None
+            LOG.exception(
+                ("Failed to update quota for deleting share group snapshot: "
+                 "%s"), e)
+
         # Cast to share manager
         self.share_rpcapi.delete_share_group_snapshot(
             context, snap, share_group['host'])
 
+        if reservations:
+            QUOTAS.commit(
+                context, reservations,
+                project_id=snap['project_id'],
+                user_id=snap['user_id'],
+            )
+
     def update_share_group_snapshot(self, context, share_group_snapshot,
                                     fields):
         return self.db.share_group_snapshot_update(
