@@ -56,12 +56,14 @@ class VersionsControllerTestCase(test.TestCase):
         v1 = [v for v in version_list if v['id'] == 'v1.0'][0]
         self.assertEqual('', v1.get('min_version'))
         self.assertEqual('', v1.get('version'))
+        self.assertEqual('DEPRECATED', v1.get('status'))
 
         v2 = [v for v in version_list if v['id'] == 'v2.0'][0]
         self.assertEqual(api_version_request._MIN_API_VERSION,
                          v2.get('min_version'))
         self.assertEqual(api_version_request._MAX_API_VERSION,
                          v2.get('version'))
+        self.assertEqual('CURRENT', v2.get('status'))
 
     @ddt.data('1.0',
               '1.1',
@@ -84,6 +86,7 @@ class VersionsControllerTestCase(test.TestCase):
         self.assertEqual(version_header_name, response.headers['Vary'])
         self.assertEqual('', version_list[0].get('min_version'))
         self.assertEqual('', version_list[0].get('version'))
+        self.assertEqual('DEPRECATED', version_list[0].get('status'))
 
     @ddt.data(api_version_request._MIN_API_VERSION,
               api_version_request._MAX_API_VERSION)
@@ -182,10 +185,10 @@ class ExperimentalAPITestCase(test.TestCase):
         self.assertEqual('2.0', response.headers[version_header_name])
 
         if experimental:
-            self.assertEqual(experimental,
+            self.assertEqual('%s' % experimental,
                              response.headers.get(experimental_header_name))
         else:
-            self.assertFalse(experimental_header_name in response.headers)
+            self.assertNotIn(experimental_header_name, response.headers)
 
     def test_experimental_api_called_when_requested(self):
 
@@ -205,7 +208,7 @@ class ExperimentalAPITestCase(test.TestCase):
         response = self.req.get_response(self.app)
 
         self.assertEqual(404, response.status_int)
-        self.assertFalse(experimental_header_name in response.headers)
+        self.assertNotIn(experimental_header_name, response.headers)
 
     def test_experimental_header_returned_in_exception(self):
 
