@@ -24,12 +24,12 @@ import six
 import webob
 
 from manila.api import common
-from manila.api.openstack import api_version_request as api_version
 from manila.api.v1 import shares
 from manila.common import constants
 from manila import context
 from manila import db
 from manila import exception
+from manila import policy
 from manila.share import api as share_api
 from manila.share import share_types
 from manila import test
@@ -78,7 +78,14 @@ class ShareAPITest(test.TestCase):
         self.vt = {
             'id': 'fake_volume_type_id',
             'name': 'fake_volume_type_name',
+            'required_extra_specs': {
+                'driver_handles_share_servers': 'False'
+            },
+            'extra_specs': {
+                'driver_handles_share_servers': 'False'
+            }
         }
+
         CONF.set_default("default_share_type", None)
 
     def _get_expected_share_detailed_response(self, values=None, admin=False):
@@ -90,7 +97,6 @@ class ShareAPITest(test.TestCase):
             'export_location': 'fake_location',
             'export_locations': ['fake_location', 'fake_location2'],
             'project_id': 'fakeproject',
-            'host': 'fakehost',
             'created_at': datetime.datetime(1, 1, 1, 1, 1, 1),
             'share_proto': 'FAKEPROTO',
             'metadata': {},
@@ -123,6 +129,7 @@ class ShareAPITest(test.TestCase):
             share['share_proto'] = share['share_proto'].upper()
         if admin:
             share['share_server_id'] = 'fake_share_server_id'
+            share['host'] = 'fakehost'
         return {'share': share}
 
     @ddt.data("1.0", "2.0", "2.1")
@@ -148,22 +155,6 @@ class ShareAPITest(test.TestCase):
         expected = self._get_expected_share_detailed_response(self.share)
         self.assertEqual(expected, res_dict)
 
-    @ddt.data("2.4", "2.5")
-    def test_share_create_with_consistency_group(self, microversion):
-        self.mock_object(share_api.API, 'create', self.create_mock)
-        body = {"share": copy.deepcopy(self.share)}
-        req = fakes.HTTPRequest.blank('/shares', version=microversion)
-
-        res_dict = self.controller.create(req, body)
-
-        expected = self._get_expected_share_detailed_response(self.share)
-        expected['share']['consistency_group_id'] = None
-        expected['share']['source_cgsnapshot_member_id'] = None
-        if (api_version.APIVersionRequest(microversion) >=
-                api_version.APIVersionRequest('2.5')):
-            expected['share']['task_state'] = None
-        self.assertEqual(expected, res_dict)
-
     def test_share_create_with_valid_default_share_type(self):
         self.mock_object(share_types, 'get_share_type_by_name',
                          mock.Mock(return_value=self.vt))
@@ -289,9 +280,11 @@ class ShareAPITest(test.TestCase):
         self.mock_object(share_api.API, 'create', create_mock)
         self.mock_object(share_api.API, 'get_snapshot',
                          stubs.stub_snapshot_get)
+        parent_share = stubs.stub_share(
+            '1', instance={'share_network_id': parent_share_net},
+            create_share_from_snapshot_support=True)
         self.mock_object(share_api.API, 'get', mock.Mock(
-            return_value=mock.Mock(
-                instance={'share_network_id': parent_share_net})))
+            return_value=parent_share))
         self.mock_object(share_api.API, 'get_share_network', mock.Mock(
             return_value={'id': parent_share_net}))
 
@@ -327,9 +320,11 @@ class ShareAPITest(test.TestCase):
         self.mock_object(share_api.API, 'create', create_mock)
         self.mock_object(share_api.API, 'get_snapshot',
                          stubs.stub_snapshot_get)
+        parent_share = stubs.stub_share(
+            '1', instance={'share_network_id': parent_share_net},
+            create_share_from_snapshot_support=True)
         self.mock_object(share_api.API, 'get', mock.Mock(
-            return_value=mock.Mock(
-                instance={'share_network_id': parent_share_net})))
+            return_value=parent_share))
         self.mock_object(share_api.API, 'get_share_network', mock.Mock(
             return_value={'id': parent_share_net}))
 
@@ -360,6 +355,52 @@ class ShareAPITest(test.TestCase):
                           req,
                           body)
 
+    @ddt.data("1.0", "2.0")
+    def test_share_create_from_snapshot_not_supported(self, microversion):
+        # This create operation should work, because the 1.0 API doesn't check
+        # create_share_from_snapshot_support.
+
+        parent_share_net = 444
+        shr = {
+            "size": 100,
+            "name": "Share Test Name",
+            "description": "Share Test Desc",
+            "share_proto": "fakeproto",
+            "availability_zone": "zone1:host1",
+            "snapshot_id": 333,
+            "share_network_id": parent_share_net
+        }
+        create_mock = mock.Mock(return_value=stubs.stub_share('1',
+                                display_name=shr['name'],
+                                display_description=shr['description'],
+                                size=shr['size'],
+                                share_proto=shr['share_proto'].upper(),
+                                snapshot_id=shr['snapshot_id'],
+                                instance=dict(
+                                    availability_zone=shr['availability_zone'],
+                                    share_network_id=shr['share_network_id'])))
+        self.mock_object(share_api.API, 'create', create_mock)
+        self.mock_object(share_api.API, 'get_snapshot',
+                         stubs.stub_snapshot_get)
+        parent_share = stubs.stub_share(
+            '1', instance={'share_network_id': parent_share_net},
+            create_share_from_snapshot_support=False)
+        self.mock_object(share_api.API, 'get', mock.Mock(
+            return_value=parent_share))
+        self.mock_object(share_api.API, 'get_share_network', mock.Mock(
+            return_value={'id': parent_share_net}))
+
+        body = {"share": copy.deepcopy(shr)}
+        req = fakes.HTTPRequest.blank('/shares', version=microversion)
+
+        res_dict = self.controller.create(req, body)
+
+        expected = self._get_expected_share_detailed_response(shr)
+        expected['share'].pop('snapshot_support')
+        self.assertDictEqual(expected, res_dict)
+        self.assertEqual(parent_share_net,
+                         create_mock.call_args[1]['share_network_id'])
+
     def test_share_creation_fails_with_bad_size(self):
         shr = {"size": '',
                "name": "Share Test Name",
@@ -404,22 +445,10 @@ class ShareAPITest(test.TestCase):
 
         self.assertEqual(expected, res_dict)
 
-    def test_share_show_with_consistency_group(self):
-        req = fakes.HTTPRequest.blank('/shares/1', version='2.4')
-        expected = self._get_expected_share_detailed_response()
-        expected['share']['consistency_group_id'] = None
-        expected['share']['source_cgsnapshot_member_id'] = None
-
-        res_dict = self.controller.show(req, '1')
-
-        self.assertEqual(expected, res_dict)
-
     def test_share_show_with_share_type_name(self):
         req = fakes.HTTPRequest.blank('/shares/1', version='2.6')
         res_dict = self.controller.show(req, '1')
         expected = self._get_expected_share_detailed_response()
-        expected['share']['consistency_group_id'] = None
-        expected['share']['source_cgsnapshot_member_id'] = None
         expected['share']['share_type_name'] = None
         expected['share']['task_state'] = None
         self.assertEqual(expected, res_dict)
@@ -446,35 +475,6 @@ class ShareAPITest(test.TestCase):
         resp = self.controller.delete(req, 1)
         self.assertEqual(202, resp.status_int)
 
-    def test_share_delete_in_consistency_group_param_not_provided(self):
-        fake_share = stubs.stub_share('fake_share',
-                                      consistency_group_id='fake_cg_id')
-        self.mock_object(share_api.API, 'get',
-                         mock.Mock(return_value=fake_share))
-        req = fakes.HTTPRequest.blank('/shares/1')
-        self.assertRaises(webob.exc.HTTPBadRequest,
-                          self.controller.delete, req, 1)
-
-    def test_share_delete_in_consistency_group(self):
-        fake_share = stubs.stub_share('fake_share',
-                                      consistency_group_id='fake_cg_id')
-        self.mock_object(share_api.API, 'get',
-                         mock.Mock(return_value=fake_share))
-        req = fakes.HTTPRequest.blank(
-            '/shares/1?consistency_group_id=fake_cg_id')
-        resp = self.controller.delete(req, 1)
-        self.assertEqual(202, resp.status_int)
-
-    def test_share_delete_in_consistency_group_wrong_id(self):
-        fake_share = stubs.stub_share('fake_share',
-                                      consistency_group_id='fake_cg_id')
-        self.mock_object(share_api.API, 'get',
-                         mock.Mock(return_value=fake_share))
-        req = fakes.HTTPRequest.blank(
-            '/shares/1?consistency_group_id=not_fake_cg_id')
-        self.assertRaises(webob.exc.HTTPBadRequest,
-                          self.controller.delete, req, 1)
-
     def test_share_update(self):
         shr = self.share
         body = {"share": shr}
@@ -487,15 +487,6 @@ class ShareAPITest(test.TestCase):
         self.assertEqual(shr['is_public'],
                          res_dict['share']['is_public'])
 
-    def test_share_update_with_consistency_group(self):
-        shr = self.share
-        body = {"share": shr}
-
-        req = fakes.HTTPRequest.blank('/share/1', version="2.4")
-        res_dict = self.controller.update(req, 1, body)
-        self.assertIsNone(res_dict['share']["consistency_group_id"])
-        self.assertIsNone(res_dict['share']["source_cgsnapshot_member_id"])
-
     def test_share_not_updates_size(self):
         req = fakes.HTTPRequest.blank('/share/1')
         res_dict = self.controller.update(req, 1, {"share": self.share})
@@ -517,7 +508,6 @@ class ShareAPITest(test.TestCase):
             'share_server_id': 'fake_share_server_id',
             'share_type_id': 'fake_share_type_id',
             'snapshot_id': 'fake_snapshot_id',
-            'host': 'fake_host',
             'share_network_id': 'fake_share_network_id',
             'metadata': '%7B%27k1%27%3A+%27v1%27%7D',  # serialized k1=v1
             'extra_specs': '%7B%27k2%27%3A+%27v2%27%7D',  # serialized k2=v2
@@ -527,6 +517,8 @@ class ShareAPITest(test.TestCase):
             'offset': '1',
             'is_public': 'False',
         }
+        if use_admin_context:
+            search_opts['host'] = 'fake_host'
         # fake_key should be filtered for non-admin
         url = '/shares?fake_key=fake_value'
         for k, v in search_opts.items():
@@ -549,7 +541,6 @@ class ShareAPITest(test.TestCase):
             'share_server_id': search_opts['share_server_id'],
             'share_type_id': search_opts['share_type_id'],
             'snapshot_id': search_opts['snapshot_id'],
-            'host': search_opts['host'],
             'share_network_id': search_opts['share_network_id'],
             'metadata': {'k1': 'v1'},
             'extra_specs': {'k2': 'v2'},
@@ -557,6 +548,7 @@ class ShareAPITest(test.TestCase):
         }
         if use_admin_context:
             search_opts_expected.update({'fake_key': 'fake_value'})
+            search_opts_expected['host'] = search_opts['host']
         share_api.API.get_all.assert_called_once_with(
             req.environ['manila.context'],
             sort_key=search_opts['sort_key'],
@@ -606,7 +598,6 @@ class ShareAPITest(test.TestCase):
             'share_server_id': 'fake_share_server_id',
             'share_type_id': 'fake_share_type_id',
             'snapshot_id': 'fake_snapshot_id',
-            'host': 'fake_host',
             'share_network_id': 'fake_share_network_id',
             'metadata': '%7B%27k1%27%3A+%27v1%27%7D',  # serialized k1=v1
             'extra_specs': '%7B%27k2%27%3A+%27v2%27%7D',  # serialized k2=v2
@@ -616,6 +607,8 @@ class ShareAPITest(test.TestCase):
             'offset': '1',
             'is_public': 'False',
         }
+        if use_admin_context:
+            search_opts['host'] = 'fake_host'
         # fake_key should be filtered for non-admin
         url = '/shares/detail?fake_key=fake_value'
         for k, v in search_opts.items():
@@ -629,9 +622,9 @@ class ShareAPITest(test.TestCase):
                 'display_name': 'n2',
                 'status': constants.STATUS_AVAILABLE,
                 'snapshot_id': 'fake_snapshot_id',
-                'share_type_id': 'fake_share_type_id',
                 'instance': {'host': 'fake_host',
-                             'share_network_id': 'fake_share_network_id'},
+                             'share_network_id': 'fake_share_network_id',
+                             'share_type_id': 'fake_share_type_id'},
             },
             {'id': 'id3', 'display_name': 'n3'},
         ]
@@ -646,7 +639,6 @@ class ShareAPITest(test.TestCase):
             'share_server_id': search_opts['share_server_id'],
             'share_type_id': search_opts['share_type_id'],
             'snapshot_id': search_opts['snapshot_id'],
-            'host': search_opts['host'],
             'share_network_id': search_opts['share_network_id'],
             'metadata': {'k1': 'v1'},
             'extra_specs': {'k2': 'v2'},
@@ -654,6 +646,7 @@ class ShareAPITest(test.TestCase):
         }
         if use_admin_context:
             search_opts_expected.update({'fake_key': 'fake_value'})
+            search_opts_expected['host'] = search_opts['host']
         share_api.API.get_all.assert_called_once_with(
             req.environ['manila.context'],
             sort_key=search_opts['sort_key'],
@@ -669,11 +662,13 @@ class ShareAPITest(test.TestCase):
         self.assertEqual(
             shares[1]['status'], result['shares'][0]['status'])
         self.assertEqual(
-            shares[1]['share_type_id'], result['shares'][0]['share_type'])
+            shares[1]['instance']['share_type_id'],
+            result['shares'][0]['share_type'])
         self.assertEqual(
             shares[1]['snapshot_id'], result['shares'][0]['snapshot_id'])
-        self.assertEqual(
-            shares[1]['instance']['host'], result['shares'][0]['host'])
+        if use_admin_context:
+            self.assertEqual(
+                shares[1]['instance']['host'], result['shares'][0]['host'])
         self.assertEqual(
             shares[1]['instance']['share_network_id'],
             result['shares'][0]['share_network_id'])
@@ -684,42 +679,41 @@ class ShareAPITest(test.TestCase):
     def test_share_list_detail_with_search_opts_by_admin(self):
         self._share_list_detail_with_search_opts(use_admin_context=True)
 
-    def _list_detail_common_expected(self):
-        return {
-            'shares': [
+    def _list_detail_common_expected(self, admin=False):
+        share_dict = {
+            'status': 'fakestatus',
+            'description': 'displaydesc',
+            'export_location': 'fake_location',
+            'export_locations': ['fake_location', 'fake_location2'],
+            'availability_zone': 'fakeaz',
+            'name': 'displayname',
+            'share_proto': 'FAKEPROTO',
+            'metadata': {},
+            'project_id': 'fakeproject',
+
+            'id': '1',
+            'snapshot_id': '2',
+            'snapshot_support': True,
+            'share_network_id': None,
+            'created_at': datetime.datetime(1, 1, 1, 1, 1, 1),
+            'size': 1,
+            'share_type': '1',
+            'volume_type': '1',
+            'is_public': False,
+            'links': [
                 {
-                    'status': 'fakestatus',
-                    'description': 'displaydesc',
-                    'export_location': 'fake_location',
-                    'export_locations': ['fake_location', 'fake_location2'],
-                    'availability_zone': 'fakeaz',
-                    'name': 'displayname',
-                    'share_proto': 'FAKEPROTO',
-                    'metadata': {},
-                    'project_id': 'fakeproject',
-                    'host': 'fakehost',
-                    'id': '1',
-                    'snapshot_id': '2',
-                    'snapshot_support': True,
-                    'share_network_id': None,
-                    'created_at': datetime.datetime(1, 1, 1, 1, 1, 1),
-                    'size': 1,
-                    'share_type': '1',
-                    'volume_type': '1',
-                    'is_public': False,
-                    'links': [
-                        {
-                            'href': 'http://localhost/v1/fake/shares/1',
-                            'rel': 'self'
-                        },
-                        {
-                            'href': 'http://localhost/fake/shares/1',
-                            'rel': 'bookmark'
-                        }
-                    ],
+                    'href': 'http://localhost/v1/fake/shares/1',
+                    'rel': 'self'
+                },
+                {
+                    'href': 'http://localhost/fake/shares/1',
+                    'rel': 'bookmark'
                 }
-            ]
+            ],
         }
+        if admin:
+            share_dict['host'] = 'fakehost'
+        return {'shares': [share_dict]}
 
     def _list_detail_test_common(self, req, expected):
         self.mock_object(share_api.API, 'get_all',
@@ -736,22 +730,11 @@ class ShareAPITest(test.TestCase):
         expected['shares'][0].pop('snapshot_support')
         self._list_detail_test_common(req, expected)
 
-    def test_share_list_detail_with_consistency_group(self):
-        env = {'QUERY_STRING': 'name=Share+Test+Name'}
-        req = fakes.HTTPRequest.blank('/shares/detail', environ=env,
-                                      version="2.4")
-        expected = self._list_detail_common_expected()
-        expected['shares'][0]['consistency_group_id'] = None
-        expected['shares'][0]['source_cgsnapshot_member_id'] = None
-        self._list_detail_test_common(req, expected)
-
     def test_share_list_detail_with_task_state(self):
         env = {'QUERY_STRING': 'name=Share+Test+Name'}
         req = fakes.HTTPRequest.blank('/shares/detail', environ=env,
                                       version="2.5")
         expected = self._list_detail_common_expected()
-        expected['shares'][0]['consistency_group_id'] = None
-        expected['shares'][0]['source_cgsnapshot_member_id'] = None
         expected['shares'][0]['task_state'] = None
         self._list_detail_test_common(req, expected)
 
@@ -771,20 +754,6 @@ class ShareAPITest(test.TestCase):
         common.remove_invalid_options(ctx, search_opts, allowed_opts)
         self.assertEqual(expected_opts, search_opts)
 
-    def test_validate_cephx_id_invalid_with_period(self):
-        self.assertRaises(webob.exc.HTTPBadRequest,
-                          self.controller._validate_cephx_id,
-                          "client.manila")
-
-    def test_validate_cephx_id_invalid_with_non_ascii(self):
-        self.assertRaises(webob.exc.HTTPBadRequest,
-                          self.controller._validate_cephx_id,
-                          u"bj\u00F6rn")
-
-    @ddt.data("alice", "alice_bob", "alice bob")
-    def test_validate_cephx_id_valid(self, test_id):
-        self.controller._validate_cephx_id(test_id)
-
 
 def _fake_access_get(self, ctxt, access_id):
 
@@ -812,11 +781,12 @@ class ShareActionsTest(test.TestCase):
         super(self.__class__, self).setUp()
         self.controller = shares.ShareController()
         self.mock_object(share_api.API, 'get', stubs.stub_share_get)
+        self.mock_policy_check = self.mock_object(policy, 'check_policy')
 
     @ddt.data(
         {'access_type': 'ip', 'access_to': '127.0.0.1'},
         {'access_type': 'user', 'access_to': '1' * 4},
-        {'access_type': 'user', 'access_to': '1' * 32},
+        {'access_type': 'user', 'access_to': '1' * 255},
         {'access_type': 'user', 'access_to': 'fake\\]{.-_\'`;}['},
         {'access_type': 'user', 'access_to': 'MYDOMAIN\\Administrator'},
         {'access_type': 'cert', 'access_to': 'x'},
@@ -827,13 +797,20 @@ class ShareActionsTest(test.TestCase):
         self.mock_object(share_api.API,
                          'allow_access',
                          mock.Mock(return_value={'fake': 'fake'}))
+        self.mock_object(self.controller._access_view_builder, 'view',
+                         mock.Mock(return_value={'access':
+                                                 {'fake': 'fake'}}))
 
         id = 'fake_share_id'
         body = {'os-allow_access': access}
         expected = {'access': {'fake': 'fake'}}
         req = fakes.HTTPRequest.blank('/v1/tenant1/shares/%s/action' % id)
+
         res = self.controller._allow_access(req, id, body)
+
         self.assertEqual(expected, res)
+        self.mock_policy_check.assert_called_once_with(
+            req.environ['manila.context'], 'share', 'allow_access')
 
     @ddt.data(
         {'access_type': 'error_type', 'access_to': '127.0.0.1'},
@@ -843,7 +820,7 @@ class ShareActionsTest(test.TestCase):
         {'access_type': 'ip', 'access_to': '127.0.0.256'},
         {'access_type': 'user', 'access_to': '1'},
         {'access_type': 'user', 'access_to': '1' * 3},
-        {'access_type': 'user', 'access_to': '1' * 33},
+        {'access_type': 'user', 'access_to': '1' * 256},
         {'access_type': 'user', 'access_to': 'root^'},
         {'access_type': 'cert', 'access_to': ''},
         {'access_type': 'cert', 'access_to': ' '},
@@ -854,8 +831,11 @@ class ShareActionsTest(test.TestCase):
         id = 'fake_share_id'
         body = {'os-allow_access': access}
         req = fakes.HTTPRequest.blank('/v1/tenant1/shares/%s/action' % id)
+
         self.assertRaises(webob.exc.HTTPBadRequest,
                           self.controller._allow_access, req, id, body)
+        self.mock_policy_check.assert_called_once_with(
+            req.environ['manila.context'], 'share', 'allow_access')
 
     def test_deny_access(self):
         def _stub_deny_access(*args, **kwargs):
@@ -867,8 +847,12 @@ class ShareActionsTest(test.TestCase):
         id = 'fake_share_id'
         body = {"os-deny_access": {"access_id": 'fake_acces_id'}}
         req = fakes.HTTPRequest.blank('/v1/tenant1/shares/%s/action' % id)
+
         res = self.controller._deny_access(req, id, body)
+
         self.assertEqual(202, res.status_int)
+        self.mock_policy_check.assert_called_once_with(
+            req.environ['manila.context'], 'share', 'deny_access')
 
     def test_deny_access_not_found(self):
         def _stub_deny_access(*args, **kwargs):
@@ -880,27 +864,48 @@ class ShareActionsTest(test.TestCase):
         id = 'super_fake_share_id'
         body = {"os-deny_access": {"access_id": 'fake_acces_id'}}
         req = fakes.HTTPRequest.blank('/v1/tenant1/shares/%s/action' % id)
+
         self.assertRaises(webob.exc.HTTPNotFound,
                           self.controller._deny_access,
                           req,
                           id,
                           body)
+        self.mock_policy_check.assert_called_once_with(
+            req.environ['manila.context'], 'share', 'deny_access')
+
+    @ddt.data('_allow_access', '_deny_access')
+    def test_allow_access_deny_access_policy_not_authorized(self, method):
+        req = fakes.HTTPRequest.blank('/v1/tenant1/shares/someuuid/action')
+        action = method[1:]
+        body = {action: None}
+        noauthexc = exception.PolicyNotAuthorized(action=action)
+        with mock.patch.object(
+                policy, 'check_policy', mock.Mock(side_effect=noauthexc)):
+            method = getattr(self.controller, method)
+
+            self.assertRaises(
+                webob.exc.HTTPForbidden, method, req, body, 'someuuid')
+            policy.check_policy.assert_called_once_with(
+                req.environ['manila.context'], 'share', action)
 
     def test_access_list(self):
-        def _fake_access_get_all(*args, **kwargs):
-            return [{"state": "fakestatus",
-                     "id": "fake_share_id",
-                     "access_type": "fakeip",
-                     "access_to": "127.0.0.1"}]
-
-        self.mock_object(share_api.API, "access_get_all",
-                         _fake_access_get_all)
+        fake_access_list = [
+            {
+                "state": "fakestatus",
+                "id": "fake_access_id",
+                "access_type": "fakeip",
+                "access_to": "127.0.0.1",
+            }
+        ]
+        self.mock_object(self.controller._access_view_builder, 'list_view',
+                         mock.Mock(return_value={'access_list':
+                                                 fake_access_list}))
         id = 'fake_share_id'
         body = {"os-access_list": None}
         req = fakes.HTTPRequest.blank('/v1/tenant1/shares/%s/action' % id)
+
         res_dict = self.controller._access_list(req, id, body)
-        expected = _fake_access_get_all()
-        self.assertEqual(expected, res_dict['access_list'])
+        self.assertEqual({'access_list': fake_access_list}, res_dict)
 
     def test_extend(self):
         id = 'fake_share_id'
