@@ -53,7 +53,7 @@ class ShareGroupAPITest(test.TestCase):
         self.fake_share_type = {'id': six.text_type(uuidutils.generate_uuid())}
         self.fake_share_group_type = {
             'id': six.text_type(uuidutils.generate_uuid())}
-        self.api_version = '2.31'
+        self.api_version = '2.34'
         self.request = fakes.HTTPRequest.blank(
             '/share-groups', version=self.api_version, experimental=True)
         self.flags(rpc_backend='manila.openstack.common.rpc.impl_fake')
@@ -91,9 +91,11 @@ class ShareGroupAPITest(test.TestCase):
             'user_id': 'fakeuser',
             'project_id': 'fakeproject',
             'status': constants.STATUS_CREATING,
-            'name': None,
-            'description': None,
+            'name': 'fake name',
+            'description': 'fake description',
             'host': None,
+            'availability_zone': None,
+            'consistent_snapshot_support': None,
             'source_share_group_snapshot_id': None,
             'share_group_type_id': self.fake_share_group_type.get('id'),
             'share_network_id': uuidutils.generate_uuid(),
@@ -111,6 +113,9 @@ class ShareGroupAPITest(test.TestCase):
             'name': share_group_db_dict['name'],
             'description': share_group_db_dict['description'],
             'host': share_group_db_dict['host'],
+            'availability_zone': share_group_db_dict['availability_zone'],
+            'consistent_snapshot_support': share_group_db_dict[
+                'consistent_snapshot_support'],
             'source_share_group_snapshot_id': share_group_db_dict[
                 'source_share_group_snapshot_id'],
             'share_group_type_id': share_group_db_dict['share_group_type_id'],
@@ -236,6 +241,92 @@ class ShareGroupAPITest(test.TestCase):
         self.mock_policy_check.assert_called_once_with(
             self.context, self.resource_name, 'create')
 
+    def test_share_group_create_with_az(self):
+        fake_az_name = 'fake_az_name'
+        fake_az_id = 'fake_az_id'
+        fake_share_group, expected_share_group = self._get_fake_share_group(
+            availability_zone_id=fake_az_id)
+        self.mock_object(
+            self.controller.share_group_api, 'create',
+            mock.Mock(return_value=fake_share_group))
+        self.mock_object(
+            share_groups.db, 'availability_zone_get',
+            mock.Mock(return_value=type(
+                'FakeAZ', (object, ), {
+                    'id': fake_az_id,
+                    'name': fake_az_name,
+                })))
+
+        body = {"share_group": {"availability_zone": fake_az_name}}
+
+        res_dict = self.controller.create(self.request, body)
+
+        self.controller.share_group_api.create.assert_called_once_with(
+            self.context, availability_zone_id=fake_az_id,
+            share_group_type_id=self.fake_share_group_type['id'],
+            share_type_ids=[self.fake_share_type['id']])
+        share_groups.db.availability_zone_get.assert_called_once_with(
+            self.context, fake_az_name)
+        self.assertEqual(expected_share_group, res_dict['share_group'])
+        self.mock_policy_check.assert_called_once_with(
+            self.context, self.resource_name, 'create')
+
+    def test_share_group_create_with_az_and_source_share_group_snapshot(self):
+        fake_az_name = 'fake_az_name'
+        fake_az_id = 'fake_az_id'
+        fake_share_group, expected_share_group = self._get_fake_share_group(
+            availability_zone_id=fake_az_id)
+        self.mock_object(
+            self.controller.share_group_api, 'create',
+            mock.Mock(return_value=fake_share_group))
+        self.mock_object(
+            share_groups.db, 'availability_zone_get',
+            mock.Mock(return_value=type(
+                'FakeAZ', (object, ), {
+                    'id': fake_az_id,
+                    'name': fake_az_name,
+                })))
+
+        body = {"share_group": {
+            "availability_zone": fake_az_name,
+            "source_share_group_snapshot_id": 'fake_sgs_id',
+        }}
+
+        self.assertRaises(
+            webob.exc.HTTPBadRequest,
+            self.controller.create,
+            self.request, body)
+
+        self.controller.share_group_api.create.assert_not_called()
+        share_groups.db.availability_zone_get.assert_not_called()
+        self.mock_policy_check.assert_called_once_with(
+            self.context, self.resource_name, 'create')
+
+    def test_share_group_create_with_nonexistent_az(self):
+        fake_az_name = 'fake_az_name'
+        fake_az_id = 'fake_az_id'
+        fake_share_group, expected_share_group = self._get_fake_share_group(
+            availability_zone_id=fake_az_id)
+        self.mock_object(
+            self.controller.share_group_api, 'create',
+            mock.Mock(return_value=fake_share_group))
+        self.mock_object(
+            share_groups.db, 'availability_zone_get',
+            mock.Mock(
+                side_effect=exception.AvailabilityZoneNotFound(id=fake_az_id)))
+
+        body = {"share_group": {"availability_zone": fake_az_name}}
+
+        self.assertRaises(
+            webob.exc.HTTPNotFound,
+            self.controller.create, self.request, body)
+
+        self.assertEqual(0, self.controller.share_group_api.create.call_count)
+        share_groups.db.availability_zone_get.assert_called_once_with(
+            self.context, fake_az_name)
+        self.mock_policy_check.assert_called_once_with(
+            self.context, self.resource_name, 'create')
+
     def test_share_group_create_with_name(self):
         fake_name = 'fake_name'
         fake_share_group, expected_share_group = self._get_fake_share_group(
@@ -509,7 +600,7 @@ class ShareGroupAPITest(test.TestCase):
                                 self.controller.create,
                                 self.request, body)
 
-        self.assertTrue('unknown_field' in six.text_type(exc))
+        self.assertIn('unknown_field', six.text_type(exc))
         self.mock_policy_check.assert_called_once_with(
             self.context, self.resource_name, 'create')
 
@@ -586,7 +677,7 @@ class ShareGroupAPITest(test.TestCase):
                                 self.controller.update,
                                 self.request, 'fake_id', body)
 
-        self.assertTrue('unknown_field' in six.text_type(exc))
+        self.assertIn('unknown_field', six.text_type(exc))
         self.mock_policy_check.assert_called_once_with(
             self.context, self.resource_name, 'update')
 
@@ -597,7 +688,7 @@ class ShareGroupAPITest(test.TestCase):
                                 self.controller.update,
                                 self.request, 'fake_id', body)
 
-        self.assertTrue('share_types' in six.text_type(exc))
+        self.assertIn('share_types', six.text_type(exc))
         self.mock_policy_check.assert_called_once_with(
             self.context, self.resource_name, 'update')
 
@@ -658,6 +749,28 @@ class ShareGroupAPITest(test.TestCase):
         self.mock_policy_check.assert_called_once_with(
             req_context, self.resource_name, 'get_all')
 
+    def test_share_group_list_index_with_like_filter(self):
+        fake, expected = self._get_fake_simple_share_group(
+            name='fake_1', description='fake_ds_1')
+        fake2, expected2 = self._get_fake_simple_share_group(
+            name='fake_2', description='fake_ds_2')
+        self.mock_object(share_group_api.API, 'get_all',
+                         mock.Mock(return_value=[fake, fake2]))
+        req = fakes.HTTPRequest.blank(
+            '/share-groups?name~=fake&description~=fake',
+            version='2.36',
+            experimental=True)
+        req_context = req.environ['manila.context']
+
+        res_dict = self.controller.index(req)
+
+        expected.pop('description')
+        expected2.pop('description')
+        self.assertEqual(2, len(res_dict['share_groups']))
+        self.assertEqual([expected, expected2], res_dict['share_groups'])
+        self.mock_policy_check.assert_called_once_with(
+            req_context, self.resource_name, 'get_all')
+
     def test_share_group_list_detail(self):
         fake, expected = self._get_fake_share_group()
         self.mock_object(
