@@ -39,7 +39,6 @@ class ShareInstancesAPITest(test.TestCase):
         super(self.__class__, self).setUp()
         self.controller = share_instances.ShareInstancesController()
         self.resource_name = self.controller.resource_name
-        self.context = context.RequestContext('admin', 'fake', True)
         self.mock_policy_check = self.mock_object(
             policy, 'check_policy', mock.Mock(return_value=True))
         self.admin_context = context.RequestContext('admin', 'fake', True)
@@ -60,7 +59,7 @@ class ShareInstancesAPITest(test.TestCase):
     def _get_request(self, uri, context=None, version="2.3"):
         if context is None:
             context = self.admin_context
-        req = fakes.HTTPRequest.blank('/shares', version=version)
+        req = fakes.HTTPRequest.blank(uri, version=version)
         req.environ['manila.context'] = context
         return req
 
@@ -69,8 +68,13 @@ class ShareInstancesAPITest(test.TestCase):
         self.assertEqual([i['id'] for i in expected],
                          [i['id'] for i in actual])
 
-    def test_index(self):
-        req = self._get_request('/share_instances')
+    @ddt.data("2.3", "2.34", "2.35")
+    def test_index(self, version):
+        url = '/share_instances'
+        if (api_version_request.APIVersionRequest(version) >=
+                api_version_request.APIVersionRequest('2.35')):
+            url += "?export_location_path=/admin/export/location"
+        req = self._get_request(url, version=version)
         req_context = req.environ['manila.context']
         share_instances_count = 3
         test_instances = [
@@ -78,10 +82,44 @@ class ShareInstancesAPITest(test.TestCase):
             for s in range(0, share_instances_count)
         ]
 
+        db.share_export_locations_update(
+            self.admin_context, test_instances[0]['id'],
+            '/admin/export/location', False)
+
+        actual_result = self.controller.index(req)
+
+        if (api_version_request.APIVersionRequest(version) >=
+                api_version_request.APIVersionRequest('2.35')):
+            test_instances = test_instances[:1]
+        self._validate_ids_in_share_instances_list(
+            test_instances, actual_result['share_instances'])
+        self.mock_policy_check.assert_called_once_with(
+            req_context, self.resource_name, 'index')
+
+    def test_index_with_limit(self):
+        req = self._get_request('/share_instances')
+        req_context = req.environ['manila.context']
+        share_instances_count = 3
+        test_instances = [
+            db_utils.create_share(size=s + 1).instance
+            for s in range(0, share_instances_count)
+        ]
+        expect_links = [
+            {
+                'href': (
+                    'http://localhost/v1/fake/share_instances?'
+                    'limit=3&marker=%s' % test_instances[2]['id']),
+                'rel': 'next',
+            }
+        ]
+
+        url = 'share_instances?limit=3'
+        req = self._get_request(url)
         actual_result = self.controller.index(req)
 
         self._validate_ids_in_share_instances_list(
             test_instances, actual_result['share_instances'])
+        self.assertEqual(expect_links, actual_result['share_instances_links'])
         self.mock_policy_check.assert_called_once_with(
             req_context, self.resource_name, 'index')
 
@@ -232,6 +270,20 @@ class ShareInstancesAPITest(test.TestCase):
         self._reset_status(ctxt, instance, req, db.share_instance_get,
                            valid_code, valid_status, version=version)
 
+    @ddt.data(*fakes.fixture_valid_reset_status_body)
+    @ddt.unpack
+    def test_share_instance_reset_status(self, body, version):
+        instance, req = self._setup_share_instance_data()
+        req.headers['X-Openstack-Manila-Api-Version'] = version
+
+        if float(version) > 2.6:
+            state = body['reset_status']['status']
+        else:
+            state = body['os-reset_status']['status']
+        self._reset_status(self.admin_context, instance, req,
+                           db.share_instance_get, 202,
+                           state, body, version=version)
+
     @ddt.data(
         ({'os-reset_status': {'x-status': 'bad'}}, '2.6'),
         ({'os-reset_status': {'status': 'invalid'}}, '2.6'),
