@@ -41,7 +41,7 @@ class DataManagerTestCase(test.TestCase):
         self.context = context.get_admin_context()
         self.topic = 'fake_topic'
         self.share = db_utils.create_share()
-        manager.CONF.set_default('migration_tmp_location', '/tmp/')
+        manager.CONF.set_default('mount_tmp_location', '/tmp/')
 
     def test_init(self):
         manager = self.manager
@@ -71,17 +71,15 @@ class DataManagerTestCase(test.TestCase):
             utils.IsAMatcher(context.RequestContext), share['id'],
             {'task_state': constants.TASK_STATE_DATA_COPYING_ERROR})
 
-    @ddt.data({'notify': True, 'exc': None},
-              {'notify': False, 'exc': None},
-              {'notify': 'fake',
-               'exc': exception.ShareDataCopyCancelled(src_instance='ins1',
-                                                       dest_instance='ins2')},
-              {'notify': 'fake', 'exc': Exception('fake')})
-    @ddt.unpack
-    def test_migration_start(self, notify, exc):
+    @ddt.data(None, Exception('fake'), exception.ShareDataCopyCancelled(
+        src_instance='ins1',
+        dest_instance='ins2'))
+    def test_migration_start(self, exc):
 
         # mocks
         self.mock_object(db, 'share_get', mock.Mock(return_value=self.share))
+        self.mock_object(db, 'share_instance_get', mock.Mock(
+            return_value=self.share.instance))
 
         self.mock_object(data_utils, 'Copy',
                          mock.Mock(return_value='fake_copy'))
@@ -102,12 +100,12 @@ class DataManagerTestCase(test.TestCase):
         if exc is None or isinstance(exc, exception.ShareDataCopyCancelled):
             self.manager.migration_start(
                 self.context, [], self.share['id'],
-                'ins1_id', 'ins2_id', 'info_src', 'info_dest', notify)
+                'ins1_id', 'ins2_id', 'info_src', 'info_dest')
         else:
             self.assertRaises(
                 exception.ShareDataCopyFailed, self.manager.migration_start,
                 self.context, [], self.share['id'], 'ins1_id', 'ins2_id',
-                'info_src', 'info_dest', notify)
+                'info_src', 'info_dest')
 
             db.share_update.assert_called_once_with(
                 self.context, self.share['id'],
@@ -120,9 +118,9 @@ class DataManagerTestCase(test.TestCase):
             self.context, 'fake_copy', self.share, 'ins1_id', 'ins2_id',
             'info_src', 'info_dest')
 
-        if notify or exc:
+        if exc:
             share_rpc.ShareAPI.migration_complete.assert_called_once_with(
-                self.context, self.share, 'ins1_id', 'ins2_id')
+                self.context, self.share.instance, 'ins2_id')
 
     @ddt.data({'cancelled': False, 'exc': None},
               {'cancelled': False, 'exc': Exception('fake')},
@@ -132,10 +130,10 @@ class DataManagerTestCase(test.TestCase):
 
         access = db_utils.create_access(share_id=self.share['id'])
 
-        migration_info_src = {'mount': 'mount_cmd_src',
-                              'unmount': 'unmount_cmd_src'}
-        migration_info_dest = {'mount': 'mount_cmd_dest',
-                               'unmount': 'unmount_cmd_dest'}
+        connection_info_src = {'mount': 'mount_cmd_src',
+                               'unmount': 'unmount_cmd_src'}
+        connection_info_dest = {'mount': 'mount_cmd_dest',
+                                'unmount': 'unmount_cmd_dest'}
 
         get_progress = {'total_progress': 100}
 
@@ -143,10 +141,12 @@ class DataManagerTestCase(test.TestCase):
         fake_copy = mock.MagicMock(cancelled=cancelled)
 
         self.mock_object(db, 'share_update')
-
+        self.mock_object(db, 'share_instance_get',
+                         mock.Mock(side_effect=[self.share['instance'],
+                                                self.share['instance']]))
         self.mock_object(helper.DataServiceHelper,
                          'allow_access_to_data_service',
-                         mock.Mock(return_value=access))
+                         mock.Mock(return_value=[access]))
 
         self.mock_object(helper.DataServiceHelper, 'mount_share_instance')
 
@@ -169,8 +169,8 @@ class DataManagerTestCase(test.TestCase):
             self.assertRaises(
                 exception.ShareDataCopyCancelled,
                 self.manager._copy_share_data, self.context, fake_copy,
-                self.share, 'ins1_id', 'ins2_id', migration_info_src,
-                migration_info_dest)
+                self.share, 'ins1_id', 'ins2_id', connection_info_src,
+                connection_info_dest)
             extra_updates = [
                 mock.call(
                     self.context, self.share['id'],
@@ -186,12 +186,12 @@ class DataManagerTestCase(test.TestCase):
             self.assertRaises(
                 exception.ShareDataCopyFailed, self.manager._copy_share_data,
                 self.context, fake_copy, self.share, 'ins1_id',
-                'ins2_id', migration_info_src, migration_info_dest)
+                'ins2_id', connection_info_src, connection_info_dest)
 
         else:
             self.manager._copy_share_data(
                 self.context, fake_copy, self.share, 'ins1_id',
-                'ins2_id', migration_info_src, migration_info_dest)
+                'ins2_id', connection_info_src, connection_info_dest)
             extra_updates = [
                 mock.call(
                     self.context, self.share['id'],
@@ -220,35 +220,43 @@ class DataManagerTestCase(test.TestCase):
 
         db.share_update.assert_has_calls(update_list)
 
-        helper.DataServiceHelper.allow_access_to_data_service.\
-            assert_called_once_with(self.share, 'ins1_id', 'ins2_id')
+        (helper.DataServiceHelper.allow_access_to_data_service.
+            assert_called_once_with(
+                self.share['instance'], connection_info_src,
+                self.share['instance'], connection_info_dest))
 
         helper.DataServiceHelper.mount_share_instance.assert_has_calls([
-            mock.call(migration_info_src['mount'], '/tmp/', 'ins1_id'),
-            mock.call(migration_info_dest['mount'], '/tmp/', 'ins2_id')])
+            mock.call(connection_info_src['mount'], '/tmp/',
+                      self.share['instance']),
+            mock.call(connection_info_dest['mount'], '/tmp/',
+                      self.share['instance'])])
 
         fake_copy.run.assert_called_once_with()
         if exc is None:
             fake_copy.get_progress.assert_called_once_with()
 
         helper.DataServiceHelper.unmount_share_instance.assert_has_calls([
-            mock.call(migration_info_src['unmount'], '/tmp/', 'ins1_id'),
-            mock.call(migration_info_dest['unmount'], '/tmp/', 'ins2_id')])
+            mock.call(connection_info_src['unmount'], '/tmp/', 'ins1_id'),
+            mock.call(connection_info_dest['unmount'], '/tmp/', 'ins2_id')])
 
         helper.DataServiceHelper.deny_access_to_data_service.assert_has_calls([
-            mock.call(access, 'ins1_id'), mock.call(access, 'ins2_id')])
+            mock.call([access], self.share['instance']),
+            mock.call([access], self.share['instance'])])
 
     def test__copy_share_data_exception_access(self):
 
-        migration_info_src = {'mount': 'mount_cmd_src',
-                              'unmount': 'unmount_cmd_src'}
-        migration_info_dest = {'mount': 'mount_cmd_src',
+        connection_info_src = {'mount': 'mount_cmd_src',
                                'unmount': 'unmount_cmd_src'}
+        connection_info_dest = {'mount': 'mount_cmd_src',
+                                'unmount': 'unmount_cmd_src'}
 
         fake_copy = mock.MagicMock(cancelled=False)
 
         # mocks
         self.mock_object(db, 'share_update')
+        self.mock_object(db, 'share_instance_get',
+                         mock.Mock(side_effect=[self.share['instance'],
+                                                self.share['instance']]))
 
         self.mock_object(
             helper.DataServiceHelper, 'allow_access_to_data_service',
@@ -261,33 +269,38 @@ class DataManagerTestCase(test.TestCase):
         self.assertRaises(exception.ShareDataCopyFailed,
                           self.manager._copy_share_data, self.context,
                           fake_copy, self.share, 'ins1_id', 'ins2_id',
-                          migration_info_src, migration_info_dest)
+                          connection_info_src, connection_info_dest)
 
         # asserts
         db.share_update.assert_called_once_with(
             self.context, self.share['id'],
             {'task_state': constants.TASK_STATE_DATA_COPYING_STARTING})
 
-        helper.DataServiceHelper.allow_access_to_data_service.\
-            assert_called_once_with(self.share, 'ins1_id', 'ins2_id')
+        (helper.DataServiceHelper.allow_access_to_data_service.
+            assert_called_once_with(
+                self.share['instance'], connection_info_src,
+                self.share['instance'], connection_info_dest))
 
     def test__copy_share_data_exception_mount_1(self):
 
         access = db_utils.create_access(share_id=self.share['id'])
 
-        migration_info_src = {'mount': 'mount_cmd_src',
-                              'unmount': 'unmount_cmd_src'}
-        migration_info_dest = {'mount': 'mount_cmd_src',
+        connection_info_src = {'mount': 'mount_cmd_src',
                                'unmount': 'unmount_cmd_src'}
+        connection_info_dest = {'mount': 'mount_cmd_src',
+                                'unmount': 'unmount_cmd_src'}
 
         fake_copy = mock.MagicMock(cancelled=False)
 
         # mocks
         self.mock_object(db, 'share_update')
+        self.mock_object(db, 'share_instance_get',
+                         mock.Mock(side_effect=[self.share['instance'],
+                                                self.share['instance']]))
 
         self.mock_object(helper.DataServiceHelper,
                          'allow_access_to_data_service',
-                         mock.Mock(return_value=access))
+                         mock.Mock(return_value=[access]))
 
         self.mock_object(helper.DataServiceHelper, 'mount_share_instance',
                          mock.Mock(side_effect=Exception('fake')))
@@ -299,42 +312,47 @@ class DataManagerTestCase(test.TestCase):
         self.assertRaises(exception.ShareDataCopyFailed,
                           self.manager._copy_share_data, self.context,
                           fake_copy, self.share, 'ins1_id', 'ins2_id',
-                          migration_info_src, migration_info_dest)
+                          connection_info_src, connection_info_dest)
 
         # asserts
         db.share_update.assert_called_once_with(
             self.context, self.share['id'],
             {'task_state': constants.TASK_STATE_DATA_COPYING_STARTING})
 
-        helper.DataServiceHelper.allow_access_to_data_service.\
-            assert_called_once_with(self.share, 'ins1_id', 'ins2_id')
+        (helper.DataServiceHelper.allow_access_to_data_service.
+            assert_called_once_with(
+                self.share['instance'], connection_info_src,
+                self.share['instance'], connection_info_dest))
 
         helper.DataServiceHelper.mount_share_instance.assert_called_once_with(
-            migration_info_src['mount'], '/tmp/', 'ins1_id')
+            connection_info_src['mount'], '/tmp/', self.share['instance'])
 
         helper.DataServiceHelper.cleanup_temp_folder.assert_called_once_with(
             'ins1_id', '/tmp/')
 
         helper.DataServiceHelper.cleanup_data_access.assert_has_calls([
-            mock.call(access, 'ins2_id'), mock.call(access, 'ins1_id')])
+            mock.call([access], 'ins2_id'), mock.call([access], 'ins1_id')])
 
     def test__copy_share_data_exception_mount_2(self):
 
         access = db_utils.create_access(share_id=self.share['id'])
 
-        migration_info_src = {'mount': 'mount_cmd_src',
-                              'unmount': 'unmount_cmd_src'}
-        migration_info_dest = {'mount': 'mount_cmd_src',
+        connection_info_src = {'mount': 'mount_cmd_src',
                                'unmount': 'unmount_cmd_src'}
+        connection_info_dest = {'mount': 'mount_cmd_src',
+                                'unmount': 'unmount_cmd_src'}
 
         fake_copy = mock.MagicMock(cancelled=False)
 
         # mocks
         self.mock_object(db, 'share_update')
+        self.mock_object(db, 'share_instance_get',
+                         mock.Mock(side_effect=[self.share['instance'],
+                                                self.share['instance']]))
 
         self.mock_object(helper.DataServiceHelper,
                          'allow_access_to_data_service',
-                         mock.Mock(return_value=access))
+                         mock.Mock(return_value=[access]))
 
         self.mock_object(helper.DataServiceHelper, 'mount_share_instance',
                          mock.Mock(side_effect=[None, Exception('fake')]))
@@ -348,29 +366,33 @@ class DataManagerTestCase(test.TestCase):
         self.assertRaises(exception.ShareDataCopyFailed,
                           self.manager._copy_share_data, self.context,
                           fake_copy, self.share, 'ins1_id', 'ins2_id',
-                          migration_info_src, migration_info_dest)
+                          connection_info_src, connection_info_dest)
 
         # asserts
         db.share_update.assert_called_once_with(
             self.context, self.share['id'],
             {'task_state': constants.TASK_STATE_DATA_COPYING_STARTING})
 
-        helper.DataServiceHelper.allow_access_to_data_service.\
-            assert_called_once_with(self.share, 'ins1_id', 'ins2_id')
+        (helper.DataServiceHelper.allow_access_to_data_service.
+            assert_called_once_with(
+                self.share['instance'], connection_info_src,
+                self.share['instance'], connection_info_dest))
 
         helper.DataServiceHelper.mount_share_instance.assert_has_calls([
-            mock.call(migration_info_src['mount'], '/tmp/', 'ins1_id'),
-            mock.call(migration_info_dest['mount'], '/tmp/', 'ins2_id')])
+            mock.call(connection_info_src['mount'], '/tmp/',
+                      self.share['instance']),
+            mock.call(connection_info_dest['mount'], '/tmp/',
+                      self.share['instance'])])
 
-        helper.DataServiceHelper.cleanup_unmount_temp_folder.\
+        (helper.DataServiceHelper.cleanup_unmount_temp_folder.
             assert_called_once_with(
-                migration_info_src['unmount'], '/tmp/', 'ins1_id')
+                connection_info_src['unmount'], '/tmp/', 'ins1_id'))
 
         helper.DataServiceHelper.cleanup_temp_folder.assert_has_calls([
             mock.call('ins2_id', '/tmp/'), mock.call('ins1_id', '/tmp/')])
 
         helper.DataServiceHelper.cleanup_data_access.assert_has_calls([
-            mock.call(access, 'ins2_id'), mock.call(access, 'ins1_id')])
+            mock.call([access], 'ins2_id'), mock.call([access], 'ins1_id')])
 
     def test_data_copy_cancel(self):
 
