@@ -149,7 +149,7 @@ class ManilaMigrationsCheckers(test_migrations.WalkVersionsMixin,
     def test_walk_versions(self):
         """Walks all version scripts for each tested database.
 
-        While walking, ensur that there are no errors in the version
+        While walking, ensure that there are no errors in the version
         scripts for each engine.
         """
         with mock.patch('manila.db.sqlalchemy.api.get_engine',
@@ -186,7 +186,7 @@ class TestManilaMigrationsMySQL(ManilaMigrationsCheckers,
             text(sanity_check),
             database=self.engine.url.database)
 
-        self.assertTrue(total.scalar() > 0, "No tables found. Wrong schema?")
+        self.assertGreater(total.scalar(), 0, "No tables found. Wrong schema?")
 
         noninnodb_query = """
             SELECT count(*)
