@@ -19,13 +19,13 @@ from neutronclient.common import exceptions as neutron_client_exc
 from neutronclient.v2_0 import client as clientv20
 from oslo_config import cfg
 
-from manila import context
 from manila.db import base
 from manila import exception
 from manila.network.neutron import api as neutron_api
 from manila.network.neutron import constants as neutron_constants
 from manila import test
 from manila.tests.db import fakes
+from manila.tests import utils as test_utils
 
 CONF = cfg.CONF
 
@@ -81,11 +81,76 @@ class FakeNeutronClient(object):
         pass
 
 
+class NeutronclientTestCase(test.TestCase):
+
+    def test_no_auth_obj(self):
+        mock_client_loader = self.mock_object(
+            neutron_api.client_auth, 'AuthClientLoader')
+        fake_context = 'fake_context'
+        data = {
+            'DEFAULT': {
+                'neutron_admin_username': 'foo_username',
+                'neutron_admin_password': 'foo_password',
+                'neutron_admin_tenant_name': 'foo_tenant_name',
+                'neutron_admin_auth_url': 'foo_auth_url',
+            },
+            'neutron': {
+                'endpoint_type': 'foo_endpoint_type',
+                'region_name': 'foo_region_name',
+            }
+        }
+
+        self.client = None
+        with test_utils.create_temp_config_with_opts(data):
+            self.client = neutron_api.API()
+            self.client.get_client(fake_context)
+
+        mock_client_loader.assert_called_once_with(
+            client_class=neutron_api.clientv20.Client,
+            exception_module=neutron_api.neutron_client_exc,
+            cfg_group=neutron_api.NEUTRON_GROUP,
+            deprecated_opts_for_v2={
+                'username': data['DEFAULT']['neutron_admin_username'],
+                'password': data['DEFAULT']['neutron_admin_password'],
+                'tenant_name': data['DEFAULT']['neutron_admin_tenant_name'],
+                'auth_url': data['DEFAULT']['neutron_admin_auth_url'],
+            },
+        )
+        mock_client_loader.return_value.get_client.assert_called_once_with(
+            self.client,
+            fake_context,
+            endpoint_type=data['neutron']['endpoint_type'],
+            region_name=data['neutron']['region_name'],
+        )
+
+    def test_with_auth_obj(self):
+        fake_context = 'fake_context'
+        data = {
+            'neutron': {
+                'endpoint_type': 'foo_endpoint_type',
+                'region_name': 'foo_region_name',
+            }
+        }
+
+        self.client = None
+        with test_utils.create_temp_config_with_opts(data):
+            self.client = neutron_api.API()
+            self.client.auth_obj = type(
+                'FakeAuthObj', (object, ), {'get_client': mock.Mock()})
+            self.client.get_client(fake_context)
+
+        self.client.auth_obj.get_client.assert_called_once_with(
+            self.client,
+            fake_context,
+            endpoint_type=data['neutron']['endpoint_type'],
+            region_name=data['neutron']['region_name'],
+        )
+
+
 class NeutronApiTest(test.TestCase):
 
     def setUp(self):
         super(NeutronApiTest, self).setUp()
-        self.context = context.get_admin_context()
         self.mock_object(base, 'Base', fakes.FakeModel)
         self.mock_object(
             clientv20, 'Client', mock.Mock(return_value=FakeNeutronClient()))
@@ -150,8 +215,6 @@ class NeutronApiTest(test.TestCase):
 
     def test_create_port_with_required_args(self):
         # Set up test data
-        self.mock_object(self.neutron_api, '_has_port_binding_extension',
-                         mock.Mock(return_value=True))
         port_args = {'tenant_id': 'test tenant', 'network_id': 'test net'}
 
         # Execute method 'create_port'
@@ -161,13 +224,10 @@ class NeutronApiTest(test.TestCase):
         self.assertEqual(port_args['tenant_id'], port['tenant_id'])
         self.assertEqual(port_args['network_id'],
                          port['network_id'])
-        self.neutron_api._has_port_binding_extension.assert_called_once_with()
         self.assertTrue(clientv20.Client.called)
 
     def test_create_port_with_additional_kwargs(self):
         # Set up test data
-        self.mock_object(self.neutron_api, '_has_port_binding_extension',
-                         mock.Mock(return_value=True))
         port_args = {'tenant_id': 'test tenant', 'network_id': 'test net',
                      'binding_arg': 'foo'}
 
@@ -180,15 +240,22 @@ class NeutronApiTest(test.TestCase):
                          port['network_id'])
         self.assertEqual(port_args['binding_arg'],
                          port['binding_arg'])
-        self.neutron_api._has_port_binding_extension.assert_called_once_with()
         self.assertTrue(clientv20.Client.called)
 
+    def test_create_port_with_host_id_no_binding_ext(self):
+        self.mock_object(self.neutron_api, '_has_port_binding_extension',
+                         mock.Mock(return_value=False))
+        port_args = {
+            'tenant_id': 'test tenant',
+            'network_id': 'test net',
+            'host_id': 'foohost'
+        }
+
+        self.assertRaises(exception.NetworkException,
+                          self.neutron_api.create_port, **port_args)
+
     @mock.patch.object(neutron_api.LOG, 'exception', mock.Mock())
     def test_create_port_exception(self):
-        # Set up test data
-        self.mock_object(
-            self.neutron_api, '_has_port_binding_extension',
-            mock.Mock(return_value=True))
         self.mock_object(
             self.neutron_api.client, 'create_port',
             mock.Mock(side_effect=neutron_client_exc.NeutronClientException))
@@ -200,7 +267,6 @@ class NeutronApiTest(test.TestCase):
                           **port_args)
 
         # Verify results
-        self.neutron_api._has_port_binding_extension.assert_called_once_with()
         self.assertTrue(neutron_api.LOG.exception.called)
         self.assertTrue(clientv20.Client.called)
         self.assertTrue(self.neutron_api.client.create_port.called)
@@ -208,9 +274,6 @@ class NeutronApiTest(test.TestCase):
     @mock.patch.object(neutron_api.LOG, 'exception', mock.Mock())
     def test_create_port_exception_status_409(self):
         # Set up test data
-        self.mock_object(
-            self.neutron_api, '_has_port_binding_extension',
-            mock.Mock(return_value=True))
         self.mock_object(
             self.neutron_api.client, 'create_port',
             mock.Mock(side_effect=neutron_client_exc.NeutronClientException(
@@ -223,7 +286,6 @@ class NeutronApiTest(test.TestCase):
                           **port_args)
 
         # Verify results
-        self.neutron_api._has_port_binding_extension.assert_called_once_with()
         self.assertTrue(neutron_api.LOG.exception.called)
         self.assertTrue(clientv20.Client.called)
         self.assertTrue(self.neutron_api.client.create_port.called)
