@@ -70,7 +70,7 @@ class StandaloneNetworkPluginTest(test.TestCase):
                 'standalone_network_plugin_segmentation_id': 1001,
                 'standalone_network_plugin_allowed_ip_ranges': (
                     '10.0.0.3-10.0.0.7,10.0.0.69-10.0.0.157,10.0.0.213'),
-                'standalone_network_plugin_ip_version': 4,
+                'network_plugin_ipv4_enabled': True,
             },
         }
         allowed_cidrs = [
@@ -104,7 +104,7 @@ class StandaloneNetworkPluginTest(test.TestCase):
                 'standalone_network_plugin_gateway': (
                     '2001:cdba::3257:9652'),
                 'standalone_network_plugin_mask': '48',
-                'standalone_network_plugin_ip_version': 6,
+                'network_plugin_ipv6_enabled': True,
             },
         }
         with test_utils.create_temp_config_with_opts(data):
@@ -124,7 +124,8 @@ class StandaloneNetworkPluginTest(test.TestCase):
             ['2001:cdba::3257:9652/48'], instance.allowed_cidrs)
         self.assertEqual(
             ('2001:cdba::', '2001:cdba::3257:9652',
-             '2001:cdba:0:ffff:ffff:ffff:ffff:ffff'),
+             netaddr.IPAddress('2001:cdba:0:ffff:ffff:ffff:ffff:ffff').format()
+             ),
             instance.reserved_addresses)
 
     @ddt.data('custom_config_group_name', 'DEFAULT')
@@ -137,7 +138,7 @@ class StandaloneNetworkPluginTest(test.TestCase):
                 'standalone_network_plugin_segmentation_id': 3999,
                 'standalone_network_plugin_allowed_ip_ranges': (
                     '2001:db8::-2001:db8:0000:0000:0000:007f:ffff:ffff'),
-                'standalone_network_plugin_ip_version': 6,
+                'network_plugin_ipv6_enabled': True,
             },
         }
         with test_utils.create_temp_config_with_opts(data):
@@ -167,7 +168,7 @@ class StandaloneNetworkPluginTest(test.TestCase):
                 'standalone_network_plugin_mask': '255.255.0.0',
                 'standalone_network_plugin_network_type': network_type,
                 'standalone_network_plugin_segmentation_id': 1001,
-                'standalone_network_plugin_ip_version': 4,
+                'network_plugin_ipv4_enabled': True,
             },
         }
         with test_utils.create_temp_config_with_opts(data):
@@ -185,7 +186,7 @@ class StandaloneNetworkPluginTest(test.TestCase):
                 'standalone_network_plugin_mask': '255.255.0.0',
                 'standalone_network_plugin_network_type': fake_network_type,
                 'standalone_network_plugin_segmentation_id': 1001,
-                'standalone_network_plugin_ip_version': 4,
+                'network_plugin_ipv4_enabled': True,
             },
         }
         with test_utils.create_temp_config_with_opts(data):
@@ -254,10 +255,15 @@ class StandaloneNetworkPluginTest(test.TestCase):
         data = {
             group_name: {
                 'standalone_network_plugin_gateway': gateway,
-                'standalone_network_plugin_ip_version': vers,
                 'standalone_network_plugin_mask': '25',
             },
         }
+        if vers == 4:
+            data[group_name]['network_plugin_ipv4_enabled'] = True
+        if vers == 6:
+            data[group_name]['network_plugin_ipv4_enabled'] = False
+            data[group_name]['network_plugin_ipv6_enabled'] = True
+
         with test_utils.create_temp_config_with_opts(data):
             self.assertRaises(
                 exception.NetworkBadConfigurationException,
@@ -282,13 +288,13 @@ class StandaloneNetworkPluginTest(test.TestCase):
 
         instance.deallocate_network(fake_context, share_server_id)
 
-        instance.db.network_allocations_get_for_share_server.\
-            assert_called_once_with(fake_context, share_server_id)
-        instance.db.network_allocation_delete.\
+        (instance.db.network_allocations_get_for_share_server.
+            assert_called_once_with(fake_context, share_server_id))
+        (instance.db.network_allocation_delete.
             assert_has_calls([
                 mock.call(fake_context, 'fake1'),
                 mock.call(fake_context, 'fake2'),
-            ])
+            ]))
 
     def test_allocate_network_zero_addresses_ipv4(self):
         data = {
@@ -308,14 +314,17 @@ class StandaloneNetworkPluginTest(test.TestCase):
         instance.db.share_network_update.assert_called_once_with(
             fake_context, fake_share_network['id'],
             dict(network_type=None, segmentation_id=None,
-                 cidr=six.text_type(instance.net.cidr), ip_version=4))
+                 cidr=six.text_type(instance.net.cidr),
+                 gateway=six.text_type(instance.gateway),
+                 ip_version=4,
+                 mtu=1500))
 
     def test_allocate_network_zero_addresses_ipv6(self):
         data = {
             'DEFAULT': {
                 'standalone_network_plugin_gateway': '2001:db8::0001',
                 'standalone_network_plugin_mask': '64',
-                'standalone_network_plugin_ip_version': 6,
+                'network_plugin_ipv6_enabled': True,
             },
         }
         with test_utils.create_temp_config_with_opts(data):
@@ -329,7 +338,10 @@ class StandaloneNetworkPluginTest(test.TestCase):
         instance.db.share_network_update.assert_called_once_with(
             fake_context, fake_share_network['id'],
             dict(network_type=None, segmentation_id=None,
-                 cidr=six.text_type(instance.net.cidr), ip_version=6))
+                 cidr=six.text_type(instance.net.cidr),
+                 gateway=six.text_type(instance.gateway),
+                 ip_version=6,
+                 mtu=1500))
 
     def test_allocate_network_one_ip_address_ipv4_no_usages_exist(self):
         data = {
@@ -356,7 +368,9 @@ class StandaloneNetworkPluginTest(test.TestCase):
             'network_type': 'vlan',
             'segmentation_id': 1003,
             'cidr': '10.0.0.0/24',
+            'gateway': '10.0.0.1',
             'ip_version': 4,
+            'mtu': 1500,
         }
         instance.db.share_network_update.assert_called_once_with(
             fake_context, fake_share_network['id'], na_data)
@@ -400,7 +414,9 @@ class StandaloneNetworkPluginTest(test.TestCase):
             'network_type': None,
             'segmentation_id': None,
             'cidr': six.text_type(instance.net.cidr),
+            'gateway': six.text_type(instance.gateway),
             'ip_version': 4,
+            'mtu': 1500,
         }
         instance.db.share_network_update.assert_called_once_with(
             ctxt, fake_share_network['id'], dict(**na_data))
@@ -443,6 +459,9 @@ class StandaloneNetworkPluginTest(test.TestCase):
         instance.db.share_network_update.assert_called_once_with(
             fake_context, fake_share_network['id'],
             dict(network_type=None, segmentation_id=None,
-                 cidr=six.text_type(instance.net.cidr), ip_version=4))
+                 cidr=six.text_type(instance.net.cidr),
+                 gateway=six.text_type(instance.gateway),
+                 ip_version=4,
+                 mtu=1500))
         instance.db.network_allocations_get_by_ip_address.assert_has_calls(
             [mock.call(fake_context, '10.0.0.2')])
