@@ -98,8 +98,8 @@ class HostManagerTestCase(test.TestCase):
                 return True
 
             self.mock_object(FakeFilterClass1, '_filter_one', fake_filter_one)
-            result = self.host_manager.get_filtered_hosts(self.fake_hosts,
-                                                          fake_properties)
+            result, last_filter = self.host_manager.get_filtered_hosts(
+                self.fake_hosts, fake_properties)
             self._verify_result(info, result)
             self.host_manager._choose_host_filters.assert_called_once_with(
                 mock.ANY)
@@ -217,6 +217,7 @@ class HostManagerTestCase(test.TestCase):
                         'compression': False,
                         'replication_type': None,
                         'replication_domain': None,
+                        'sg_consistent_snapshot_support': None,
                     },
                 }, {
                     'name': 'host2@back1#BBB',
@@ -244,6 +245,7 @@ class HostManagerTestCase(test.TestCase):
                         'compression': False,
                         'replication_type': None,
                         'replication_domain': None,
+                        'sg_consistent_snapshot_support': None,
                     },
                 }, {
                     'name': 'host2@back2#CCC',
@@ -271,6 +273,7 @@ class HostManagerTestCase(test.TestCase):
                         'compression': False,
                         'replication_type': None,
                         'replication_domain': None,
+                        'sg_consistent_snapshot_support': None,
                     },
                 },
             ]
@@ -320,6 +323,7 @@ class HostManagerTestCase(test.TestCase):
                         'compression': False,
                         'replication_type': None,
                         'replication_domain': None,
+                        'sg_consistent_snapshot_support': None,
                     },
                 }, {
                     'name': 'host2@BBB#pool2',
@@ -348,6 +352,7 @@ class HostManagerTestCase(test.TestCase):
                         'compression': False,
                         'replication_type': None,
                         'replication_domain': None,
+                        'sg_consistent_snapshot_support': None,
                     },
                 }, {
                     'name': 'host3@CCC#pool3',
@@ -376,6 +381,7 @@ class HostManagerTestCase(test.TestCase):
                         'compression': False,
                         'replication_type': None,
                         'replication_domain': None,
+                        'sg_consistent_snapshot_support': None,
                     },
                 }, {
                     'name': 'host4@DDD#pool4a',
@@ -404,6 +410,7 @@ class HostManagerTestCase(test.TestCase):
                         'compression': False,
                         'replication_type': None,
                         'replication_domain': None,
+                        'sg_consistent_snapshot_support': None,
                     },
                 }, {
                     'name': 'host4@DDD#pool4b',
@@ -432,6 +439,7 @@ class HostManagerTestCase(test.TestCase):
                         'compression': False,
                         'replication_type': None,
                         'replication_domain': None,
+                        'sg_consistent_snapshot_support': None,
                     },
                 },
             ]
@@ -493,6 +501,7 @@ class HostManagerTestCase(test.TestCase):
                         'compression': False,
                         'replication_type': None,
                         'replication_domain': None,
+                        'sg_consistent_snapshot_support': None,
                     },
                 }, {
                     'name': 'host2@back1#BBB',
@@ -520,6 +529,7 @@ class HostManagerTestCase(test.TestCase):
                         'compression': False,
                         'replication_type': None,
                         'replication_domain': None,
+                        'sg_consistent_snapshot_support': None,
                     },
                 },
             ]
@@ -575,6 +585,7 @@ class HostManagerTestCase(test.TestCase):
                         'compression': False,
                         'replication_type': None,
                         'replication_domain': None,
+                        'sg_consistent_snapshot_support': None,
                     },
                 },
             ]
@@ -626,7 +637,9 @@ class HostStateTestCase(test.TestCase):
         share_capability = {'total_capacity_gb': 0,
                             'free_capacity_gb': 100,
                             'reserved_percentage': 0,
-                            'timestamp': None}
+                            'timestamp': None,
+                            'ipv4_support': True,
+                            'ipv6_support': False}
         fake_host = host_manager.HostState('host1', share_capability)
         self.assertIsNone(fake_host.free_capacity_gb)
 
@@ -635,9 +648,13 @@ class HostStateTestCase(test.TestCase):
         # Backend level stats remain uninitialized
         self.assertEqual(0, fake_host.total_capacity_gb)
         self.assertIsNone(fake_host.free_capacity_gb)
+        self.assertTrue(fake_host.ipv4_support)
+        self.assertFalse(fake_host.ipv6_support)
         # Pool stats has been updated
         self.assertEqual(0, fake_host.pools['_pool0'].total_capacity_gb)
         self.assertEqual(100, fake_host.pools['_pool0'].free_capacity_gb)
+        self.assertTrue(fake_host.pools['_pool0'].ipv4_support)
+        self.assertFalse(fake_host.pools['_pool0'].ipv6_support)
 
         # Test update for existing host state
         share_capability.update(dict(total_capacity_gb=1000))
@@ -663,6 +680,8 @@ class HostStateTestCase(test.TestCase):
             'vendor_name': 'OpenStack',
             'driver_version': '1.1',
             'storage_protocol': 'NFS_CIFS',
+            'ipv4_support': True,
+            'ipv6_support': False,
             'pools': [
                 {'pool_name': 'pool1',
                  'total_capacity_gb': 500,
@@ -696,6 +715,8 @@ class HostStateTestCase(test.TestCase):
         self.assertEqual('NFS_CIFS', fake_host.storage_protocol)
         self.assertEqual('OpenStack', fake_host.vendor_name)
         self.assertEqual('1.1', fake_host.driver_version)
+        self.assertTrue(fake_host.ipv4_support)
+        self.assertFalse(fake_host.ipv6_support)
 
         # Backend level stats remain uninitialized
         self.assertEqual(0, fake_host.total_capacity_gb)
@@ -705,8 +726,12 @@ class HostStateTestCase(test.TestCase):
 
         self.assertEqual(500, fake_host.pools['pool1'].total_capacity_gb)
         self.assertEqual(230, fake_host.pools['pool1'].free_capacity_gb)
+        self.assertTrue(fake_host.pools['pool1'].ipv4_support)
+        self.assertFalse(fake_host.pools['pool1'].ipv6_support)
         self.assertEqual(1024, fake_host.pools['pool2'].total_capacity_gb)
         self.assertEqual(1024, fake_host.pools['pool2'].free_capacity_gb)
+        self.assertTrue(fake_host.pools['pool2'].ipv4_support)
+        self.assertFalse(fake_host.pools['pool2'].ipv6_support)
 
         capability = {
             'share_backend_name': 'Backend1',
@@ -825,9 +850,9 @@ class HostStateTestCase(test.TestCase):
                                                context=fake_context)
 
         result = fake_host.__repr__()
-        expected = "host: 'host1', free_capacity_gb: None, " \
-                   "pools: {'Backend1': host: 'host1#Backend1', " \
-                   "free_capacity_gb: 15000, pools: None}"
+        expected = ("host: 'host1', free_capacity_gb: None, "
+                    "pools: {'Backend1': host: 'host1#Backend1', "
+                    "free_capacity_gb: 15000, pools: None}")
         self.assertEqual(expected, result)
 
 
@@ -861,14 +886,17 @@ class PoolStateTestCase(test.TestCase):
             'share_capability':
                 {'total_capacity_gb': 1024, 'free_capacity_gb': 512,
                  'reserved_percentage': 0, 'timestamp': None,
-                 'cap1': 'val1', 'cap2': 'val2'},
+                 'cap1': 'val1', 'cap2': 'val2', 'ipv4_support': True,
+                 'ipv6_support': False},
             'instances': []
         },
         {
             'share_capability':
                 {'total_capacity_gb': 1024, 'free_capacity_gb': 512,
                  'allocated_capacity_gb': 256, 'reserved_percentage': 0,
-                 'timestamp': None, 'cap1': 'val1', 'cap2': 'val2'},
+                 'timestamp': None, 'cap1': 'val1', 'cap2': 'val2',
+                 'ipv4_support': False, 'ipv6_support': True
+                 },
             'instances':
                 [
                     {
@@ -883,14 +911,17 @@ class PoolStateTestCase(test.TestCase):
             'share_capability':
                 {'total_capacity_gb': 1024, 'free_capacity_gb': 512,
                  'allocated_capacity_gb': 256, 'reserved_percentage': 0,
-                 'timestamp': None, 'cap1': 'val1', 'cap2': 'val2'},
+                 'timestamp': None, 'cap1': 'val1', 'cap2': 'val2',
+                 'ipv4_support': True, 'ipv6_support': True},
             'instances': []
         },
         {
             'share_capability':
                 {'total_capacity_gb': 1024, 'free_capacity_gb': 512,
                  'provisioned_capacity_gb': 256, 'reserved_percentage': 0,
-                 'timestamp': None, 'cap1': 'val1', 'cap2': 'val2'},
+                 'timestamp': None, 'cap1': 'val1', 'cap2': 'val2',
+                 'ipv4_support': False, 'ipv6_support': False
+                 },
             'instances':
                 [
                     {
@@ -965,3 +996,9 @@ class PoolStateTestCase(test.TestCase):
                              fake_pool.allocated_capacity_gb)
             self.assertEqual(share_capability['provisioned_capacity_gb'],
                              fake_pool.provisioned_capacity_gb)
+        if 'ipv4_support' in share_capability:
+            self.assertEqual(share_capability['ipv4_support'],
+                             fake_pool.ipv4_support)
+        if 'ipv6_support' in share_capability:
+            self.assertEqual(share_capability['ipv6_support'],
+                             fake_pool.ipv6_support)
