@@ -17,6 +17,12 @@
 Tests For Scheduler Manager
 """
 
+try:
+    # Python3 variant
+    from importlib import reload
+except ImportError:
+    pass
+
 import ddt
 import mock
 from oslo_config import cfg
@@ -25,6 +31,8 @@ from manila.common import constants
 from manila import context
 from manila import db
 from manila import exception
+from manila.message import message_field
+from manila import quota
 from manila.scheduler.drivers import base
 from manila.scheduler.drivers import filter
 from manila.scheduler import manager
@@ -46,6 +54,19 @@ class SchedulerManagerTestCase(test.TestCase):
 
     def setUp(self):
         super(SchedulerManagerTestCase, self).setUp()
+        self.periodic_tasks = []
+
+        def _periodic_task(*args, **kwargs):
+            def decorator(f):
+                self.periodic_tasks.append(f)
+                return f
+            return mock.Mock(side_effect=decorator)
+
+        self.mock_periodic_task = self.mock_object(
+            manager.periodic_task, 'periodic_task',
+            mock.Mock(side_effect=_periodic_task))
+        reload(manager)
+
         self.flags(scheduler_driver=self.driver_cls_name)
         self.manager = self.manager_cls()
         self.context = context.RequestContext('fake_user', 'fake_project')
@@ -116,7 +137,9 @@ class SchedulerManagerTestCase(test.TestCase):
                 assert_called_once_with(service_name, host, capabilities))
 
     @mock.patch.object(db, 'share_update', mock.Mock())
-    def test_create_share_exception_puts_share_in_error_state(self):
+    @mock.patch('manila.message.api.API.create')
+    def test_create_share_exception_puts_share_in_error_state(
+            self, _mock_message_create):
         """Test NoValidHost exception for create_share.
 
         Puts the share in 'error' state and eats the exception.
@@ -124,9 +147,10 @@ class SchedulerManagerTestCase(test.TestCase):
         fake_share_id = 1
 
         request_spec = {'share_id': fake_share_id}
+        ex = exception.NoValidHost(reason='')
         with mock.patch.object(
                 self.manager.driver, 'schedule_create_share',
-                mock.Mock(side_effect=self.raise_no_valid_host)):
+                mock.Mock(side_effect=ex)):
             self.mock_object(manager.LOG, 'error')
 
             self.manager.create_share_instance(
@@ -138,6 +162,12 @@ class SchedulerManagerTestCase(test.TestCase):
                 assert_called_once_with(self.context, request_spec, {}))
             manager.LOG.error.assert_called_once_with(mock.ANY, mock.ANY)
 
+            _mock_message_create.assert_called_once_with(
+                self.context,
+                message_field.Action.ALLOCATE_HOST,
+                self.context.project_id, resource_type='SHARE',
+                exception=ex, resource_id=fake_share_id)
+
     @mock.patch.object(db, 'share_update', mock.Mock())
     def test_create_share_other_exception_puts_share_in_error_state(self):
         """Test any exception except NoValidHost for create_share.
@@ -164,6 +194,29 @@ class SchedulerManagerTestCase(test.TestCase):
                 assert_called_once_with(self.context, request_spec, {}))
             manager.LOG.error.assert_called_once_with(mock.ANY, mock.ANY)
 
+    @mock.patch.object(quota.QUOTAS, 'expire')
+    def test__expire_reservations(self, mock_expire):
+        self.manager._expire_reservations(self.context)
+
+        mock_expire.assert_called_once_with(self.context)
+
+    @mock.patch('manila.message.api.API.cleanup_expired_messages')
+    def test__clean_expired_messages(self, mock_expire):
+        self.manager._clean_expired_messages(self.context)
+
+        mock_expire.assert_called_once_with(self.context)
+
+    def test_periodic_tasks(self):
+        self.assertEqual(2, self.mock_periodic_task.call_count)
+
+        self.assertEqual(2, len(self.periodic_tasks))
+        self.assertEqual(
+            self.periodic_tasks[0].__name__,
+            self.manager._expire_reservations.__name__)
+        self.assertEqual(
+            self.periodic_tasks[1].__name__,
+            self.manager._clean_expired_messages.__name__)
+
     def test_get_pools(self):
         """Ensure get_pools exists and calls base_scheduler.get_pools."""
         mock_get_pools = self.mock_object(self.manager.driver,
