@@ -34,6 +34,7 @@ import time
 
 from oslo_config import cfg
 from oslo_log import log
+from oslo_utils import timeutils
 
 from manila.common import constants
 from manila import exception
@@ -319,8 +320,8 @@ class DummyDriver(driver.ShareDriver):
         """Removes the specified snapshot from Manila management."""
 
     @slow_me_down
-    def revert_to_snapshot(self, context, snapshot, access_rules,
-                           share_server=None):
+    def revert_to_snapshot(self, context, snapshot, share_access_rules,
+                           snapshot_access_rules, share_server=None):
         """Reverts a share (in place) to the specified snapshot."""
 
     @slow_me_down
@@ -380,13 +381,15 @@ class DummyDriver(driver.ShareDriver):
             "storage_protocol": "NFS_CIFS",
             "reserved_percentage":
                 self.configuration.reserved_share_percentage,
-            "consistency_group_support": "pool",
             "snapshot_support": True,
             "create_share_from_snapshot_support": True,
             "revert_to_snapshot_support": True,
             "mount_snapshot_support": True,
             "driver_name": "Dummy",
             "pools": self._get_pools_info(),
+            "share_group_stats": {
+                "consistent_snapshot_support": "pool",
+            }
         }
         if self.configuration.replication_domain:
             data["replication_type"] = "readable"
@@ -413,13 +416,13 @@ class DummyDriver(driver.ShareDriver):
     @slow_me_down
     def create_cgsnapshot(self, context, snap_dict, share_server=None):
         """Create a consistency group snapshot."""
-        LOG.debug("Successfully created CG snapshot %s." % snap_dict["id"])
+        LOG.debug("Successfully created CG snapshot %s.", snap_dict["id"])
         return None, None
 
     @slow_me_down
     def delete_cgsnapshot(self, context, snap_dict, share_server=None):
         """Delete a consistency group snapshot."""
-        LOG.debug("Successfully deleted CG snapshot %s." % snap_dict["id"])
+        LOG.debug("Successfully deleted CG snapshot %s.", snap_dict["id"])
         return None, None
 
     @slow_me_down
@@ -493,7 +496,8 @@ class DummyDriver(driver.ShareDriver):
     @slow_me_down
     def revert_to_replicated_snapshot(self, context, active_replica,
                                       replica_list, active_replica_snapshot,
-                                      replica_snapshots, access_rules,
+                                      replica_snapshots, share_access_rules,
+                                      snapshot_access_rules,
                                       share_server=None):
         """Reverts a replicated share (in place) to the specified snapshot."""
 
@@ -541,7 +545,7 @@ class DummyDriver(driver.ShareDriver):
 
         """
         LOG.debug(
-            "Migration of dummy share with ID '%s' has been started." %
+            "Migration of dummy share with ID '%s' has been started.",
             source_share["id"])
         self.migration_progress[source_share['share_id']] = 0
 
@@ -557,9 +561,9 @@ class DummyDriver(driver.ShareDriver):
         self.migration_progress[source_share["id"]] += 50
 
         LOG.debug(
-            "Migration of dummy share with ID '%s' is continuing, %s." %
-            (source_share["id"],
-             self.migration_progress[source_share["id"]]))
+            "Migration of dummy share with ID '%s' is continuing, %s.",
+            source_share["id"],
+            self.migration_progress[source_share["id"]])
 
         return self.migration_progress[source_share["id"]] == 100
 
@@ -592,7 +596,7 @@ class DummyDriver(driver.ShareDriver):
             }
         )
         LOG.debug(
-            "Migration of dummy share with ID '%s' has been completed." %
+            "Migration of dummy share with ID '%s' has been completed.",
             source_share_ref["id"])
         self.migration_progress.pop(source_share_ref["id"], None)
 
@@ -606,7 +610,7 @@ class DummyDriver(driver.ShareDriver):
             destination_share_server=None):
         """Is called to cancel driver migration."""
         LOG.debug(
-            "Migration of dummy share with ID '%s' has been canceled." %
+            "Migration of dummy share with ID '%s' has been canceled.",
             source_share["id"])
         self.migration_progress.pop(source_share["id"], None)
 
@@ -626,3 +630,12 @@ class DummyDriver(driver.ShareDriver):
                       "progress": total_progress
                   })
         return {"total_progress": total_progress}
+
+    def update_share_usage_size(self, context, shares):
+        share_updates = []
+        gathered_at = timeutils.utcnow()
+        for s in shares:
+            share_updates.append({'id': s['id'],
+                                  'used_size':  1,
+                                  'gathered_at': gathered_at})
+        return share_updates
