@@ -90,15 +90,41 @@ class HDFSNativeShareDriverTestCase(test.TestCase):
                           share_server=None)
         self.assertFalse(self._driver._get_share_path.called)
 
-    def test__create_share(self):
+    def test__set_share_size(self):
         share_dir = '/' + self.share['name']
         sizestr = six.text_type(self.share['size']) + 'g'
         self._driver._hdfs_execute = mock.Mock(return_value=True)
+        self._driver._set_share_size(self.share)
+        self._driver._hdfs_execute.assert_called_once_with(
+            'fake_hdfs_bin', 'dfsadmin', '-setSpaceQuota', sizestr, share_dir)
+
+    def test__set_share_size_exception(self):
+        share_dir = '/' + self.share['name']
+        sizestr = six.text_type(self.share['size']) + 'g'
+        self._driver._hdfs_execute = mock.Mock(
+            side_effect=exception.ProcessExecutionError)
+        self.assertRaises(exception.HDFSException,
+                          self._driver._set_share_size, self.share)
+        self._driver._hdfs_execute.assert_called_once_with(
+            'fake_hdfs_bin', 'dfsadmin', '-setSpaceQuota', sizestr, share_dir)
+
+    def test__set_share_size_with_new_size(self):
+        share_dir = '/' + self.share['name']
+        new_size = 'fake_size'
+        sizestr = new_size + 'g'
+        self._driver._hdfs_execute = mock.Mock(return_value=True)
+        self._driver._set_share_size(self.share, new_size)
+        self._driver._hdfs_execute.assert_called_once_with(
+            'fake_hdfs_bin', 'dfsadmin', '-setSpaceQuota', sizestr, share_dir)
+
+    def test__create_share(self):
+        share_dir = '/' + self.share['name']
+        self._driver._hdfs_execute = mock.Mock(return_value=True)
+        self._driver._set_share_size = mock.Mock()
         self._driver._create_share(self.share)
         self._driver._hdfs_execute.assert_any_call(
             'fake_hdfs_bin', 'dfs', '-mkdir', share_dir)
-        self._driver._hdfs_execute.assert_any_call(
-            'fake_hdfs_bin', 'dfsadmin', '-setSpaceQuota', sizestr, share_dir)
+        self._driver._set_share_size.assert_called_once_with(self.share)
         self._driver._hdfs_execute.assert_any_call(
             'fake_hdfs_bin', 'dfsadmin', '-allowSnapshot', share_dir)
 
@@ -319,13 +345,20 @@ class HDFSNativeShareDriverTestCase(test.TestCase):
         self._driver._hdfs_execute.assert_called_once_with(
             *cmd, check_exit_code=True)
 
+    def test_extend_share(self):
+        new_size = "fake_size"
+        self._driver._set_share_size = mock.Mock()
+        self._driver.extend_share(self.share, new_size)
+        self._driver._set_share_size.assert_called_once_with(
+            self.share, new_size)
+
     def test__check_hdfs_state_healthy(self):
         fake_out = "fakeinfo\n...Status: HEALTHY"
         self._driver._hdfs_execute = mock.Mock(return_value=(fake_out, ''))
         result = self._driver._check_hdfs_state()
         self._driver._hdfs_execute.assert_called_once_with(
             'fake_hdfs_bin', 'fsck', '/')
-        self.assertEqual(True, result)
+        self.assertTrue(result)
 
     def test__check_hdfs_state_down(self):
         fake_out = "fakeinfo\n...Status: DOWN"
@@ -333,7 +366,7 @@ class HDFSNativeShareDriverTestCase(test.TestCase):
         result = self._driver._check_hdfs_state()
         self._driver._hdfs_execute.assert_called_once_with(
             'fake_hdfs_bin', 'fsck', '/')
-        self.assertEqual(False, result)
+        self.assertFalse(result)
 
     def test__check_hdfs_state_exception(self):
         self._driver._hdfs_execute = mock.Mock(
@@ -344,9 +377,9 @@ class HDFSNativeShareDriverTestCase(test.TestCase):
             'fake_hdfs_bin', 'fsck', '/')
 
     def test__get_available_capacity(self):
-        fake_out = 'Configured Capacity: 2.4\n' + \
-            'Total Capacity: 2\n' + \
-            'DFS free: 1'
+        fake_out = ('Configured Capacity: 2.4\n' +
+                    'Total Capacity: 2\n' +
+                    'DFS free: 1')
         self._driver._hdfs_execute = mock.Mock(return_value=(fake_out, ''))
         total, free = self._driver._get_available_capacity()
         self._driver._hdfs_execute.assert_called_once_with(
@@ -372,13 +405,16 @@ class HDFSNativeShareDriverTestCase(test.TestCase):
             return_value=(11111.0, 12345.0))
         result = self._driver.get_share_stats(True)
         expected_keys = [
-            'QoS_support', 'driver_version', 'share_backend_name',
+            'qos', 'driver_version', 'share_backend_name',
             'free_capacity_gb', 'total_capacity_gb',
             'driver_handles_share_servers',
             'reserved_percentage', 'vendor_name', 'storage_protocol',
+            'ipv4_support', 'ipv6_support'
         ]
         for key in expected_keys:
             self.assertIn(key, result)
+        self.assertTrue(result['ipv4_support'])
+        self.assertFalse(False, result['ipv6_support'])
         self.assertEqual('HDFS', result['storage_protocol'])
         self._driver._get_available_capacity.assert_called_once_with()
 
