@@ -466,6 +466,10 @@ X    Allow Change & Read Unix user\\1090
 
 """
 
+HNAS_RESULT_check_snap_error = """ \
+path-to-object-number/FS-TestCG: Unable to locate component: share1
+path-to-object-number/FS-TestCG: Failed to resolve object number"""
+
 
 @ddt.ddt
 class HNASSSHTestCase(test.TestCase):
@@ -507,6 +511,7 @@ class HNASSSHTestCase(test.TestCase):
             'share_id': 'vvol_test',
             'host': 'ubuntu@hitachi2#HITACHI2',
         }
+        self.mock_log.debug.reset_mock()
 
     def test_get_stats(self):
         fake_list_command = ['df', '-a', '-f', self.fs_name]
@@ -535,13 +540,36 @@ class HNASSSHTestCase(test.TestCase):
         self.assertEqual(5120.0, free)
         self.assertTrue(dedupe)
 
-    def test_nfs_export_add(self):
-        fake_nfs_command = ['nfs-export', 'add', '-S', 'disable', '-c',
-                            '127.0.0.1', '/shares/vvol_test', self.fs_name,
-                            '/shares/vvol_test']
-        self.mock_object(ssh.HNASSSHBackend, '_execute', mock.Mock())
+    def test_get_stats_error(self):
 
-        self._driver_ssh.nfs_export_add('vvol_test')
+        fake_list_command = ['df', '-a', '-f', self.fs_name]
+
+        self.mock_object(ssh.HNASSSHBackend, '_execute',
+                         mock.Mock(side_effect=putils.ProcessExecutionError))
+
+        self.assertRaises(exception.HNASBackendException,
+                          self._driver_ssh.get_stats)
+
+        ssh.HNASSSHBackend._execute.assert_called_with(fake_list_command)
+
+    @ddt.data(True, False)
+    def test_nfs_export_add(self, is_snapshot):
+        if is_snapshot:
+            name = '/snapshots/fake_snap'
+            path = '/snapshots/fake_share/fake_snap'
+        else:
+            name = path = '/shares/fake_share'
+
+        fake_nfs_command = ['nfs-export', 'add', '-S', 'disable', '-c',
+                            '127.0.0.1', name, self.fs_name,
+                            path]
+        self.mock_object(ssh.HNASSSHBackend, '_execute')
+
+        if is_snapshot:
+            self._driver_ssh.nfs_export_add('fake_share',
+                                            snapshot_id='fake_snap')
+        else:
+            self._driver_ssh.nfs_export_add('fake_share')
 
         self._driver_ssh._execute.assert_called_with(fake_nfs_command)
 
@@ -553,11 +581,19 @@ class HNASSSHTestCase(test.TestCase):
                           self._driver_ssh.nfs_export_add, 'vvol_test')
         self.assertTrue(self.mock_log.exception.called)
 
-    def test_nfs_export_del(self):
-        fake_nfs_command = ['nfs-export', 'del', '/shares/vvol_test']
-        self.mock_object(ssh.HNASSSHBackend, '_execute', mock.Mock())
+    @ddt.data(True, False)
+    def test_nfs_export_del(self, is_snapshot):
+        if is_snapshot:
+            name = '/snapshots/vvol_test'
+            args = {'snapshot_id': 'vvol_test'}
+        else:
+            name = '/shares/vvol_test'
+            args = {'share_id': 'vvol_test'}
 
-        self._driver_ssh.nfs_export_del('vvol_test')
+        fake_nfs_command = ['nfs-export', 'del', name]
+        self.mock_object(ssh.HNASSSHBackend, '_execute')
+
+        self._driver_ssh.nfs_export_del(**args)
 
         self._driver_ssh._execute.assert_called_with(fake_nfs_command)
 
@@ -570,7 +606,11 @@ class HNASSSHTestCase(test.TestCase):
 
         self.assertTrue(self.mock_log.warning.called)
 
-    def test_nfs_export_del_error(self):
+    def test_nfs_export_del_exception(self):
+        self.assertRaises(exception.HNASBackendException,
+                          self._driver_ssh.nfs_export_del)
+
+    def test_nfs_export_del_execute_error(self):
         self.mock_object(ssh.HNASSSHBackend, '_execute', mock.Mock(
             side_effect=[putils.ProcessExecutionError(stderr='')]))
 
@@ -578,14 +618,26 @@ class HNASSSHTestCase(test.TestCase):
                           self._driver_ssh.nfs_export_del, 'vvol_test')
         self.assertTrue(self.mock_log.exception.called)
 
-    def test_cifs_share_add(self):
+    @ddt.data(True, False)
+    def test_cifs_share_add(self, is_snapshot):
+        if is_snapshot:
+            name = 'fake_snap'
+            path = r'\\snapshots\\fake_share\\fake_snap'
+        else:
+            name = 'fake_share'
+            path = r'\\shares\\fake_share'
+
         fake_cifs_add_command = ['cifs-share', 'add', '-S', 'disable',
                                  '--enable-abe', '--nodefaultsaa',
-                                 'vvol_test', self.fs_name,
-                                 r'\\shares\\vvol_test']
-        self.mock_object(ssh.HNASSSHBackend, '_execute', mock.Mock())
+                                 name, self.fs_name,
+                                 path]
+        self.mock_object(ssh.HNASSSHBackend, '_execute')
 
-        self._driver_ssh.cifs_share_add('vvol_test')
+        if is_snapshot:
+            self._driver_ssh.cifs_share_add('fake_share',
+                                            snapshot_id='fake_snap')
+        else:
+            self._driver_ssh.cifs_share_add('fake_share')
 
         self._driver_ssh._execute.assert_called_with(fake_cifs_add_command)
 
@@ -600,7 +652,7 @@ class HNASSSHTestCase(test.TestCase):
     def test_cifs_share_del(self):
         fake_cifs_del_command = ['cifs-share', 'del', '--target-label',
                                  self.fs_name, 'vvol_test']
-        self.mock_object(ssh.HNASSSHBackend, '_execute', mock.Mock())
+        self.mock_object(ssh.HNASSSHBackend, '_execute')
 
         self._driver_ssh.cifs_share_del('vvol_test')
 
@@ -629,7 +681,7 @@ class HNASSSHTestCase(test.TestCase):
         self._driver_ssh._execute.assert_called_with(fake_cifs_del_command)
 
     def test_get_nfs_host_list(self):
-        self.mock_object(ssh.HNASSSHBackend, "_get_share_export", mock.Mock(
+        self.mock_object(ssh.HNASSSHBackend, "_get_export", mock.Mock(
             return_value=[ssh.Export(HNAS_RESULT_export)]))
 
         host_list = self._driver_ssh.get_nfs_host_list('fake_id')
@@ -638,20 +690,38 @@ class HNASSSHTestCase(test.TestCase):
 
     def test_update_nfs_access_rule_empty_host_list(self):
         fake_export_command = ['nfs-export', 'mod', '-c', '127.0.0.1',
-                               '/shares/fake_id']
-        self.mock_object(ssh.HNASSSHBackend, "_execute", mock.Mock())
+                               '/snapshots/fake_id']
+        self.mock_object(ssh.HNASSSHBackend, "_execute")
 
-        self._driver_ssh.update_nfs_access_rule("fake_id", [])
+        self._driver_ssh.update_nfs_access_rule([], snapshot_id="fake_id")
 
         self._driver_ssh._execute.assert_called_with(fake_export_command)
 
     def test_update_nfs_access_rule(self):
         fake_export_command = ['nfs-export', 'mod', '-c',
                                u'"127.0.0.1,127.0.0.2"', '/shares/fake_id']
-        self.mock_object(ssh.HNASSSHBackend, "_execute", mock.Mock())
+        self.mock_object(ssh.HNASSSHBackend, "_execute")
 
-        self._driver_ssh.update_nfs_access_rule("fake_id", ['127.0.0.1',
-                                                            '127.0.0.2'])
+        self._driver_ssh.update_nfs_access_rule(['127.0.0.1', '127.0.0.2'],
+                                                share_id="fake_id")
+
+        self._driver_ssh._execute.assert_called_with(fake_export_command)
+
+    def test_update_nfs_access_rule_exception_no_share_provided(self):
+        self.assertRaises(exception.HNASBackendException,
+                          self._driver_ssh.update_nfs_access_rule,
+                          ['127.0.0.1'])
+
+    def test_update_nfs_access_rule_exception_error(self):
+
+        fake_export_command = ['nfs-export', 'mod', '-c',
+                               u'"127.0.0.1,127.0.0.2"', '/shares/fake_id']
+        self.mock_object(ssh.HNASSSHBackend, "_execute", mock.Mock(
+            side_effect=putils.ProcessExecutionError))
+
+        self.assertRaises(exception.HNASBackendException,
+                          self._driver_ssh.update_nfs_access_rule,
+                          ['127.0.0.1', '127.0.0.2'], share_id="fake_id")
 
         self._driver_ssh._execute.assert_called_with(fake_export_command)
 
@@ -659,26 +729,39 @@ class HNASSSHTestCase(test.TestCase):
         fake_cifs_allow_command = ['cifs-saa', 'add', '--target-label',
                                    self.fs_name, 'vvol_test',
                                    'fake_user', 'ar']
-        self.mock_object(ssh.HNASSSHBackend, '_execute', mock.Mock())
+        self.mock_object(ssh.HNASSSHBackend, '_execute')
 
         self._driver_ssh.cifs_allow_access('vvol_test', 'fake_user', 'ar')
 
         self._driver_ssh._execute.assert_called_with(fake_cifs_allow_command)
 
-    def test_cifs_allow_access_already_allowed_user(self):
+    @ddt.data(True, False)
+    def test_cifs_allow_access_already_allowed_user(self, is_snapshot):
         fake_cifs_allow_command = ['cifs-saa', 'add', '--target-label',
                                    self.fs_name, 'vvol_test',
                                    'fake_user', 'acr']
+        if not is_snapshot:
+            fake_cifs_allow_command2 = ['cifs-saa', 'change', '--target-label',
+                                        'file_system', 'vvol_test',
+                                        'fake_user', 'acr']
+
         self.mock_object(ssh.HNASSSHBackend, '_execute',
                          mock.Mock(side_effect=[putils.ProcessExecutionError(
-                             stderr='already listed as a user')]))
+                             stderr='already listed as a user'),
+                             "Rule modified."]))
 
-        self._driver_ssh.cifs_allow_access('vvol_test', 'fake_user', 'acr')
+        self._driver_ssh.cifs_allow_access('vvol_test', 'fake_user', 'acr',
+                                           is_snapshot=is_snapshot)
 
-        self._driver_ssh._execute.assert_called_with(fake_cifs_allow_command)
+        _execute_calls = [mock.call(fake_cifs_allow_command)]
+        if not is_snapshot:
+            _execute_calls.append(mock.call(fake_cifs_allow_command2))
+
+        self._driver_ssh._execute.assert_has_calls(_execute_calls)
         self.assertTrue(self.mock_log.debug.called)
 
-    def test_cifs_allow_access_exception(self):
+    @ddt.data(True, False)
+    def test_cifs_allow_access_exception(self, is_snapshot):
         fake_cifs_allow_command = ['cifs-saa', 'add', '--target-label',
                                    self.fs_name, 'vvol_test',
                                    'fake_user', 'acr']
@@ -687,32 +770,57 @@ class HNASSSHTestCase(test.TestCase):
                              stderr='Could not add user/group fake_user to '
                                     'share \'vvol_test\'')]))
 
-        self.assertRaises(exception.InvalidShareAccess,
+        self.assertRaises(exception.HNASBackendException,
+                          self._driver_ssh.cifs_allow_access, 'vvol_test',
+                          'fake_user', 'acr', is_snapshot=is_snapshot)
+
+        self._driver_ssh._execute.assert_called_with(fake_cifs_allow_command)
+
+    def test_cifs_update_access_level_exception(self):
+        fake_cifs_allow_command = ['cifs-saa', 'add', '--target-label',
+                                   self.fs_name, 'vvol_test',
+                                   'fake_user', 'acr']
+        fake_cifs_allow_command2 = ['cifs-saa', 'change', '--target-label',
+                                    'file_system', 'vvol_test', 'fake_user',
+                                    'acr']
+
+        self.mock_object(ssh.HNASSSHBackend, '_execute',
+                         mock.Mock(side_effect=[putils.ProcessExecutionError(
+                             stderr='already listed as a user'),
+                             putils.ProcessExecutionError(
+                             stderr='Error when trying to modify rule.')]))
+
+        self.assertRaises(exception.HNASBackendException,
                           self._driver_ssh.cifs_allow_access, 'vvol_test',
                           'fake_user', 'acr')
 
-        self._driver_ssh._execute.assert_called_with(fake_cifs_allow_command)
+        self._driver_ssh._execute.assert_has_calls(
+            [mock.call(fake_cifs_allow_command),
+             mock.call(fake_cifs_allow_command2)])
+        self.assertTrue(self.mock_log.debug.called)
 
     def test_cifs_deny_access(self):
         fake_cifs_deny_command = ['cifs-saa', 'delete', '--target-label',
                                   self.fs_name, 'vvol_test', 'fake_user']
-        self.mock_object(ssh.HNASSSHBackend, '_execute', mock.Mock())
+        self.mock_object(ssh.HNASSSHBackend, '_execute')
 
         self._driver_ssh.cifs_deny_access('vvol_test', 'fake_user')
 
         self._driver_ssh._execute.assert_called_with(fake_cifs_deny_command)
 
-    def test_cifs_deny_access_already_deleted_user(self):
+    @ddt.data(True, False)
+    def test_cifs_deny_access_already_deleted_user(self, is_snapshot):
         fake_cifs_deny_command = ['cifs-saa', 'delete', '--target-label',
                                   self.fs_name, 'vvol_test', 'fake_user']
         self.mock_object(ssh.HNASSSHBackend, '_execute', mock.Mock(
             side_effect=[putils.ProcessExecutionError(
                 stderr='not listed as a user')]))
 
-        self._driver_ssh.cifs_deny_access('vvol_test', 'fake_user')
+        self._driver_ssh.cifs_deny_access('vvol_test', 'fake_user',
+                                          is_snapshot=is_snapshot)
 
         self._driver_ssh._execute.assert_called_with(fake_cifs_deny_command)
-        self.assertTrue(self.mock_log.debug.called)
+        self.assertTrue(self.mock_log.warning.called)
 
     def test_cifs_deny_access_backend_exception(self):
         fake_cifs_deny_command = ['cifs-saa', 'delete', '--target-label',
@@ -829,7 +937,7 @@ class HNASSSHTestCase(test.TestCase):
                          (HNAS_RESULT_job_running, ''),
                          (HNAS_RESULT_empty, '')]))
         self.mock_object(time, "time", mock.Mock(side_effect=[0, 0, 200, 200]))
-        self.mock_object(time, "sleep", mock.Mock())
+        self.mock_object(time, "sleep")
 
         self.assertRaises(exception.HNASBackendException,
                           self._driver_ssh.tree_clone, "/src", "/dst")
@@ -857,28 +965,167 @@ class HNASSSHTestCase(test.TestCase):
                 stderr='')]
         ))
 
-        self.assertRaises(putils.ProcessExecutionError,
+        self.assertRaises(exception.HNASBackendException,
                           self._driver_ssh.tree_delete, "/path")
         self.assertTrue(self.mock_log.exception.called)
         self._driver_ssh._execute.assert_called_with(fake_tree_delete_command)
 
     def test_create_directory(self):
         locked_selectfs_args = ['create', '/path']
-        self.mock_object(ssh.HNASSSHBackend, "_locked_selectfs", mock.Mock())
+        self.mock_object(ssh.HNASSSHBackend, "_locked_selectfs")
+        self.mock_object(ssh.HNASSSHBackend, "check_directory",
+                         mock.Mock(return_value=True))
 
         self._driver_ssh.create_directory("/path")
 
         self._driver_ssh._locked_selectfs.assert_called_with(
             *locked_selectfs_args)
+        ssh.HNASSSHBackend.check_directory.assert_called_once_with('/path')
+        self.assertFalse(self.mock_log.warning.called)
+
+    def test_create_directory_context_change_fail(self):
+        locked_selectfs_args = ['create', '/path']
+        self.mock_object(time, 'sleep')
+        self.mock_object(ssh.HNASSSHBackend, "_locked_selectfs")
+        self.mock_object(ssh.HNASSSHBackend, "check_directory",
+                         mock.Mock(return_value=False))
+
+        self.assertRaises(exception.HNASSSCContextChange,
+                          self._driver_ssh.create_directory, "/path")
+
+        self._driver_ssh._locked_selectfs.assert_called_with(
+            *locked_selectfs_args)
+        ssh.HNASSSHBackend.check_directory.assert_called_with('/path')
+        self.assertTrue(self.mock_log.warning.called)
+
+    def test_create_directory_context_change_success(self):
+        locked_selectfs_args = ['create', '/path']
+        self.mock_object(time, 'sleep')
+        self.mock_object(ssh.HNASSSHBackend, "_locked_selectfs")
+        self.mock_object(ssh.HNASSSHBackend, "check_directory",
+                         mock.Mock(side_effect=[False, False, True]))
+
+        self._driver_ssh.create_directory("/path")
+
+        self._driver_ssh._locked_selectfs.assert_called_with(
+            *locked_selectfs_args)
+        ssh.HNASSSHBackend.check_directory.assert_called_with('/path')
+        self.assertTrue(self.mock_log.warning.called)
 
     def test_delete_directory(self):
         locked_selectfs_args = ['delete', '/path']
-        self.mock_object(ssh.HNASSSHBackend, "_locked_selectfs", mock.Mock())
+        self.mock_object(ssh.HNASSSHBackend, "_locked_selectfs")
+        self.mock_object(ssh.HNASSSHBackend, "check_directory",
+                         mock.Mock(return_value=False))
 
         self._driver_ssh.delete_directory("/path")
 
         self._driver_ssh._locked_selectfs.assert_called_with(
             *locked_selectfs_args)
+        ssh.HNASSSHBackend.check_directory.assert_called_once_with('/path')
+        self.assertFalse(self.mock_log.debug.called)
+
+    def test_delete_directory_directory_not_empty(self):
+        locked_selectfs_args = ['delete', '/path']
+        self.mock_object(ssh.HNASSSHBackend, "_locked_selectfs", mock.Mock(
+            side_effect=exception.HNASDirectoryNotEmpty(msg='fake')))
+        self.mock_object(ssh.HNASSSHBackend, "check_directory")
+
+        self._driver_ssh.delete_directory("/path")
+
+        self._driver_ssh._locked_selectfs.assert_called_with(
+            *locked_selectfs_args)
+        ssh.HNASSSHBackend.check_directory.assert_not_called()
+        self.assertFalse(self.mock_log.debug.called)
+
+    def test_delete_directory_context_change_fail(self):
+        locked_selectfs_args = ['delete', '/path']
+        self.mock_object(time, 'sleep')
+        self.mock_object(ssh.HNASSSHBackend, "_locked_selectfs")
+        self.mock_object(ssh.HNASSSHBackend, "check_directory",
+                         mock.Mock(return_value=True))
+
+        self.assertRaises(exception.HNASSSCContextChange,
+                          self._driver_ssh.delete_directory, "/path")
+
+        self._driver_ssh._locked_selectfs.assert_called_with(
+            *locked_selectfs_args)
+        ssh.HNASSSHBackend.check_directory.assert_called_with('/path')
+        self.assertTrue(self.mock_log.debug.called)
+
+    def test_delete_directory_context_change_success(self):
+        locked_selectfs_args = ['delete', '/path']
+        self.mock_object(time, 'sleep')
+        self.mock_object(ssh.HNASSSHBackend, "_locked_selectfs")
+        self.mock_object(ssh.HNASSSHBackend, "check_directory",
+                         mock.Mock(side_effect=[True, True, False]))
+
+        self._driver_ssh.delete_directory("/path")
+
+        self._driver_ssh._locked_selectfs.assert_called_with(
+            *locked_selectfs_args)
+        ssh.HNASSSHBackend.check_directory.assert_called_with('/path')
+        self.assertTrue(self.mock_log.debug.called)
+
+    def test_check_directory(self):
+        path = ("/snapshots/" + self.snapshot['share_id'] + "/" +
+                self.snapshot['id'])
+        check_snap_args = ['path-to-object-number', '-f', self.fs_name, path]
+
+        self.mock_object(ssh.HNASSSHBackend, '_execute')
+
+        out = self._driver_ssh.check_directory(path)
+
+        self.assertTrue(out)
+        self._driver_ssh._execute.assert_called_with(check_snap_args)
+
+    def test_check_directory_retry(self):
+        error_msg = ("Unable to run path-to-object-number as "
+                     "path-to-object-number is currently running on volume "
+                     "39.")
+        path = ("/snapshots/" + self.snapshot['share_id'] + "/" +
+                self.snapshot['id'])
+
+        check_snap_args = ['path-to-object-number', '-f', self.fs_name, path]
+
+        self.mock_object(time, "sleep")
+        self.mock_object(ssh.HNASSSHBackend, '_execute',
+                         mock.Mock(side_effect=[putils.ProcessExecutionError(
+                             stdout=error_msg), putils.ProcessExecutionError(
+                             stdout=error_msg), 'Object number: 0x45a4']))
+
+        out = self._driver_ssh.check_directory(path)
+
+        self.assertIs(True, out)
+        self._driver_ssh._execute.assert_called_with(check_snap_args)
+
+    def test_check_inexistent_snapshot(self):
+        path = "/path/snap1/snapshot07-08-2016"
+
+        check_snap_args = ['path-to-object-number', '-f', self.fs_name, path]
+
+        self.mock_object(ssh.HNASSSHBackend, '_execute',
+                         mock.Mock(side_effect=putils.ProcessExecutionError(
+                             stdout=HNAS_RESULT_check_snap_error)))
+
+        out = self._driver_ssh.check_directory(path)
+
+        self.assertFalse(out)
+        self._driver_ssh._execute.assert_called_with(check_snap_args)
+
+    def test_check_directory_error(self):
+        path = "/path/snap1/snapshot07-08-2016"
+
+        check_snap_args = ['path-to-object-number', '-f', self.fs_name, path]
+
+        self.mock_object(ssh.HNASSSHBackend, '_execute',
+                         mock.Mock(side_effect=putils.ProcessExecutionError(
+                             stdout="Internal Server Error.")))
+
+        self.assertRaises(exception.HNASBackendException,
+                          self._driver_ssh.check_directory, path)
+
+        self._driver_ssh._execute.assert_called_with(check_snap_args)
 
     def test_check_fs_mounted_true(self):
         self.mock_object(ssh.HNASSSHBackend, "_execute",
@@ -906,18 +1153,31 @@ class HNASSSHTestCase(test.TestCase):
         self.mock_object(ssh.HNASSSHBackend, "_execute", mock.Mock(
             side_effect=putils.ProcessExecutionError(stderr='')))
 
-        self.assertRaises(putils.ProcessExecutionError, self._driver_ssh.mount)
+        self.assertRaises(
+            exception.HNASBackendException, self._driver_ssh.mount)
+
         self._driver_ssh._execute.assert_called_with(fake_mount_command)
 
     def test_vvol_create(self):
         fake_vvol_create_command = ['virtual-volume', 'add', '--ensure',
                                     self.fs_name, 'vvol', '/shares/vvol']
-        self.mock_object(ssh.HNASSSHBackend, "_execute", mock.Mock())
+        self.mock_object(ssh.HNASSSHBackend, "_execute")
 
         self._driver_ssh.vvol_create("vvol")
 
         self._driver_ssh._execute.assert_called_with(fake_vvol_create_command)
 
+    def test_vvol_create_error(self):
+        fake_vvol_create_command = ['virtual-volume', 'add', '--ensure',
+                                    self.fs_name, 'vvol', '/shares/vvol']
+        self.mock_object(ssh.HNASSSHBackend, "_execute",
+                         mock.Mock(side_effect=putils.ProcessExecutionError))
+
+        self.assertRaises(exception.HNASBackendException,
+                          self._driver_ssh.vvol_create, "vvol")
+
+        self._driver_ssh._execute.assert_called_with(fake_vvol_create_command)
+
     def test_vvol_delete_vvol_does_not_exist(self):
         fake_vvol_delete_command = ['tree-delete-job-submit', '--confirm',
                                     '-f', self.fs_name, '/shares/vvol']
@@ -928,7 +1188,7 @@ class HNASSSHTestCase(test.TestCase):
 
         self._driver_ssh.vvol_delete("vvol")
 
-        self.assertTrue(self.mock_log.debug.called)
+        self.assertTrue(self.mock_log.warning.called)
         self._driver_ssh._execute.assert_called_with(fake_vvol_delete_command)
 
     def test_vvol_delete_error(self):
@@ -939,7 +1199,7 @@ class HNASSSHTestCase(test.TestCase):
                 stderr='')]
         ))
 
-        self.assertRaises(putils.ProcessExecutionError,
+        self.assertRaises(exception.HNASBackendException,
                           self._driver_ssh.vvol_delete, "vvol")
         self.assertTrue(self.mock_log.exception.called)
         self._driver_ssh._execute.assert_called_with(fake_vvol_delete_command)
@@ -948,7 +1208,7 @@ class HNASSSHTestCase(test.TestCase):
         fake_add_quota_command = ['quota', 'add', '--usage-limit', '1G',
                                   '--usage-hard-limit', 'yes',
                                   self.fs_name, 'vvol']
-        self.mock_object(ssh.HNASSSHBackend, "_execute", mock.Mock())
+        self.mock_object(ssh.HNASSSHBackend, "_execute")
 
         self._driver_ssh.quota_add('vvol', 1)
 
@@ -957,12 +1217,35 @@ class HNASSSHTestCase(test.TestCase):
     def test_modify_quota(self):
         fake_modify_quota_command = ['quota', 'mod', '--usage-limit', '1G',
                                      self.fs_name, 'vvol']
-        self.mock_object(ssh.HNASSSHBackend, "_execute", mock.Mock())
+        self.mock_object(ssh.HNASSSHBackend, "_execute")
 
         self._driver_ssh.modify_quota('vvol', 1)
 
         self._driver_ssh._execute.assert_called_with(fake_modify_quota_command)
 
+    def test_quota_add_error(self):
+        fake_add_quota_command = ['quota', 'add', '--usage-limit', '1G',
+                                  '--usage-hard-limit', 'yes',
+                                  self.fs_name, 'vvol']
+        self.mock_object(ssh.HNASSSHBackend, "_execute",
+                         mock.Mock(side_effect=putils.ProcessExecutionError))
+
+        self.assertRaises(exception.HNASBackendException,
+                          self._driver_ssh.quota_add, 'vvol', 1)
+
+        self._driver_ssh._execute.assert_called_with(fake_add_quota_command)
+
+    def test_modify_quota_error(self):
+        fake_modify_quota_command = ['quota', 'mod', '--usage-limit', '1G',
+                                     self.fs_name, 'vvol']
+        self.mock_object(ssh.HNASSSHBackend, "_execute",
+                         mock.Mock(side_effect=putils.ProcessExecutionError))
+
+        self.assertRaises(exception.HNASBackendException,
+                          self._driver_ssh.modify_quota, 'vvol', 1)
+
+        self._driver_ssh._execute.assert_called_with(fake_modify_quota_command)
+
     def test_check_vvol(self):
         fake_check_vvol_command = ['virtual-volume', 'list', '--verbose',
                                    self.fs_name, 'vvol']
@@ -983,14 +1266,25 @@ class HNASSSHTestCase(test.TestCase):
                           self._driver_ssh.check_quota, 'vvol')
         self._driver_ssh._execute.assert_called_with(fake_check_quota_command)
 
-    def test_check_export(self):
-        self.mock_object(ssh.HNASSSHBackend, "_get_share_export", mock.Mock(
+    def test_check_quota_error(self):
+        fake_check_quota_command = ['quota', 'list', '--verbose',
+                                    self.fs_name, 'vvol']
+        self.mock_object(ssh.HNASSSHBackend, "_execute", mock.Mock(
+            side_effect=putils.ProcessExecutionError))
+
+        self.assertRaises(exception.HNASBackendException,
+                          self._driver_ssh.check_quota, 'vvol')
+        self._driver_ssh._execute.assert_called_with(fake_check_quota_command)
+
+    @ddt.data(True, False)
+    def test_check_export(self, is_snapshot):
+        self.mock_object(ssh.HNASSSHBackend, "_get_export", mock.Mock(
             return_value=[ssh.Export(HNAS_RESULT_export)]))
 
-        self._driver_ssh.check_export("vvol_test")
+        self._driver_ssh.check_export("vvol_test", is_snapshot)
 
     def test_check_export_error(self):
-        self.mock_object(ssh.HNASSSHBackend, "_get_share_export", mock.Mock(
+        self.mock_object(ssh.HNASSSHBackend, "_get_export", mock.Mock(
             return_value=[ssh.Export(HNAS_RESULT_wrong_export)]))
 
         self.assertRaises(exception.HNASItemNotFoundException,
@@ -1024,7 +1318,7 @@ class HNASSSHTestCase(test.TestCase):
         self.mock_object(ssh.HNASSSHBackend, '_execute', mock.Mock(
             side_effect=[putils.ProcessExecutionError(stderr='Error.')]))
 
-        self.assertRaises(putils.ProcessExecutionError,
+        self.assertRaises(exception.HNASBackendException,
                           self._driver_ssh.check_cifs, 'wrong_vvol')
         self._driver_ssh._execute.assert_called_with(check_cifs_share_command)
 
@@ -1118,16 +1412,47 @@ class HNASSSHTestCase(test.TestCase):
 
         self.assertEqual(1024, self._driver_ssh.get_share_usage("vvol_test"))
 
-    def test__get_share_export(self):
-        self.mock_object(ssh.HNASSSHBackend, '_execute',
-                         mock.Mock(return_value=[HNAS_RESULT_export_ip, '']))
+    @ddt.data(True, False)
+    def test__get_share_export(self, is_snapshot):
+        self.mock_object(ssh.HNASSSHBackend, '_execute', mock.Mock(
+            return_value=[HNAS_RESULT_export_ip, '']))
 
-        export_list = self._driver_ssh._get_share_export('fake_id')
+        export_list = self._driver_ssh._get_export(
+            name='fake_name', is_snapshot=is_snapshot)
+        path = '/shares/fake_name'
+        if is_snapshot:
+            path = '/snapshots/fake_name'
 
+        command = ['nfs-export', 'list ', path]
+
+        self._driver_ssh._execute.assert_called_with(command)
         self.assertEqual('vvol_test', export_list[0].export_name)
         self.assertEqual('/vvol_test', export_list[0].export_path)
         self.assertEqual('fake_fs', export_list[0].file_system_label)
         self.assertEqual('Yes', export_list[0].mounted)
+        self.assertIn('rw', export_list[0].export_configuration[0])
+
+    def test__get_share_export_fs_not_available(self):
+
+        self.mock_object(ssh.HNASSSHBackend, '_execute', mock.Mock(
+            return_value=[HNAS_RESULT_exp_no_fs, '']))
+
+        export_list = self._driver_ssh._get_export(name='fake_name')
+        path = '/shares/fake_name'
+
+        command = ['nfs-export', 'list ', path]
+
+        self._driver_ssh._execute.assert_called_with(command)
+        self.assertEqual('no_fs', export_list[0].export_name)
+        self.assertEqual('/export_without_fs', export_list[0].export_path)
+        self.assertEqual('*** not available ***',
+                         export_list[0].file_system_info)
+        self.assertEqual([], export_list[0].export_configuration)
+        not_in_keys = ['file_system_label', 'file_system_size', 'formatted',
+                       'file_system_free_space', 'file_system_state', 'failed',
+                       'mounted', 'thin_provisioned']
+        for key in not_in_keys:
+            self.assertNotIn(key, export_list[0].__dict__)
 
     def test__get_share_export_exception_not_found(self):
 
@@ -1136,7 +1461,7 @@ class HNASSSHTestCase(test.TestCase):
                 stderr="NFS Export List: Export 'id' does not exist.")))
 
         self.assertRaises(exception.HNASItemNotFoundException,
-                          self._driver_ssh._get_share_export, 'fake_id')
+                          self._driver_ssh._get_export, 'fake_id')
 
     def test__get_share_export_exception_error(self):
 
@@ -1144,8 +1469,8 @@ class HNASSSHTestCase(test.TestCase):
             side_effect=putils.ProcessExecutionError(stderr="Some error.")
         ))
 
-        self.assertRaises(putils.ProcessExecutionError,
-                          self._driver_ssh._get_share_export, 'fake_id')
+        self.assertRaises(exception.HNASBackendException,
+                          self._driver_ssh._get_export, 'fake_id')
 
     def test__execute(self):
         key = self.ssh_private_key
@@ -1175,7 +1500,7 @@ class HNASSSHTestCase(test.TestCase):
                           'tree-clone-job-submit -e /src /dst')
         msg = 'Failed to establish SSC connection'
 
-        self.mock_object(time, "sleep", mock.Mock())
+        self.mock_object(time, "sleep")
         self.mock_object(paramiko.SSHClient, 'connect')
         self.mock_object(putils, 'ssh_execute',
                          mock.Mock(side_effect=[
@@ -1192,23 +1517,51 @@ class HNASSSHTestCase(test.TestCase):
                                               check_exit_code=True)
 
         self.assertTrue(self.mock_log.debug.called)
-        self.assertTrue(self.mock_log.error.called)
 
     def test__locked_selectfs_create_operation(self):
         exec_command = ['selectfs', self.fs_name, '\n', 'ssc', '127.0.0.1',
                         'console-context', '--evs', six.text_type(self.evs_id),
                         'mkdir', '-p', '/path']
-        self.mock_object(ssh.HNASSSHBackend, '_execute', mock.Mock())
+        self.mock_object(ssh.HNASSSHBackend, '_execute')
 
         self._driver_ssh._locked_selectfs('create', '/path')
 
         self._driver_ssh._execute.assert_called_with(exec_command)
 
-    def test__locked_selectfs_delete_operation_successfull(self):
+    def test__locked_selectfs_create_operation_error(self):
+        exec_command = ['selectfs', self.fs_name, '\n', 'ssc', '127.0.0.1',
+                        'console-context', '--evs', six.text_type(self.evs_id),
+                        'mkdir', '-p', '/path']
+        self.mock_object(
+            ssh.HNASSSHBackend, '_execute',
+            mock.Mock(side_effect=putils.ProcessExecutionError(
+                stderr="some error")))
+
+        self.assertRaises(exception.HNASBackendException,
+                          self._driver_ssh._locked_selectfs, 'create', '/path')
+
+        self._driver_ssh._execute.assert_called_with(exec_command)
+
+    def test__locked_selectfs_create_operation_context_change(self):
+        exec_command = ['selectfs', self.fs_name, '\n', 'ssc', '127.0.0.1',
+                        'console-context', '--evs', six.text_type(self.evs_id),
+                        'mkdir', '-p', '/path']
+        self.mock_object(
+            ssh.HNASSSHBackend, '_execute',
+            mock.Mock(side_effect=putils.ProcessExecutionError(
+                stderr="Current file system invalid: VolumeNotFound")))
+
+        self.assertRaises(exception.HNASSSCContextChange,
+                          self._driver_ssh._locked_selectfs, 'create', '/path')
+
+        self._driver_ssh._execute.assert_called_with(exec_command)
+        self.assertTrue(self.mock_log.debug.called)
+
+    def test__locked_selectfs_delete_operation_successful(self):
         exec_command = ['selectfs', self.fs_name, '\n', 'ssc', '127.0.0.1',
                         'console-context', '--evs', six.text_type(self.evs_id),
                         'rmdir', '/path']
-        self.mock_object(ssh.HNASSSHBackend, '_execute', mock.Mock())
+        self.mock_object(ssh.HNASSSHBackend, '_execute')
 
         self._driver_ssh._locked_selectfs('delete', '/path')
 
@@ -1220,16 +1573,38 @@ class HNASSSHTestCase(test.TestCase):
         self.mock_object(ssh.HNASSSHBackend, '_execute', mock.Mock(
             side_effect=[putils.ProcessExecutionError(stderr=msg)]))
 
-        self._driver_ssh._locked_selectfs('delete', '/path')
+        self.assertRaises(exception.HNASDirectoryNotEmpty,
+                          self._driver_ssh._locked_selectfs, 'delete', '/path')
 
         self.assertTrue(self.mock_log.debug.called)
 
     def test__locked_selectfs_delete_exception(self):
-        msg = 'rmdir: cannot remove \'/path\''
+        msg = "rmdir: cannot remove '/path'"
 
         self.mock_object(ssh.HNASSSHBackend, '_execute', mock.Mock(
             side_effect=[putils.ProcessExecutionError(stderr=msg)]))
 
-        self.assertRaises(putils.ProcessExecutionError,
+        self.assertRaises(exception.HNASBackendException,
                           self._driver_ssh._locked_selectfs, 'delete', 'path')
         self.assertTrue(self.mock_log.exception.called)
+
+    def test__locked_selectfs_delete_not_found(self):
+        msg = "rmdir: cannot remove '/path': NotFound"
+
+        self.mock_object(ssh.HNASSSHBackend, '_execute', mock.Mock(
+            side_effect=[putils.ProcessExecutionError(stderr=msg)]))
+
+        self._driver_ssh._locked_selectfs('delete', 'path')
+
+        self.assertTrue(self.mock_log.warning.called)
+
+    def test__locked_selectfs_delete_context_change(self):
+        msg = "Current file system invalid: VolumeNotFound"
+
+        self.mock_object(ssh.HNASSSHBackend, '_execute', mock.Mock(
+            side_effect=[putils.ProcessExecutionError(stderr=msg)]))
+
+        self.assertRaises(exception.HNASSSCContextChange,
+                          self._driver_ssh._locked_selectfs, 'delete', 'path')
+
+        self.assertTrue(self.mock_log.debug.called)
