@@ -30,9 +30,6 @@ from manila.tests.share.drivers.hpe import test_hpe_3par_constants as constants
 @ddt.ddt
 class HPE3ParDriverFPGTestCase(test.TestCase):
 
-    def setUp(self):
-        super(HPE3ParDriverFPGTestCase, self).setUp()
-
     @ddt.data((-1, 4),
               (0, 5),
               (0, -1))
@@ -735,8 +732,10 @@ class HPE3ParDriverTestCase(test.TestCase):
             'snapshot_support': True,
             'create_share_from_snapshot_support': True,
             'revert_to_snapshot_support': False,
-            'share_group_snapshot_support': True,
             'mount_snapshot_support': False,
+            'share_group_stats': {
+                'consistent_snapshot_support': None,
+            },
             'storage_protocol': 'NFS_CIFS',
             'thin_provisioning': True,
             'total_capacity_gb': 0,
@@ -745,6 +744,8 @@ class HPE3ParDriverTestCase(test.TestCase):
             'replication_domain': None,
             'filter_function': None,
             'goodness_function': None,
+            'ipv4_support': True,
+            'ipv6_support': False,
         }
 
         result = self.driver.get_share_stats(refresh=True)
@@ -813,11 +814,15 @@ class HPE3ParDriverTestCase(test.TestCase):
             'snapshot_support': True,
             'create_share_from_snapshot_support': True,
             'revert_to_snapshot_support': False,
-            'share_group_snapshot_support': True,
             'mount_snapshot_support': False,
+            'share_group_stats': {
+                'consistent_snapshot_support': None,
+            },
             'replication_domain': None,
             'filter_function': None,
             'goodness_function': None,
+            'ipv4_support': True,
+            'ipv6_support': False,
         }
 
         result = self.driver.get_share_stats(refresh=True)
@@ -853,11 +858,15 @@ class HPE3ParDriverTestCase(test.TestCase):
             'snapshot_support': True,
             'create_share_from_snapshot_support': True,
             'revert_to_snapshot_support': False,
-            'share_group_snapshot_support': True,
             'mount_snapshot_support': False,
+            'share_group_stats': {
+                'consistent_snapshot_support': None,
+            },
             'replication_domain': None,
             'filter_function': None,
             'goodness_function': None,
+            'ipv4_support': True,
+            'ipv6_support': False,
         }
 
         result = self.driver.get_share_stats(refresh=True)
