@@ -19,7 +19,18 @@ FAKE_RES_DETAIL_DATA_LOGIN = """
         <authSid><![CDATA[fakeSid]]></authSid>
     </QDocRoot>"""
 
-FAKE_RES_DETAIL_DATA_GETBASIC_INFO_ES = """
+FAKE_RES_DETAIL_DATA_GETBASIC_INFO_ES_1_1_1 = """
+    <QDocRoot version="1.0">
+        <model>
+            <displayModelName><![CDATA[ES1640dc]]></displayModelName>
+            <internalModelName><![CDATA[ES1640dc]]></internalModelName>
+        </model>
+        <firmware>
+            <version><![CDATA[1.1.1]]></version>
+        </firmware>
+    </QDocRoot>"""
+
+FAKE_RES_DETAIL_DATA_GETBASIC_INFO_ES_1_1_3 = """
     <QDocRoot version="1.0">
         <model>
             <displayModelName><![CDATA[ES1640dc]]></displayModelName>
@@ -30,7 +41,18 @@ FAKE_RES_DETAIL_DATA_GETBASIC_INFO_ES = """
         </firmware>
     </QDocRoot>"""
 
-FAKE_RES_DETAIL_DATA_GETBASIC_INFO_TS = """
+FAKE_RES_DETAIL_DATA_GETBASIC_INFO_TS_4_0_0 = """
+    <QDocRoot version="1.0">
+        <model>
+            <displayModelName><![CDATA[TS-870U]]></displayModelName>
+            <internalModelName><![CDATA[TS-870U]]></internalModelName>
+        </model>
+        <firmware>
+            <version><![CDATA[4.0.0]]></version>
+        </firmware>
+    </QDocRoot>"""
+
+FAKE_RES_DETAIL_DATA_GETBASIC_INFO_TS_4_3_0 = """
     <QDocRoot version="1.0">
         <model>
             <displayModelName><![CDATA[TS-870U]]></displayModelName>
@@ -41,7 +63,18 @@ FAKE_RES_DETAIL_DATA_GETBASIC_INFO_TS = """
         </firmware>
     </QDocRoot>"""
 
-FAKE_RES_DETAIL_DATA_GETBASIC_INFO_TES_TS = """
+FAKE_RES_DETAIL_DATA_GETBASIC_INFO_TES_TS_4_0_0 = """
+    <QDocRoot version="1.0">
+        <model>
+            <displayModelName><![CDATA[TES-1885U]]></displayModelName>
+            <internalModelName><![CDATA[TS-1885U]]></internalModelName>
+        </model>
+        <firmware>
+            <version><![CDATA[4.0.0]]></version>
+        </firmware>
+    </QDocRoot>"""
+
+FAKE_RES_DETAIL_DATA_GETBASIC_INFO_TES_TS_4_3_0 = """
     <QDocRoot version="1.0">
         <model>
             <displayModelName><![CDATA[TES-1885U]]></displayModelName>
@@ -52,7 +85,18 @@ FAKE_RES_DETAIL_DATA_GETBASIC_INFO_TES_TS = """
         </firmware>
     </QDocRoot>"""
 
-FAKE_RES_DETAIL_DATA_GETBASIC_INFO_TES_ES = """
+FAKE_RES_DETAIL_DATA_GETBASIC_INFO_TES_ES_1_1_1 = """
+    <QDocRoot version="1.0">
+        <model>
+            <displayModelName><![CDATA[TES-1885U]]></displayModelName>
+            <internalModelName><![CDATA[ES-1885U]]></internalModelName>
+        </model>
+        <firmware>
+            <version><![CDATA[1.1.1]]></version>
+        </firmware>
+    </QDocRoot>"""
+
+FAKE_RES_DETAIL_DATA_GETBASIC_INFO_TES_ES_1_1_3 = """
     <QDocRoot version="1.0">
         <model>
             <displayModelName><![CDATA[TES-1885U]]></displayModelName>
@@ -94,6 +138,10 @@ FAKE_RES_DETAIL_DATA_VOLUME_INFO = """
                 <vol_no><![CDATA[fakeNo]]></vol_no>
                 <size><![CDATA[10]]></size>
                 <vol_mount_path>fakeMountPath</vol_mount_path>
+                <dedup><![CDATA[off]]></dedup>
+                <compression><![CDATA[1]]></compression>
+                <thin_pro><![CDATA[1]]></thin_pro>
+                <cache><![CDATA[0]]></cache>
             </row>
         </Volume_Info>
         <result><![CDATA[0]]></result>
@@ -148,7 +196,7 @@ FAKE_RES_DETAIL_DATA_GET_HOST_LIST = """
             <host>
                 <index><![CDATA[fakeHostIndex]]></index>
                 <hostid><![CDATA[fakeHostId]]></hostid>
-                <name><![CDATA[manila-hst-123]]></name>
+                <name><![CDATA[manila-fakeHostName]]></name>
                 <netaddrs>
                     <ipv4>
                         <![CDATA[fakeIp]]>
@@ -208,6 +256,20 @@ FAKE_RES_DETAIL_DATA_DELETE_SNAPSHOT = """
         <result>0</result>
     </QDocRoot>"""
 
+FAKE_RES_DETAIL_DATA_DELETE_SNAPSHOT_SNAPSHOT_NOT_EXIST = """
+    <QDocRoot version="1.0">
+        <authPassed><![CDATA[1]]></authPassed>
+        <ES_RET_CODE><![CDATA[1]]></ES_RET_CODE>
+        <result>-206021</result>
+    </QDocRoot>"""
+
+FAKE_RES_DETAIL_DATA_DELETE_SNAPSHOT_SHARE_NOT_EXIST = """
+    <QDocRoot version="1.0">
+        <authPassed><![CDATA[1]]></authPassed>
+        <ES_RET_CODE><![CDATA[1]]></ES_RET_CODE>
+        <result>-200005</result>
+    </QDocRoot>"""
+
 FAKE_RES_DETAIL_DATA_GET_HOST_LIST_API = """
     <QDocRoot version="1.0">
         <authPassed><![CDATA[1]]></authPassed>
@@ -229,6 +291,15 @@ FAKE_RES_DETAIL_DATA_GET_HOST_LIST_API = """
         <result><![CDATA[0]]></result>
     </QDocRoot>"""
 
+FAKE_RES_DETAIL_DATA_GET_NO_HOST_LIST_API = """
+    <QDocRoot version="1.0">
+        <authPassed><![CDATA[1]]></authPassed>
+        <ES_RET_CODE><![CDATA[1]]></ES_RET_CODE>
+        <content>
+        </content>
+        <result><![CDATA[0]]></result>
+    </QDocRoot>"""
+
 FAKE_RES_DETAIL_DATA_CREATE_SNAPSHOT = """
     <QDocRoot version="1.0">
         <authPassed><![CDATA[1]]></authPassed>
@@ -258,7 +329,8 @@ class SnapshotClass(object):
             'id': 'fakeSnapshotId',
             'share': {'share_id': 'fakeShareId', 'id': 'fakeId'},
             'share_instance': {'share_id': 'fakeShareId', 'id': 'fakeId'},
-            'size': self.size
+            'size': self.size,
+            'share_instance_id': 'fakeShareId'
         }[arg]
 
     def __setitem__(self, key, value):
@@ -347,44 +419,84 @@ class AccessClass(object):
         }[arg]
 
 
-class FakeGetBasicInfoResponseEs(object):
+class FakeGetBasicInfoResponseEs_1_1_1(object):
     """Fake GetBasicInfo response from ES nas."""
 
     status = 'fackStatus'
 
     def read(self):
         """Mock response.read."""
-        return FAKE_RES_DETAIL_DATA_GETBASIC_INFO_ES
+        return FAKE_RES_DETAIL_DATA_GETBASIC_INFO_ES_1_1_1
 
 
-class FakeGetBasicInfoResponseTs(object):
+class FakeGetBasicInfoResponseEs_1_1_3(object):
+    """Fake GetBasicInfo response from ES nas."""
+
+    status = 'fackStatus'
+
+    def read(self):
+        """Mock response.read."""
+        return FAKE_RES_DETAIL_DATA_GETBASIC_INFO_ES_1_1_3
+
+
+class FakeGetBasicInfoResponseTs_4_0_0(object):
     """Fake GetBasicInfoTS response from TS nas."""
 
     status = 'fackStatus'
 
     def read(self):
         """Mock response.read."""
-        return FAKE_RES_DETAIL_DATA_GETBASIC_INFO_TS
+        return FAKE_RES_DETAIL_DATA_GETBASIC_INFO_TS_4_0_0
 
 
-class FakeGetBasicInfoResponseTesTs(object):
+class FakeGetBasicInfoResponseTs_4_3_0(object):
     """Fake GetBasicInfoTS response from TS nas."""
 
     status = 'fackStatus'
 
     def read(self):
         """Mock response.read."""
-        return FAKE_RES_DETAIL_DATA_GETBASIC_INFO_TES_TS
+        return FAKE_RES_DETAIL_DATA_GETBASIC_INFO_TS_4_3_0
 
 
-class FakeGetBasicInfoResponseTesEs(object):
+class FakeGetBasicInfoResponseTesTs_4_0_0(object):
     """Fake GetBasicInfoTS response from TS nas."""
 
     status = 'fackStatus'
 
     def read(self):
         """Mock response.read."""
-        return FAKE_RES_DETAIL_DATA_GETBASIC_INFO_TES_ES
+        return FAKE_RES_DETAIL_DATA_GETBASIC_INFO_TES_TS_4_0_0
+
+
+class FakeGetBasicInfoResponseTesTs_4_3_0(object):
+    """Fake GetBasicInfoTS response from TS nas."""
+
+    status = 'fackStatus'
+
+    def read(self):
+        """Mock response.read."""
+        return FAKE_RES_DETAIL_DATA_GETBASIC_INFO_TES_TS_4_3_0
+
+
+class FakeGetBasicInfoResponseTesEs_1_1_1(object):
+    """Fake GetBasicInfoTS response from TS nas."""
+
+    status = 'fackStatus'
+
+    def read(self):
+        """Mock response.read."""
+        return FAKE_RES_DETAIL_DATA_GETBASIC_INFO_TES_ES_1_1_1
+
+
+class FakeGetBasicInfoResponseTesEs_1_1_3(object):
+    """Fake GetBasicInfoTS response from TS nas."""
+
+    status = 'fackStatus'
+
+    def read(self):
+        """Mock response.read."""
+        return FAKE_RES_DETAIL_DATA_GETBASIC_INFO_TES_ES_1_1_3
 
 
 class FakeGetBasicInfoResponseError(object):
@@ -418,7 +530,7 @@ class FakeDeleteShareResponse(object):
 
 
 class FakeDeleteSnapshotResponse(object):
-    """Fake pool info response."""
+    """Fake delete snapshot response."""
 
     status = 'fackStatus'
 
@@ -427,8 +539,28 @@ class FakeDeleteSnapshotResponse(object):
         return FAKE_RES_DETAIL_DATA_DELETE_SNAPSHOT
 
 
+class FakeDeleteSnapshotResponseSnapshotNotExist(object):
+    """Fake delete snapshot response."""
+
+    status = 'fackStatus'
+
+    def read(self):
+        """Mock response.read."""
+        return FAKE_RES_DETAIL_DATA_DELETE_SNAPSHOT_SNAPSHOT_NOT_EXIST
+
+
+class FakeDeleteSnapshotResponseShareNotExist(object):
+    """Fake delete snapshot response."""
+
+    status = 'fackStatus'
+
+    def read(self):
+        """Mock response.read."""
+        return FAKE_RES_DETAIL_DATA_DELETE_SNAPSHOT_SHARE_NOT_EXIST
+
+
 class FakeGetHostListResponse(object):
-    """Fake pool info response."""
+    """Fake host info response."""
 
     status = 'fackStatus'
 
@@ -437,6 +569,16 @@ class FakeGetHostListResponse(object):
         return FAKE_RES_DETAIL_DATA_GET_HOST_LIST_API
 
 
+class FakeGetNoHostListResponse(object):
+    """Fake host info response."""
+
+    status = 'fackStatus'
+
+    def read(self):
+        """Mock response.read."""
+        return FAKE_RES_DETAIL_DATA_GET_NO_HOST_LIST_API
+
+
 class FakeAuthPassFailResponse(object):
     """Fake pool info response."""
 
