@@ -16,6 +16,7 @@
 
 """Tests For miscellaneous util methods used with share."""
 
+import ddt
 import mock
 
 from manila.common import constants
@@ -23,6 +24,7 @@ from manila.share import utils as share_utils
 from manila import test
 
 
+@ddt.ddt
 class ShareUtilsTestCase(test.TestCase):
     def test_extract_host_without_pool(self):
         host = 'Host@Backend'
