@@ -116,19 +116,25 @@ class GenericUtilsTestCase(test.TestCase):
     @ddt.data(
         (("3G", "G"), 3.0),
         (("4.1G", "G"), 4.1),
+        (("4,1G", "G"), 4.1),
         (("5.23G", "G"), 5.23),
+        (("5,23G", "G"), 5.23),
         (("9728M", "G"), 9.5),
         (("8192K", "G"), 0.0078125),
         (("2T", "G"), 2048.0),
         (("2.1T", "G"), 2150.4),
+        (("2,1T", "G"), 2150.4),
         (("3P", "G"), 3145728.0),
         (("3.4P", "G"), 3565158.4),
+        (("3,4P", "G"), 3565158.4),
         (("9728M", "M"), 9728.0),
         (("9728.2381T", "T"), 9728.2381),
+        (("9728,2381T", "T"), 9728.2381),
         (("0", "G"), 0.0),
         (("512", "M"), 0.00048828125),
         (("2097152.", "M"), 2.0),
         ((".1024", "K"), 0.0001),
+        ((",1024", "K"), 0.0001),
         (("2048G", "T"), 2.0),
         (("65536G", "P"), 0.0625),
     )
@@ -145,6 +151,14 @@ class GenericUtilsTestCase(test.TestCase):
         ("1KM", "G"),
         ("K1M", "G"),
         ("M1K", "G"),
+        ("1.2fake", "G"),
+        ("1,2fake", "G"),
+        ("2.2GG", "G"),
+        ("1.1KM", "G"),
+        ("K2.2M", "G"),
+        ("K2,2M", "G"),
+        ("M2.2K", "G"),
+        ("M2,2K", "G"),
         ("", "G"),
         (23, "G"),
         (23.0, "G"),
@@ -331,54 +345,58 @@ class SSHPoolTestCase(test.TestCase):
             paramiko.SSHClient.assert_called_once_with()
 
 
+@ddt.ddt
 class CidrToNetmaskTestCase(test.TestCase):
     """Unit test for cidr to netmask."""
 
-    def test_cidr_to_netmask_01(self):
-        cidr = '10.0.0.0/0'
-        expected_netmask = '0.0.0.0'
+    @ddt.data(
+        ('10.0.0.0/0', '0.0.0.0'),
+        ('10.0.0.0/24', '255.255.255.0'),
+        ('10.0.0.0/5', '248.0.0.0'),
+        ('10.0.0.0/32', '255.255.255.255'),
+        ('10.0.0.1', '255.255.255.255'),
+    )
+    @ddt.unpack
+    def test_cidr_to_netmask(self, cidr, expected_netmask):
         result = utils.cidr_to_netmask(cidr)
         self.assertEqual(expected_netmask, result)
 
-    def test_cidr_to_netmask_02(self):
-        cidr = '10.0.0.0/24'
-        expected_netmask = '255.255.255.0'
-        result = utils.cidr_to_netmask(cidr)
-        self.assertEqual(expected_netmask, result)
-
-    def test_cidr_to_netmask_03(self):
-        cidr = '10.0.0.0/5'
-        expected_netmask = '248.0.0.0'
-        result = utils.cidr_to_netmask(cidr)
-        self.assertEqual(expected_netmask, result)
-
-    def test_cidr_to_netmask_04(self):
-        cidr = '10.0.0.0/32'
-        expected_netmask = '255.255.255.255'
-        result = utils.cidr_to_netmask(cidr)
-        self.assertEqual(expected_netmask, result)
-
-    def test_cidr_to_netmask_05(self):
-        cidr = '10.0.0.1'
-        expected_netmask = '255.255.255.255'
-        result = utils.cidr_to_netmask(cidr)
-        self.assertEqual(expected_netmask, result)
-
-    def test_cidr_to_netmask_invalid_01(self):
-        cidr = '10.0.0.0/33'
+    @ddt.data(
+        '10.0.0.0/33',
+        '',
+        '10.0.0.555/33'
+    )
+    def test_cidr_to_netmask_invalid(self, cidr):
         self.assertRaises(exception.InvalidInput, utils.cidr_to_netmask, cidr)
 
-    def test_cidr_to_netmask_invalid_02(self):
-        cidr = ''
-        self.assertRaises(exception.InvalidInput, utils.cidr_to_netmask, cidr)
 
-    def test_cidr_to_netmask_invalid_03(self):
-        cidr = '10.0.0.0/33'
-        self.assertRaises(exception.InvalidInput, utils.cidr_to_netmask, cidr)
+@ddt.ddt
+class CidrToPrefixLenTestCase(test.TestCase):
+    """Unit test for cidr to prefix length."""
 
-    def test_cidr_to_netmask_invalid_04(self):
-        cidr = '10.0.0.555/33'
-        self.assertRaises(exception.InvalidInput, utils.cidr_to_netmask, cidr)
+    @ddt.data(
+        ('10.0.0.0/0', 0),
+        ('10.0.0.0/24', 24),
+        ('10.0.0.1', 32),
+        ('fdf8:f53b:82e1::1/0', 0),
+        ('fdf8:f53b:82e1::1/64', 64),
+        ('fdf8:f53b:82e1::1', 128),
+    )
+    @ddt.unpack
+    def test_cidr_to_prefixlen(self, cidr, expected_prefixlen):
+        result = utils.cidr_to_prefixlen(cidr)
+        self.assertEqual(expected_prefixlen, result)
+
+    @ddt.data(
+        '10.0.0.0/33',
+        '',
+        '10.0.0.555/33',
+        'fdf8:f53b:82e1::1/129',
+        'fdf8:f53b:82e1::fffff'
+    )
+    def test_cidr_to_prefixlen_invalid(self, cidr):
+        self.assertRaises(exception.InvalidInput,
+                          utils.cidr_to_prefixlen, cidr)
 
 
 @ddt.ddt
@@ -732,7 +750,7 @@ class ShareMigrationHelperTestCase(test.TestCase):
         db.share_instance_get.assert_has_calls(
             [mock.call(mock.ANY, sid), mock.call(mock.ANY, sid)]
         )
-        time.sleep.assert_called_once_with(1)
+        time.sleep.assert_called_once_with(1.414)
 
     @ddt.data(
         (
